"""
This module contains precomputed values for levelstratum.adm_evaluate
to facilitate faster computation.

It contains many (meromorphic) low-genus strata that were computed to
a large part on a computer of the MPIM (requiring significant memory).
"""

from sage.rings.rational_field import QQ  # pylint: disable=import-error

ADM_EVAL_CACHE = {
    ((0,), ((1, 1),)): QQ('1/24'),
    ((-2, 1, 1), ((2, 2),)): QQ('1/6'),
    ((-2, 1, 1), ((1, 1), (2, 1))): QQ('1/6'),
    ((-2, -2, 1, 1), ((3, 1),)): QQ('1'),
    ((0, 0), ((1, 1), (2, 1))): QQ('1/24'),
    ((0, 0), ((1, 2),)): QQ('1/24'),
    ((-2, 1, 1), ((1, 2),)): QQ('1/24'),
    ((-2, 2), ((1, 1),)): QQ('1/8'),
    ((-2, -2, 1, 1), ((1, 1),)): QQ('1'),
    ((-2, 2), ((2, 1),)): QQ('1/8'),
    ((2,), ((1, 3),)): QQ('1/1920'),
    ((1, 1), ((1, 4),)): QQ('1/720'),
    ((-3, 3), ((1, 1),)): QQ('1/3'),
    ((1, 1), ((1, 2), (2, 2))): QQ('1/720'),
    ((1, 1), ((1, 1), (2, 3))): QQ('1/720'),
    ((0, 1, 1), ((1, 5),)): QQ('13/5760'),
    ((0, 2), ((1, 4),)): QQ('11/1920'),
    ((0, 0, 0), ((1, 3),)): QQ('1/24'),
    ((0, 1, 1), ((1, 3), (2, 2))): QQ('11/720'),
    ((-2, 0, 1, 1), ((2, 3),)): QQ('5/24'),
    ((-2, 0, 2), ((2, 2),)): QQ('1/4'),
    ((0, 0, 0), ((1, 1), (2, 2))): QQ('1/12'),
    ((-2, 0, 1, 1), ((1, 1), (2, 2))): QQ('1/4'),
    ((-2, -2, 0, 1, 1), ((3, 2),)): QQ('1'),
    ((-2, 0, 2), ((1, 1), (2, 1))): QQ('1/4'),
    ((-2, -2, 0, 2), ((3, 1),)): QQ('1'),
    ((-2, 0, 0, 0), ((2, 1),)): QQ('1'),
    ((0, 0, 0), ((1, 1), (2, 1), (3, 1))): QQ('1/12'),
    ((0, 1, 1), ((1, 2), (2, 3))): QQ('1/90'),
    ((-2, 0, 1, 1), ((2, 1), (3, 2))): QQ('1/2'),
    ((-2, 0, 1, 1), ((1, 1), (2, 1), (3, 1))): QQ('1/2'),
    ((-2, -2, 0, 1, 1), ((3, 1), (4, 1))): QQ('2'),
    ((-2, 0, 1, 1), ((1, 2), (2, 1))): QQ('1/8'),
    ((-4, 0, 1, 1), ((2, 1),)): QQ('1'),
    ((-2, -2, 0, 1, 1), ((1, 1), (3, 1))): QQ('2'),
    ((-2, 0, 0, 0), ((1, 1),)): QQ('1'),
    ((-2, 0, 2), ((1, 2),)): QQ('1/8'),
    ((-2, 0, 1, 1), ((1, 3),)): QQ('1/24'),
    ((-2, -2, 0, 1, 1), ((1, 2),)): QQ('1'),
    ((-4, 0, 1, 1), ((1, 1),)): QQ('1'),
    ((-2, -2, 0, 2), ((1, 1),)): QQ('1'),
    ((-2, -2, 0, 1, 1), ((1, 1), (2, 1))): QQ('2'),
    ((-2, 1, 1), ((2, 1), (3, 1))): QQ('1/6'),
    ((0, 1, 1), ((2, 5),)): QQ('1/720'),
    ((-2, 0, 1, 1), ((3, 3),)): QQ('1/6'),
    ((-2, 1, 3), ((2, 4),)): QQ('7/90'),
    ((-2, 1, 3), ((1, 1), (2, 3))): QQ('8/45'),
    ((-2, -2, 1, 3), ((3, 3),)): QQ('2/3'),
    ((-2, 1, 3), ((1, 2), (2, 2))): QQ('67/360'),
    ((-2, -2, -2, 1, 3), ((4, 2),)): QQ('1'),
    ((-4, 1, 3), ((2, 2),)): QQ('1'),
    ((-2, -2, 1, 3), ((1, 1), (3, 2))): QQ('11/6'),
    ((-2, 0, 1, 1), ((1, 1), (3, 2))): QQ('1/3'),
    ((-2, -2, 0, 1, 1), ((4, 2),)): QQ('1'),
    ((-2, 1, 3), ((1, 3), (2, 1))): QQ('31/360'),
    ((-3, -3, 1, 3), ((3, 1),)): QQ('1'),
    ((-4, -2, 1, 3), ((3, 1),)): QQ('1'),
    ((-2, -2, 1, 3), ((1, 2), (3, 1))): QQ('41/24'),
    ((-2, -2, -2, 1, 3), ((1, 1), (4, 1))): QQ('2'),
    ((-4, 1, 3), ((1, 1), (2, 1))): QQ('1'),
    ((-2, -2, 1, 3), ((1, 1), (2, 1), (3, 1))): QQ('2'),
    ((4,), ((1, 5),)): QQ('13/580608'),
    ((-2, 4), ((2, 3),)): QQ('19/1152'),
    ((-2, 4), ((1, 1), (2, 2))): QQ('73/1152'),
    ((-2, -2, 4), ((3, 2),)): QQ('7/24'),
    ((-2, 4), ((1, 2), (2, 1))): QQ('97/1152'),
    ((-2, -2, -2, 4), ((4, 1),)): QQ('1'),
    ((-4, 4), ((2, 1),)): QQ('5/8'),
    ((-2, -2, 4), ((1, 1), (3, 1))): QQ('11/12'),
    ((-2, 4), ((1, 3),)): QQ('43/1152'),
    ((-2, -2, 4), ((1, 2),)): QQ('19/24'),
    ((-2, -2, -2, 4), ((1, 1),)): QQ('1'),
    ((-4, 4), ((1, 1),)): QQ('5/8'),
    ((-2, -2, 4), ((1, 1), (2, 1))): QQ('11/12'),
    ((-2, 1, 3), ((1, 4),)): QQ('83/5760'),
    ((-2, -2, 1, 3), ((1, 3),)): QQ('13/24'),
    ((-3, -3, 1, 3), ((1, 1),)): QQ('1'),
    ((-4, -2, 1, 3), ((1, 1),)): QQ('1'),
    ((-2, -2, -2, 1, 3), ((1, 2),)): QQ('1'),
    ((-2, -2, -2, 1, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, 1, 3), ((2, 1),)): QQ('1'),
    ((-4, 1, 3), ((1, 2),)): QQ('3/8'),
    ((-2, -2, 1, 3), ((1, 1), (2, 2))): QQ('23/24'),
    ((1, 3), ((1, 6),)): QQ('23/45360'),
    ((0, 2), ((1, 2), (2, 2))): QQ('3/640'),
    ((0, 2), ((1, 1), (2, 3))): QQ('1/640'),
    ((0, 2), ((2, 4),)): QQ('1/1920'),
    ((-2, 0, 2), ((3, 2),)): QQ('1/8'),
    ((-2, -2, 0, 2), ((4, 1),)): QQ('1'),
    ((-2, 0, 2), ((1, 1), (3, 1))): QQ('1/4'),
    ((0, 0, 2), ((1, 2), (2, 3))): QQ('7/160'),
    ((0, 0, 0, 0), ((1, 2), (2, 2))): QQ('1/6'),
    ((0, 0, 2), ((1, 1), (2, 4))): QQ('11/480'),
    ((0, 0, 0, 0), ((1, 1), (2, 3))): QQ('1/8'),
    ((-2, 0, 2), ((2, 1), (3, 1))): QQ('1/4'),
    ((0, 0, 2), ((1, 1), (2, 2), (3, 2))): QQ('3/160'),
    ((-2, 0, 0, 2), ((2, 1), (3, 2))): QQ('3/4'),
    ((-2, 0, 0, 0, 0), ((2, 1), (3, 1))): QQ('2'),
    ((-2, -2, 0, 0, 2), ((3, 1), (4, 1))): QQ('2'),
    ((-2, 0, 0, 2), ((1, 1), (2, 1), (3, 1))): QQ('3/4'),
    ((0, 0, 2), ((1, 5),)): QQ('11/1920'),
    ((0, 0, 0, 0), ((1, 4),)): QQ('1/24'),
    ((0, 0, 2), ((1, 3), (3, 2))): QQ('13/960'),
    ((-2, 0, 0, 2), ((2, 3),)): QQ('1/4'),
    ((-2, 0, 0, 0, 0), ((2, 2),)): QQ('1'),
    ((-2, -2, 0, 0, 2), ((3, 2),)): QQ('1'),
    ((-2, 0, 0, 2), ((1, 1), (2, 2))): QQ('1/2'),
    ((-2, 0, 0, 0, 0), ((1, 1), (2, 1))): QQ('2'),
    ((0, 0, 2), ((1, 1), (2, 1), (3, 3))): QQ('1/160'),
    ((0, 0, 2), ((1, 2), (3, 3))): QQ('1/160'),
    ((-2, 0, 0, 2), ((2, 1), (4, 2))): QQ('3/8'),
    ((-2, -2, 0, 0, 2), ((3, 1), (5, 1))): QQ('2'),
    ((-2, 0, 0, 2), ((1, 1), (2, 1), (4, 1))): QQ('3/4'),
    ((-2, -2, 0, 0, 2), ((1, 1), (3, 1))): QQ('2'),
    ((-4, 0, 0, 2), ((2, 1),)): QQ('1'),
    ((-2, 0, 0, 2), ((1, 2), (2, 1))): QQ('3/8'),
    ((-2, 0, 0, 0, 0), ((1, 2),)): QQ('1'),
    ((-2, -2, 0, 0, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-2, -2, 0, 0, 2), ((1, 2),)): QQ('1'),
    ((-4, 0, 0, 2), ((1, 1),)): QQ('1'),
    ((-2, 0, 0, 2), ((1, 3),)): QQ('1/8'),
    ((0, 0, 2), ((3, 5),)): QQ('1/1920'),
    ((-2, 0, 0, 2), ((4, 3),)): QQ('1/8'),
    ((-2, 2, 2), ((2, 4),)): QQ('19/480'),
    ((-2, -2, 2, 2), ((3, 3),)): QQ('11/24'),
    ((-2, 2, 2), ((1, 1), (2, 3))): QQ('53/480'),
    ((-2, -2, 0, 0, 2), ((5, 2),)): QQ('1'),
    ((-2, -2, 2, 2), ((1, 1), (3, 2))): QQ('11/8'),
    ((-2, -2, -2, 2, 2), ((4, 2),)): QQ('1'),
    ((-4, 2, 2), ((2, 2),)): QQ('19/24'),
    ((-2, 2, 2), ((1, 2), (2, 2))): QQ('127/960'),
    ((-2, 0, 0, 2), ((1, 1), (4, 2))): QQ('3/8'),
    ((-2, -2, 2, 2), ((1, 1), (2, 1), (3, 1))): QQ('7/4'),
    ((-2, -2, 2, 2), ((1, 2), (3, 1))): QQ('11/8'),
    ((-2, -2, -2, 2, 2), ((1, 1), (4, 1))): QQ('2'),
    ((-4, -2, 2, 2), ((3, 1),)): QQ('1'),
    ((-3, -3, 2, 2), ((3, 1),)): QQ('1'),
    ((-4, 2, 2), ((1, 1), (2, 1))): QQ('11/12'),
    ((-2, 2, 2), ((1, 3), (2, 1))): QQ('37/480'),
    ((-2, -2, 2, 2), ((1, 1), (2, 2))): QQ('17/24'),
    ((-2, -2, 2, 2), ((1, 3),)): QQ('11/24'),
    ((-2, -2, -2, 2, 2), ((1, 2),)): QQ('1'),
    ((-4, -2, 2, 2), ((2, 1),)): QQ('1'),
    ((-2, -2, -2, 2, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, 2, 2), ((1, 1),)): QQ('1'),
    ((-3, -3, 2, 2), ((1, 1),)): QQ('1'),
    ((-4, 2, 2), ((1, 2),)): QQ('7/24'),
    ((-2, 2, 2), ((1, 4),)): QQ('103/5760'),
    ((0, 0, 0, 0), ((1, 1), (2, 1), (3, 2))): QQ('1/4'),
    ((0, 0, 0, 0), ((1, 1), (2, 1), (3, 1), (4, 1))): QQ('1/4'),
    ((2, 2), ((1, 6),)): QQ('43/322560'),
    ((-3, 1, 2), ((1, 2),)): QQ('1/6'),
    ((-3, 0, 0, 1), ((1, 1),)): QQ('1'),
    ((-3, -2, 1, 2), ((1, 1),)): QQ('1'),
    ((-3, -3, 1, 1, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, 1, 1, 2), ((1, 2),)): QQ('1'),
    ((-6, 1, 1, 2), ((1, 1),)): QQ('1'),
    ((-4, -2, 1, 1, 2), ((2, 2),)): QQ('1'),
    ((-3, -2, 1, 2), ((2, 1),)): QQ('1'),
    ((-4, -2, 1, 1, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-2, -2, 0, 0, 1, 1), ((1, 1), (2, 2))): QQ('3'),
    ((-2, -2, -2, 1, 1, 2), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, 1, 1, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-2, -2, 0, 0, 1, 1), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, 1, 1, 2), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-4, -2, 1, 1, 2), ((1, 2),)): QQ('1'),
    ((-4, 1, 1, 2), ((1, 3),)): QQ('5/24'),
    ((-4, 0, 0, 1, 1), ((1, 2),)): QQ('1'),
    ((-2, 0, 0, 1, 1), ((1, 4),)): QQ('1/24'),
    ((-2, 1, 1, 2), ((1, 5),)): QQ('43/5760'),
    ((-2, -2, 1, 1, 2), ((1, 1), (2, 3))): QQ('5/6'),
    ((-2, -2, 1, 1, 2), ((1, 2), (2, 2))): QQ('11/12'),
    ((-2, -2, 1, 1, 2), ((1, 4),)): QQ('3/8'),
    ((1, 1, 1, 1), ((1, 1), (2, 1), (3, 1), (4, 5))): QQ('79/8640'),
    ((-2, 1, 1, 1, 1), ((2, 1), (3, 1), (4, 1), (5, 3))): QQ('31/24'),
    ((-2, 1, 1, 1, 1), ((1, 1), (2, 1), (3, 1), (4, 1), (5, 2))): QQ('73/24'),
    ((-2, -2, 1, 1, 1, 1), ((3, 1), (4, 1), (5, 1), (6, 2))): QQ('45/4'),
    ((-2, -2, 1, 1, 1, 1), ((1, 1), (3, 1), (4, 1), (5, 1), (6, 1))): QQ('25'),
    ((-2, -2, -2, 1, 1, 1, 1), ((4, 1), (5, 1), (6, 1), (7, 1))): QQ('24'),
    ((0, 1, 1), ((1, 3), (2, 1), (3, 1))): QQ('11/720'),
    ((-2, 0, 1, 1), ((2, 1), (3, 1), (4, 1))): QQ('1/2'),
    ((-2, 0, 1, 1), ((1, 1), (3, 1), (4, 1))): QQ('1/2'),
    ((-2, -2, 0, 1, 1), ((4, 1), (5, 1))): QQ('2'),
    ((-2, 1, 1, 1, 1), ((1, 2), (2, 1), (3, 1), (4, 1), (5, 1))): QQ('67/24'),
    ((-4, 1, 1, 1, 1), ((2, 1), (3, 1), (4, 1), (5, 1))): QQ('9'),
    ((-3, 1, 1, 1), ((2, 1), (3, 1), (4, 1))): QQ('5/4'),
    ((6,), ((1, 7),)): QQ('281/199065600'),
    ((-2, 6), ((2, 5),)): QQ('913/414720'),
    ((-2, -2, 6), ((3, 4),)): QQ('359/5760'),
    ((-2, 6), ((1, 1), (2, 4))): QQ('6533/414720'),
    ((-4, 6), ((2, 3),)): QQ('413/1920'),
    ((-2, -2, 6), ((1, 1), (3, 3))): QQ('631/1440'),
    ((-2, -2, -2, 6), ((4, 3),)): QQ('11/24'),
    ((-2, 6), ((1, 2), (2, 3))): QQ('9701/207360'),
    ((-4, 6), ((1, 1), (2, 2))): QQ('1463/1920'),
    ((-4, -2, 6), ((3, 2),)): QQ('19/24'),
    ((-3, -3, 6), ((3, 2),)): QQ('17/24'),
    ((-2, -2, 6), ((1, 1), (2, 1), (3, 2))): QQ('2513/1440'),
    ((-2, -2, -2, 6), ((1, 1), (4, 2))): QQ('49/24'),
    ((-2, -2, 6), ((1, 2), (3, 2))): QQ('3421/2880'),
    ((-2, -2, -2, -2, 6), ((5, 2),)): QQ('1'),
    ((-2, 6), ((1, 3), (2, 2))): QQ('14533/207360'),
    ((-2, -2, -2, -2, 6), ((1, 1), (5, 1))): QQ('2'),
    ((-4, -2, -2, 6), ((4, 1),)): QQ('1'),
    ((-2, -2, -2, 6), ((1, 2), (4, 1))): QQ('27/8'),
    ((-4, -2, 6), ((2, 1), (3, 1))): QQ('9/4'),
    ((-3, -3, -2, 6), ((4, 1),)): QQ('1'),
    ((-4, 6), ((1, 2), (2, 1))): QQ('581/640'),
    ((-4, -2, 6), ((1, 1), (3, 1))): QQ('9/4'),
    ((-6, 6), ((2, 1),)): QQ('35/24'),
    ((-3, -3, 6), ((1, 1), (3, 1))): QQ('13/6'),
    ((-2, -2, 6), ((1, 1), (2, 2), (3, 1))): QQ('3809/1440'),
    ((-2, -2, 6), ((1, 3), (3, 1))): QQ('2039/1440'),
    ((-2, -2, -2, 6), ((1, 1), (2, 1), (4, 1))): QQ('23/4'),
    ((-2, 6), ((1, 4), (2, 1))): QQ('21733/414720'),
    ((-2, -2, -2, -2, 6), ((1, 2),)): QQ('1'),
    ((-4, -2, -2, 6), ((2, 1),)): QQ('1'),
    ((-4, -2, -2, 6), ((1, 1),)): QQ('1'),
    ((0, 4), ((1, 6),)): QQ('1105/580608'),
    ((-2, 0, 4), ((2, 4),)): QQ('43/288'),
    ((-2, -2, 0, 4), ((3, 3),)): QQ('23/24'),
    ((-2, 0, 4), ((1, 1), (2, 3))): QQ('89/288'),
    ((-4, 0, 4), ((2, 2),)): QQ('5/4'),
    ((-2, -2, 0, 4), ((1, 1), (3, 2))): QQ('5/2'),
    ((-2, -2, -2, 0, 4), ((4, 2),)): QQ('1'),
    ((-2, 0, 4), ((1, 2), (2, 2))): QQ('89/288'),
    ((-4, 0, 4), ((1, 1), (2, 1))): QQ('5/4'),
    ((-4, -2, 0, 4), ((3, 1),)): QQ('1'),
    ((-3, -3, 0, 4), ((3, 1),)): QQ('1'),
    ((-2, -2, 0, 4), ((1, 1), (2, 1), (3, 1))): QQ('11/4'),
    ((-2, -2, -2, 0, 4), ((1, 1), (4, 1))): QQ('2'),
    ((-2, -2, 0, 4), ((1, 2), (3, 1))): QQ('19/8'),
    ((-2, 0, 4), ((1, 3), (2, 1))): QQ('43/288'),
    ((-4, 0, 4), ((1, 2),)): QQ('5/8'),
    ((-4, -2, 0, 4), ((1, 1),)): QQ('1'),
    ((-3, -3, 0, 4), ((1, 1),)): QQ('1'),
    ((-2, -2, 0, 4), ((1, 1), (2, 2))): QQ('41/24'),
    ((-4, -2, 0, 4), ((2, 1),)): QQ('1'),
    ((-2, -2, 0, 4), ((1, 3),)): QQ('19/24'),
    ((-2, -2, -2, 0, 4), ((1, 2),)): QQ('1'),
    ((-2, -2, -2, 0, 4), ((1, 1), (2, 1))): QQ('2'),
    ((-2, 0, 4), ((1, 4),)): QQ('43/1152'),
    ((-2, -2, -2, -2, 6), ((1, 1), (2, 1))): QQ('2'),
    ((-2, -2, -2, 6), ((1, 1), (2, 2))): QQ('113/24'),
    ((-3, -3, -2, 6), ((3, 1),)): QQ('1'),
    ((-2, -2, -2, 6), ((1, 3),)): QQ('43/24'),
    ((-4, -2, 6), ((2, 2),)): QQ('17/8'),
    ((-3, -3, -2, 6), ((1, 1),)): QQ('1'),
    ((0, 1, 1), ((1, 4), (2, 1))): QQ('7/720'),
    ((-2, 0, 1, 1), ((2, 2), (3, 1))): QQ('1/2'),
    ((0, 1, 1), ((1, 1), (2, 4))): QQ('1/180'),
    ((-4, 0, 1, 1), ((3, 1),)): QQ('1'),
    ((-2, -2, 0, 1, 1), ((1, 1), (4, 1))): QQ('2'),
    ((-2, 0, 1, 1), ((1, 2), (3, 1))): QQ('5/24'),
    ((-4, 6), ((1, 3),)): QQ('231/640'),
    ((-4, -2, 6), ((1, 2),)): QQ('13/8'),
    ((-6, 6), ((1, 1),)): QQ('35/24'),
    ((-4, 0, 0, 2), ((4, 1),)): QQ('1'),
    ((-4, 2, 2), ((2, 1), (3, 1))): QQ('11/12'),
    ((-3, -3, 6), ((1, 1), (2, 1))): QQ('13/6'),
    ((-3, -3, 6), ((1, 2),)): QQ('11/6'),
    ((-2, -2, 6), ((1, 2), (2, 2))): QQ('5309/2880'),
    ((-2, -2, 6), ((1, 1), (2, 3))): QQ('1927/1440'),
    ((-4, -2, 6), ((1, 1), (2, 1))): QQ('9/4'),
    ((-2, -2, 6), ((1, 4),)): QQ('3623/5760'),
    ((-2, -2, -2, 6), ((1, 1), (2, 1), (3, 1))): QQ('23/4'),
    ((-2, -2, 2, 2), ((1, 1), (3, 1), (4, 1))): QQ('7/4'),
    ((-2, -2, -2, 2, 2), ((4, 1), (5, 1))): QQ('2'),
    ((-2, -2, 0, 0, 2), ((1, 1), (5, 1))): QQ('2'),
    ((-2, -2, 2, 2), ((3, 1), (4, 2))): QQ('17/24'),
    ((0, 0, 2), ((1, 2), (2, 2), (3, 1))): QQ('11/240'),
    ((0, 0, 2), ((1, 1), (2, 3), (3, 1))): QQ('17/480'),
    ((0, 0, 2), ((1, 4), (3, 1))): QQ('7/480'),
    ((-2, 0, 0, 2), ((2, 1), (3, 1), (4, 1))): QQ('3/4'),
    ((-2, 0, 0, 2), ((2, 2), (4, 1))): QQ('1/2'),
    ((0, 0, 2), ((1, 1), (3, 4))): QQ('1/480'),
    ((-2, 0, 0, 2), ((1, 2), (4, 1))): QQ('3/8'),
    ((0, 2), ((1, 3), (2, 1))): QQ('17/1920'),
    ((-2, 6), ((1, 5),)): QQ('6449/414720'),
    ((-2, 2, 2), ((1, 2), (2, 1), (3, 1))): QQ('91/480'),
    ((-2, 2, 2), ((1, 1), (2, 1), (3, 2))): QQ('83/480'),
    ((-2, 2, 2), ((2, 2), (3, 2))): QQ('21/320'),
    ((-2, 2, 2), ((2, 1), (3, 3))): QQ('29/480'),
    ((2, 2), ((1, 3), (2, 3))): QQ('13/53760'),
    ((2, 2), ((1, 2), (2, 4))): QQ('13/53760'),
    ((2, 2), ((1, 1), (2, 5))): QQ('71/322560'),
    ((-2, -2, -2, 1, 1, 2), ((1, 1), (2, 1), (4, 1))): QQ('6'),
    ((-3, -2, 1, 2), ((3, 1),)): QQ('1'),
    ((-4, -2, 1, 1, 2), ((2, 1), (3, 1))): QQ('2'),
    ((-2, -2, -2, 1, 1, 2), ((1, 2), (4, 1))): QQ('3'),
    ((-4, -2, 1, 1, 2), ((1, 1), (3, 1))): QQ('2'),
    ((-6, 1, 1, 2), ((2, 1),)): QQ('1'),
    ((-2, -2, -2, 1, 1, 2), ((1, 1), (4, 2))): QQ('3'),
    ((-4, -2, 1, 1, 2), ((3, 2),)): QQ('1'),
    ((-2, -2, 1, 1, 2), ((1, 1), (2, 2), (3, 1))): QQ('8/3'),
    ((-2, -2, 1, 1, 2), ((1, 1), (2, 1), (3, 2))): QQ('11/3'),
    ((-2, -2, 0, 0, 1, 1), ((1, 2), (5, 1))): QQ('3'),
    ((-2, -2, 0, 0, 1, 1), ((1, 2), (3, 1))): QQ('3'),
    ((-2, -2, 1, 1, 2), ((1, 3), (3, 1))): QQ('19/12'),
    ((-2, -2, 1, 1, 2), ((1, 2), (3, 2))): QQ('61/24'),
    ((-2, -2, 0, 0, 1, 1), ((1, 1), (2, 1), (5, 1))): QQ('6'),
    ((-2, -2, 0, 0, 1, 1), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-3, 0, 0, 1), ((2, 1),)): QQ('1'),
    ((-2, -2, 0, 0, 1, 1), ((1, 1), (3, 1), (4, 1))): QQ('6'),
    ((-2, -2, 0, 0, 1, 1), ((1, 1), (3, 2))): QQ('3'),
    ((-3, 1, 2), ((1, 1), (2, 1))): QQ('1/2'),
    ((-3, 1, 2), ((2, 2),)): QQ('1/2'),
    ((-3, 0, 0, 1), ((4, 1),)): QQ('1'),
    ((-2, 1, 1, 2), ((1, 4), (2, 1))): QQ('299/5760'),
    ((-2, 0, 0, 1, 1), ((1, 3), (4, 1))): QQ('1/4'),
    ((-2, 0, 0, 1, 1), ((1, 3), (2, 1))): QQ('1/6'),
    ((-3, -3, 1, 1, 2), ((1, 1), (3, 1))): QQ('2'),
    ((-3, -3, 1, 1, 2), ((3, 2),)): QQ('1'),
    ((-2, 1, 1, 2), ((1, 3), (2, 2))): QQ('101/720'),
    ((-2, 0, 0, 1, 1), ((1, 2), (4, 2))): QQ('13/24'),
    ((-2, 0, 0, 1, 1), ((1, 2), (2, 1), (4, 1))): QQ('5/6'),
    ((-2, 0, 0, 1, 1), ((1, 2), (2, 1), (3, 1))): QQ('1/2'),
    ((-2, 0, 0, 1, 1), ((1, 2), (2, 2))): QQ('3/8'),
    ((-2, -2, -2, 1, 1, 2), ((4, 3),)): QQ('1'),
    ((-4, 1, 1, 2), ((1, 2), (2, 1))): QQ('7/8'),
    ((-4, 1, 1, 2), ((1, 1), (2, 2))): QQ('3/2'),
    ((-4, 0, 0, 1, 1), ((1, 1), (4, 1))): QQ('2'),
    ((-4, 0, 0, 1, 1), ((1, 1), (2, 1))): QQ('2'),
    ((-4, 1, 1, 2), ((2, 3),)): QQ('5/6'),
    ((-4, 0, 0, 1, 1), ((4, 2),)): QQ('1'),
    ((-4, 0, 0, 1, 1), ((2, 1), (4, 1))): QQ('2'),
    ((-4, 0, 0, 1, 1), ((2, 1), (3, 1))): QQ('2'),
    ((-4, 0, 0, 1, 1), ((2, 2),)): QQ('1'),
    ((-2, 0, 0, 1, 1), ((1, 1), (4, 3))): QQ('1/2'),
    ((-2, 0, 0, 1, 1), ((1, 1), (2, 1), (4, 2))): QQ('4/3'),
    ((-2, 0, 0, 1, 1), ((1, 1), (2, 1), (3, 1), (4, 1))): QQ('2'),
    ((-2, 0, 0, 1, 1), ((1, 1), (2, 1), (3, 2))): QQ('1'),
    ((-2, 0, 0, 1, 1), ((1, 1), (2, 2), (4, 1))): QQ('5/4'),
    ((-2, 0, 0, 1, 1), ((1, 1), (2, 3))): QQ('11/24'),
    ((-2, -2, 1, 1, 2), ((1, 1), (3, 3))): QQ('11/6'),
    ((-2, -2, 0, 0, 1, 1), ((1, 1), (5, 2))): QQ('3'),
    ((-2, -2, 0, 0, 1, 1), ((1, 1), (3, 1), (5, 1))): QQ('6'),
    ((-2, -2, 0, 0, 1, 1), ((5, 3),)): QQ('1'),
    ((-2, -2, 0, 0, 1, 1), ((3, 1), (5, 2))): QQ('3'),
    ((-2, -2, 0, 0, 1, 1), ((3, 1), (4, 1), (5, 1))): QQ('6'),
    ((-2, -2, 0, 0, 1, 1), ((3, 2), (5, 1))): QQ('3'),
    ((-2, -2, 0, 0, 1, 1), ((3, 1), (4, 2))): QQ('3'),
    ((-2, -2, 0, 0, 1, 1), ((3, 3),)): QQ('1'),
    ((-2, 0, 0, 1, 1), ((2, 1), (4, 3))): QQ('2/3'),
    ((-2, 0, 0, 1, 1), ((2, 1), (3, 1), (4, 2))): QQ('2'),
    ((-2, 0, 0, 1, 1), ((2, 2), (4, 2))): QQ('1'),
    ((-2, 0, 0, 1, 1), ((2, 1), (3, 2), (4, 1))): QQ('2'),
    ((-2, 0, 0, 1, 1), ((2, 3), (4, 1))): QQ('17/24'),
    ((-2, 0, 0, 1, 1), ((2, 2), (3, 2))): QQ('7/6'),
    ((-2, 0, 0, 1, 1), ((2, 1), (3, 3))): QQ('5/6'),
    ((-2, 0, 0, 1, 1), ((2, 4),)): QQ('5/24'),
    ((-2, 1, 1, 2), ((1, 1), (2, 4))): QQ('13/90'),
    ((-2, -2, 1, 1, 2), ((3, 4),)): QQ('1/2'),
    ((-2, 1, 1, 2), ((2, 5),)): QQ('37/720'),
    ((-2, 0, 0, 1, 1), ((4, 4),)): QQ('1/6'),
    ((1, 1, 2), ((1, 7),)): QQ('5/18144'),
    ((0, 0, 1, 1), ((3, 6),)): QQ('1/720'),
    ((0, 0, 1, 1), ((1, 1), (3, 5))): QQ('1/144'),
    ((0, 0, 1, 1), ((1, 1), (2, 1), (3, 4))): QQ('1/36'),
    ((0, 0, 1, 1), ((1, 2), (3, 4))): QQ('1/60'),
    ((0, 0, 1, 1), ((1, 1), (2, 2), (3, 3))): QQ('1/18'),
    ((0, 0, 1, 1), ((1, 3), (3, 3))): QQ('19/720'),
    ((0, 0, 1, 1), ((1, 2), (2, 2), (3, 2))): QQ('7/72'),
    ((0, 0, 1, 1), ((1, 1), (2, 3), (3, 2))): QQ('11/144'),
    ((0, 0, 1, 1), ((1, 4), (3, 2))): QQ('1/40'),
    ((0, 0, 1, 1), ((1, 2), (2, 3), (3, 1))): QQ('13/144'),
    ((0, 0, 1, 1), ((1, 1), (2, 4), (3, 1))): QQ('7/144'),
    ((0, 0, 1, 1), ((1, 5), (3, 1))): QQ('23/1920'),
    ((0, 0, 1, 1), ((1, 3), (2, 3))): QQ('13/320'),
    ((0, 0, 1, 1), ((1, 2), (2, 4))): QQ('41/1440'),
    ((0, 0, 1, 1), ((1, 1), (2, 5))): QQ('13/1152'),
    ((0, 0, 1, 1), ((1, 6),)): QQ('13/5760'),
    ((-2, 1, 1, 1, 1), ((1, 6),)): QQ('23/5760'),
    ((-2, -2, 1, 1, 1, 1), ((1, 1), (2, 4))): QQ('19/24'),
    ((-2, -2, -2, 1, 1, 1, 1), ((1, 4),)): QQ('1'),
    ((-2, -2, -2, 1, 1, 1, 1), ((1, 1), (2, 3))): QQ('4'),
    ((-4, -2, 1, 1, 1, 1), ((2, 3),)): QQ('1'),
    ((-2, -2, 1, 1, 1, 1), ((1, 2), (2, 3))): QQ('11/12'),
    ((-4, -2, 1, 1, 1, 1), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -2, 1, 1, 1), ((2, 2),)): QQ('1'),
    ((-2, -2, -2, 1, 1, 1, 1), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-2, -2, -2, 1, 1, 1, 1), ((1, 2), (2, 2))): QQ('6'),
    ((-3, -2, 1, 1, 1), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -2, 1, 1, 1), ((1, 2),)): QQ('1'),
    ((-4, -2, 1, 1, 1, 1), ((1, 2), (2, 1))): QQ('3'),
    ((-4, -2, 1, 1, 1, 1), ((1, 3),)): QQ('1'),
    ((-2, -2, 1, 1, 1, 1), ((1, 5),)): QQ('7/24'),
    ((-6, 1, 1, 1, 1), ((1, 2),)): QQ('1'),
    ((-4, 1, 1, 1, 1), ((1, 4),)): QQ('1/8'),
    ((-3, 1, 1, 1), ((1, 3),)): QQ('1/12'),
    ((-5, 1, 1, 1), ((1, 1),)): QQ('1'),
    ((-3, -3, 1, 1, 1, 1), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, 1, 5), ((1, 4),)): QQ('11/8'),
    ((-4, -2, 1, 5), ((2, 3),)): QQ('41/24'),
    ((-3, -2, -2, 5), ((1, 1),)): QQ('1'),
    ((-2, -2, -2, -2, 1, 5), ((1, 1), (2, 2))): QQ('3'),
    ((-4, -2, -2, 1, 5), ((2, 1), (3, 1))): QQ('2'),
    ((-6, -2, 1, 5), ((2, 1),)): QQ('1'),
    ((-3, -2, -2, 5), ((2, 1),)): QQ('1'),
    ((-4, -2, -2, 1, 5), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -2, 5), ((1, 1), (2, 1))): QQ('3/2'),
    ((-3, -3, -2, 1, 5), ((1, 1), (3, 1))): QQ('2'),
    ((-2, -2, -2, -2, 1, 5), ((1, 3),)): QQ('1'),
    ((-4, -2, -2, 1, 5), ((2, 2),)): QQ('1'),
    ((-6, -2, 1, 5), ((1, 1),)): QQ('1'),
    ((-3, -2, 5), ((1, 2),)): QQ('7/6'),
    ((-3, -3, -2, 1, 5), ((1, 2),)): QQ('1'),
    ((-5, -3, 1, 5), ((2, 1),)): QQ('1'),
    ((-3, -3, -2, 1, 5), ((1, 1), (2, 1))): QQ('2'),
    ((-6, 1, 5), ((1, 2),)): QQ('25/24'),
    ((-4, -2, 1, 5), ((1, 3),)): QQ('29/24'),
    ((-4, -2, -2, 1, 5), ((1, 2),)): QQ('1'),
    ((-4, -4, 1, 5), ((1, 1),)): QQ('1'),
    ((-2, -2, 1, 5), ((1, 5),)): QQ('2203/5760'),
    ((-2, -2, -2, 1, 5), ((1, 1), (2, 3))): QQ('29/6'),
    ((-2, -2, -2, 1, 5), ((1, 2), (2, 2))): QQ('83/12'),
    ((-3, -2, 5), ((2, 2),)): QQ('11/8'),
    ((-3, -3, -2, 1, 5), ((3, 2),)): QQ('1'),
    ((-2, -2, -2, 1, 5), ((1, 1), (2, 1), (3, 2))): QQ('61/6'),
    ((-4, -2, 1, 5), ((1, 1), (2, 2))): QQ('25/8'),
    ((-2, -2, -2, -2, 1, 5), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-4, -2, 1, 5), ((1, 2), (2, 1))): QQ('21/8'),
    ((-5, -3, 1, 5), ((1, 1),)): QQ('1'),
    ((-4, 1, 5), ((1, 4),)): QQ('353/1920'),
    ((-2, 1, 5), ((1, 6),)): QQ('18713/2903040'),
    ((-2, -2, 1, 5), ((1, 1), (2, 4))): QQ('5831/5760'),
    ((-2, -2, 1, 5), ((1, 2), (2, 3))): QQ('4463/2880'),
    ((-3, -3, 1, 5), ((1, 3),)): QQ('17/12'),
    ((-5, 5), ((1, 1),)): QQ('1'),
    ((-3, 5), ((1, 3),)): QQ('17/120'),
    ((-4, -2, 0, 1, 3), ((1, 2),)): QQ('1'),
    ((-6, 0, 1, 3), ((1, 1),)): QQ('1'),
    ((-4, 0, 1, 3), ((1, 3),)): QQ('3/8'),
    ((-4, -2, 0, 1, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -2, 0, 3), ((2, 1),)): QQ('1'),
    ((-2, 0, 1, 3), ((1, 5),)): QQ('83/5760'),
    ((-2, -2, 0, 1, 3), ((1, 1), (2, 3))): QQ('3/2'),
    ((-2, -2, -2, 0, 1, 3), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, 0, 1, 3), ((1, 1), (2, 2))): QQ('3'),
    ((-4, -2, 0, 1, 3), ((2, 2),)): QQ('1'),
    ((-2, -2, 0, 1, 3), ((1, 2), (2, 2))): QQ('23/12'),
    ((-2, -2, 0, 1, 3), ((1, 4),)): QQ('13/24'),
    ((-3, -3, 0, 1, 3), ((1, 2),)): QQ('1'),
    ((-3, -2, 0, 3), ((1, 1),)): QQ('1'),
    ((-3, 0, 3), ((1, 2),)): QQ('1/3'),
    ((-2, -2, -2, 0, 1, 3), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-6, 2, 4), ((1, 2),)): QQ('19/24'),
    ((-6, -2, 2, 4), ((1, 1),)): QQ('1'),
    ((-4, -2, -2, 2, 4), ((1, 2),)): QQ('1'),
    ((-4, -4, 2, 4), ((1, 1),)): QQ('1'),
    ((-2, -2, -2, 2, 4), ((1, 1), (2, 3))): QQ('23/6'),
    ((-3, -3, -2, 2, 4), ((3, 2),)): QQ('1'),
    ((-4, -2, -2, 2, 4), ((2, 2),)): QQ('1'),
    ((-6, -2, 2, 4), ((2, 1),)): QQ('1'),
    ((-2, -2, -2, -2, 2, 4), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -3, -2, 2, 4), ((1, 1), (3, 1))): QQ('2'),
    ((-4, -2, -2, 2, 4), ((2, 1), (3, 1))): QQ('2'),
    ((-4, -2, -2, 2, 4), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -2, 2, 4), ((1, 2),)): QQ('1'),
    ((-5, -3, 2, 4), ((2, 1),)): QQ('1'),
    ((-3, -3, -2, 2, 4), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, 2, 4), ((1, 3),)): QQ('23/24'),
    ((-4, 2, 4), ((1, 4),)): QQ('277/1920'),
    ((-2, 2, 4), ((1, 6),)): QQ('17831/2903040'),
    ((-2, -2, 2, 4), ((1, 1), (2, 4))): QQ('4451/5760'),
    ((-2, -2, -2, 2, 4), ((1, 4),)): QQ('9/8'),
    ((-2, -2, 2, 4), ((1, 2), (2, 3))): QQ('3563/2880'),
    ((-2, -2, -2, -2, 2, 4), ((1, 3),)): QQ('1'),
    ((-4, -2, 2, 4), ((2, 3),)): QQ('35/24'),
    ((-2, -2, -2, 2, 4), ((1, 2), (2, 2))): QQ('65/12'),
    ((-4, -2, 2, 4), ((1, 1), (2, 2))): QQ('19/8'),
    ((-2, -2, -2, 2, 4), ((1, 1), (2, 1), (3, 2))): QQ('43/6'),
    ((-2, -2, -2, -2, 2, 4), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-4, -2, 2, 4), ((1, 2), (2, 1))): QQ('15/8'),
    ((-2, -2, 2, 4), ((1, 5),)): QQ('347/1152'),
    ((-5, -3, 2, 4), ((1, 1),)): QQ('1'),
    ((-6, 0, 0, 4), ((1, 1),)): QQ('1'),
    ((-2, -2, 0, 2, 2), ((1, 4),)): QQ('11/24'),
    ((-2, -2, -2, 0, 2, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-4, -2, 0, 2, 2), ((2, 2),)): QQ('1'),
    ((-4, -2, 0, 2, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-2, -2, -2, 0, 2, 2), ((1, 3),)): QQ('1'),
    ((-4, -2, 0, 2, 2), ((1, 2),)): QQ('1'),
    ((-6, 0, 2, 2), ((1, 1),)): QQ('1'),
    ((-2, 0, 0, 0, 2), ((1, 4),)): QQ('1/8'),
    ((-3, -3, 2, 4), ((1, 3),)): QQ('7/6'),
    ((-4, 0, 0, 4), ((1, 3),)): QQ('5/8'),
    ((-4, 0, 2, 2), ((1, 3),)): QQ('7/24'),
    ((-2, 0, 0, 4), ((1, 5),)): QQ('43/1152'),
    ((-2, -2, 0, 0, 4), ((1, 1), (2, 3))): QQ('5/2'),
    ((-2, -2, -2, 0, 0, 4), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, 0, 0, 4), ((1, 1), (2, 2))): QQ('3'),
    ((-4, -2, 0, 0, 4), ((2, 2),)): QQ('1'),
    ((-2, -2, 0, 0, 4), ((1, 2), (2, 2))): QQ('41/12'),
    ((-2, -2, -2, 0, 0, 4), ((1, 1), (2, 1), (4, 1))): QQ('6'),
    ((-4, -2, 0, 0, 4), ((2, 1), (3, 1))): QQ('2'),
    ((-2, -2, -2, 0, 0, 4), ((1, 1), (4, 2))): QQ('3'),
    ((-4, -2, 0, 0, 4), ((3, 2),)): QQ('1'),
    ((-6, 0, 0, 4), ((2, 1),)): QQ('1'),
    ((-2, -2, 0, 0, 4), ((1, 4),)): QQ('19/24'),
    ((-2, 0, 2, 2), ((1, 5),)): QQ('103/5760'),
    ((-2, -2, 0, 2, 2), ((1, 1), (2, 3))): QQ('7/6'),
    ((-2, -2, 0, 2, 2), ((1, 2), (2, 2))): QQ('17/12'),
    ((-4, 0, 0, 0, 2), ((1, 2),)): QQ('1'),
    ((-2, 0, 0, 0, 0, 0), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, -2, 3, 3), ((1, 1), (2, 2))): QQ('3'),
    ((-6, -2, 3, 3), ((2, 1),)): QQ('1'),
    ((-6, -2, 3, 3), ((1, 1),)): QQ('1'),
    ((-4, -2, -2, 3, 3), ((1, 2),)): QQ('1'),
    ((-4, -4, 3, 3), ((1, 1),)): QQ('1'),
    ((-2, -2, 3, 3), ((1, 5),)): QQ('1643/5760'),
    ((-2, -2, -2, 3, 3), ((1, 1), (2, 3))): QQ('7/2'),
    ((-4, -2, 3, 3), ((2, 3),)): QQ('11/8'),
    ((-2, -2, -2, -2, 3, 3), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, 3, 3), ((1, 2), (2, 2))): QQ('59/12'),
    ((-4, -2, -2, 3, 3), ((2, 2),)): QQ('1'),
    ((-3, -3, -2, 3, 3), ((3, 2),)): QQ('1'),
    ((-4, -2, 3, 3), ((1, 1), (2, 2))): QQ('17/8'),
    ((-3, -3, -2, 3, 3), ((1, 1), (3, 1))): QQ('2'),
    ((-4, -2, -2, 3, 3), ((2, 1), (3, 1))): QQ('2'),
    ((-4, -2, -2, 3, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, 3, 3), ((1, 2), (2, 1))): QQ('13/8'),
    ((-2, -2, -2, 3, 3), ((1, 4),)): QQ('25/24'),
    ((-4, -2, 3, 3), ((1, 3),)): QQ('7/8'),
    ((-6, 3, 3), ((1, 2),)): QQ('17/24'),
    ((-2, 3, 3), ((1, 6),)): QQ('14849/2903040'),
    ((-2, -2, 3, 3), ((1, 1), (2, 4))): QQ('479/640'),
    ((-2, -2, 3, 3), ((1, 2), (2, 3))): QQ('3583/2880'),
    ((-2, -2, -2, 3, 3), ((1, 1), (2, 1), (3, 2))): QQ('37/6'),
    ((-2, -2, -2, -2, 3, 3), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-4, 3, 3), ((1, 4),)): QQ('91/640'),
    ((-5, -3, 3, 3), ((1, 1),)): QQ('1'),
    ((-3, -3, -2, 3, 3), ((1, 2),)): QQ('1'),
    ((-5, -3, 3, 3), ((2, 1),)): QQ('1'),
    ((-3, -2, 0, 3), ((3, 1),)): QQ('1'),
    ((-3, -3, -2, 3, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, 3, 3), ((1, 3),)): QQ('13/12'),
    ((-4, -2, 1, 1, 4), ((1, 4),)): QQ('7/8'),
    ((-4, -2, -2, 1, 1, 4), ((1, 3),)): QQ('1'),
    ((-4, -4, 1, 1, 4), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -3, 1, 4), ((1, 1),)): QQ('1'),
    ((-4, -4, 1, 1, 4), ((1, 2),)): QQ('1'),
    ((-4, -3, 1, 4), ((2, 1),)): QQ('1'),
    ((-4, -2, -2, 1, 1, 4), ((1, 2), (2, 1))): QQ('3'),
    ((-5, -2, 1, 4), ((2, 1),)): QQ('1'),
    ((-3, -2, -2, 1, 4), ((1, 1), (2, 1))): QQ('2'),
    ((-5, -2, 1, 4), ((1, 1),)): QQ('1'),
    ((-6, 1, 1, 4), ((1, 3),)): QQ('17/24'),
    ((-6, -2, 1, 1, 4), ((1, 2),)): QQ('1'),
    ((-2, -2, -2, -2, 1, 2, 3), ((1, 2), (2, 2))): QQ('6'),
    ((-5, -2, 2, 3), ((2, 1),)): QQ('1'),
    ((-3, -2, -2, 2, 3), ((2, 2),)): QQ('1'),
    ((-6, -2, 1, 2, 3), ((2, 2),)): QQ('1'),
    ((-3, -2, -2, 2, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, -2, 1, 2, 3), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-3, -2, -2, 2, 3), ((2, 1), (3, 1))): QQ('2'),
    ((-6, -2, 1, 2, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -2, -2, 2, 3), ((1, 2),)): QQ('1'),
    ((-4, -3, 2, 3), ((2, 1),)): QQ('1'),
    ((-5, -2, 2, 3), ((1, 1),)): QQ('1'),
    ((-4, -3, 2, 3), ((1, 1),)): QQ('1'),
    ((-6, -2, 1, 2, 3), ((1, 2),)): QQ('1'),
    ((-2, 1, 2, 3), ((1, 7),)): QQ('7877/2903040'),
    ((-2, -2, 1, 2, 3), ((1, 1), (2, 5))): QQ('193/320'),
    ((-2, -2, -2, 1, 2, 3), ((1, 5),)): QQ('7/8'),
    ((-2, -2, 1, 2, 3), ((1, 2), (2, 4))): QQ('693/640'),
    ((-4, -2, 1, 2, 3), ((2, 4),)): QQ('29/24'),
    ((-2, -2, -2, -2, 1, 2, 3), ((1, 4),)): QQ('1'),
    ((-2, -2, -2, 1, 2, 3), ((1, 1), (2, 4))): QQ('89/24'),
    ((-2, -2, -2, 1, 2, 3), ((1, 1), (2, 1), (3, 3))): QQ('59/6'),
    ((-2, -2, -2, -2, 1, 2, 3), ((1, 1), (2, 3))): QQ('4'),
    ((-4, -2, -2, 1, 2, 3), ((2, 3),)): QQ('1'),
    ((-3, -3, -2, 1, 2, 3), ((3, 3),)): QQ('1'),
    ((-3, -2, 2, 3), ((2, 3),)): QQ('7/8'),
    ((-2, -2, 1, 2, 3), ((1, 3), (2, 3))): QQ('1943/1440'),
    ((-4, -2, 1, 2, 3), ((1, 1), (2, 3))): QQ('17/6'),
    ((-3, -2, 2, 3), ((1, 1), (2, 2))): QQ('11/8'),
    ((-2, -2, -2, 1, 2, 3), ((1, 1), (2, 2), (3, 2))): QQ('49/4'),
    ((-4, -2, -2, 1, 2, 3), ((1, 1), (2, 2))): QQ('3'),
    ((-4, -2, -2, 1, 2, 3), ((2, 1), (3, 2))): QQ('3'),
    ((-2, -2, -2, -2, 1, 2, 3), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-3, -3, -2, 1, 2, 3), ((1, 1), (3, 2))): QQ('3'),
    ((-3, -2, 0, 1, 2), ((2, 2),)): QQ('1'),
    ((-3, -2, 2, 3), ((1, 2), (2, 1))): QQ('7/6'),
    ((-4, -2, -2, 1, 2, 3), ((1, 2), (2, 1))): QQ('3'),
    ((-3, -3, -2, 1, 2, 3), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-3, -2, 0, 1, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -2, 1, 2, 3), ((1, 2), (3, 1))): QQ('3'),
    ((-3, -2, 2, 3), ((1, 3),)): QQ('2/3'),
    ((-4, -2, -2, 1, 2, 3), ((1, 3),)): QQ('1'),
    ((-4, -4, 1, 2, 3), ((1, 2),)): QQ('1'),
    ((-3, -3, -2, 1, 2, 3), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -3, 0, 1, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -2, 1, 2, 3), ((1, 3),)): QQ('1'),
    ((-5, -3, 1, 2, 3), ((2, 2),)): QQ('1'),
    ((-3, -2, 0, 1, 2), ((1, 2),)): QQ('1'),
    ((-4, -2, 1, 2, 3), ((1, 2), (2, 2))): QQ('11/4'),
    ((-4, -4, 1, 2, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, 1, 2, 3), ((1, 3), (2, 1))): QQ('11/6'),
    ((-4, -2, 1, 2, 3), ((1, 4),)): QQ('17/24'),
    ((-2, -2, -2, 8), ((1, 5),)): QQ('13543/5760'),
    ((-4, -2, 8), ((2, 4),)): QQ('19543/5760'),
    ((-6, -2, -2, 8), ((1, 1),)): QQ('1'),
    ((-2, -2, -2, -2, 8), ((1, 2), (2, 2))): QQ('209/12'),
    ((-4, -2, -2, 8), ((2, 1), (3, 2))): QQ('233/24'),
    ((-6, -2, -2, 8), ((2, 1),)): QQ('1'),
    ((-4, -4, -2, 8), ((3, 1),)): QQ('1'),
    ((-5, -3, -2, 8), ((3, 1),)): QQ('1'),
    ((-4, -2, -2, -2, 8), ((2, 2),)): QQ('1'),
    ((-3, -3, -2, -2, 8), ((3, 2),)): QQ('1'),
    ((-2, -2, -2, -2, -2, 8), ((1, 1), (2, 2))): QQ('3'),
    ((-6, -2, 8), ((2, 2),)): QQ('33/8'),
    ((-4, -2, -2, 8), ((1, 1), (2, 2))): QQ('67/8'),
    ((-3, -3, -2, 8), ((1, 1), (3, 2))): QQ('71/8'),
    ((-4, -2, -2, -2, 8), ((2, 1), (3, 1))): QQ('2'),
    ((-4, -2, -2, -2, 8), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, -2, 8), ((1, 2), (2, 1))): QQ('63/8'),
    ((-4, -4, -2, 8), ((1, 1),)): QQ('1'),
    ((-4, -3, -3, 8), ((2, 1),)): QQ('1'),
    ((-3, -3, -2, -2, 8), ((1, 1), (3, 1))): QQ('2'),
    ((-2, -2, -2, -2, 8), ((1, 1), (2, 3))): QQ('71/6'),
    ((-2, -2, -2, -2, -2, 8), ((1, 3),)): QQ('1'),
    ((-4, -2, -2, -2, 8), ((1, 2),)): QQ('1'),
    ((-2, -2, -2, -2, 8), ((1, 1), (2, 1), (3, 2))): QQ('187/6'),
    ((-3, -3, -2, -2, 8), ((3, 1), (4, 1))): QQ('2'),
    ((-2, -2, -2, -2, -2, 8), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-6, -2, 8), ((1, 1), (2, 1))): QQ('17/4'),
    ((-3, -3, -2, 8), ((1, 1), (2, 1), (3, 1))): QQ('21/2'),
    ((-3, -3, -2, 8), ((1, 2), (3, 1))): QQ('26/3'),
    ((-5, -3, -2, 8), ((2, 1),)): QQ('1'),
    ((-3, -3, -2, -2, 8), ((1, 2),)): QQ('1'),
    ((-4, -3, -3, 8), ((1, 1),)): QQ('1'),
    ((-4, -2, -2, 8), ((1, 3),)): QQ('71/24'),
    ((-4, -4, 8), ((1, 1), (2, 1))): QQ('47/12'),
    ((-4, -2, -2, 8), ((1, 1), (2, 1), (3, 1))): QQ('43/4'),
    ((-2, -2, -2, -2, 8), ((1, 4),)): QQ('25/8'),
    ((-4, -2, -2, 8), ((2, 3),)): QQ('83/24'),
    ((-3, -3, -2, -2, 8), ((1, 1), (2, 1))): QQ('2'),
    ((-5, -3, -2, 8), ((1, 1),)): QQ('1'),
    ((-6, -2, 8), ((1, 2),)): QQ('67/24'),
    ((-3, -3, -2, 8), ((1, 1), (2, 2))): QQ('8'),
    ((-3, -3, -2, 8), ((1, 3),)): QQ('19/6'),
    ((-5, -3, 8), ((2, 2),)): QQ('11/3'),
    ((-4, -4, 8), ((1, 2),)): QQ('79/24'),
    ((-6, 8), ((1, 3),)): QQ('179/128'),
    ((-2, -2, 8), ((1, 6),)): QQ('1500599/2903040'),
    ((-2, -2, -2, 8), ((1, 1), (2, 4))): QQ('55811/5760'),
    ((-4, -2, 8), ((1, 1), (2, 3))): QQ('3253/480'),
    ((-3, -3, -2, 8), ((3, 3),)): QQ('27/8'),
    ((-2, -2, -2, 8), ((1, 1), (2, 1), (3, 3))): QQ('2225/96'),
    ((-2, -2, -2, 8), ((1, 2), (2, 3))): QQ('51083/2880'),
    ((-4, -2, 8), ((1, 2), (2, 2))): QQ('7267/960'),
    ((-2, -2, -2, 8), ((1, 1), (2, 2), (3, 2))): QQ('6319/192'),
    ((-2, -2, -2, -2, 8), ((1, 1), (2, 1), (3, 1), (4, 1))): QQ('39'),
    ((-4, -2, 8), ((1, 3), (2, 1))): QQ('2177/480'),
    ((-4, -2, 8), ((1, 4),)): QQ('1191/640'),
    ((-5, -3, 8), ((1, 1), (2, 1))): QQ('4'),
    ((-5, -3, 8), ((1, 2),)): QQ('3'),
    ((-2, 8), ((1, 7),)): QQ('1209151/154828800'),
    ((-2, -2, 8), ((1, 1), (2, 5))): QQ('255413/161280'),
    ((-2, -2, 8), ((1, 2), (2, 4))): QQ('107321/35840'),
    ((-2, -2, 8), ((1, 3), (2, 3))): QQ('32019/8960'),
    ((-8, 8), ((1, 1),)): QQ('21/8'),
    ((-4, 8), ((1, 5),)): QQ('7691/35840'),
    ((-2, -2, 0, 0, 0, 2), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, 0, 2, 2), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-3, -3, 0, 0, 4), ((1, 2),)): QQ('1'),
    ((-3, -3, 0, 2, 2), ((1, 2),)): QQ('1'),
    ((-4, -2, 0, 0, 4), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, 0, 0, 4), ((1, 2),)): QQ('1'),
    ((-2, -2, -2, 0, 0, 4), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-2, -2, -2, 1, 2, 3), ((1, 2), (2, 3))): QQ('27/4'),
    ((-2, -2, 1, 2, 3), ((1, 6),)): QQ('1123/5760'),
    ((-4, 1, 2, 3), ((1, 5),)): QQ('51/640'),
    ((-6, 1, 2, 3), ((1, 3),)): QQ('13/24'),
    ((-8, 1, 2, 3), ((1, 1),)): QQ('1'),
    ((-2, -2, 0, 1, 1, 2), ((1, 5),)): QQ('3/8'),
    ((-2, -2, -2, 0, 1, 1, 2), ((1, 1), (2, 3))): QQ('4'),
    ((-4, -2, 0, 1, 1, 2), ((2, 3),)): QQ('1'),
    ((-4, -2, 0, 1, 1, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-2, -2, -2, 0, 1, 1, 2), ((1, 2), (2, 2))): QQ('6'),
    ((-4, -2, 0, 1, 1, 2), ((1, 2), (2, 1))): QQ('3'),
    ((-4, -2, 0, 1, 1, 2), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, 0, 1, 1, 2), ((1, 4),)): QQ('1'),
    ((-5, -3, 1, 2, 3), ((1, 2),)): QQ('1'),
    ((-3, 2, 3), ((1, 4),)): QQ('7/120'),
    ((-4, -2, 0, 0, 1, 3), ((1, 3),)): QQ('1'),
    ((-5, 2, 3), ((1, 2),)): QQ('1/2'),
    ((-2, 0, 0, 1, 3), ((1, 6),)): QQ('83/5760'),
    ((-2, -2, 0, 0, 1, 3), ((1, 1), (2, 4))): QQ('49/24'),
    ((-2, -2, -2, 0, 0, 1, 3), ((1, 4),)): QQ('1'),
    ((-2, -2, 0, 0, 1, 3), ((1, 2), (2, 3))): QQ('41/12'),
    ((-4, -2, 0, 0, 1, 3), ((2, 3),)): QQ('1'),
    ((-2, -2, -2, 0, 0, 1, 3), ((1, 1), (2, 3))): QQ('4'),
    ((-4, -2, 0, 0, 1, 3), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -2, 0, 0, 3), ((2, 2),)): QQ('1'),
    ((-4, -2, 0, 0, 1, 3), ((1, 2), (2, 1))): QQ('3'),
    ((-2, -2, 0, 0, 1, 3), ((1, 5),)): QQ('13/24'),
    ((-6, 0, 1, 1, 2), ((1, 2),)): QQ('1'),
    ((-4, 0, 1, 1, 2), ((1, 4),)): QQ('5/24'),
    ((-5, -3, 1, 2, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-5, 0, 1, 2), ((1, 1),)): QQ('1'),
    ((-2, -2, -2, -2, 1, 2, 3), ((1, 1), (2, 1), (3, 1), (4, 1))): QQ('24'),
    ((-2, -2, 0, 0, 0, 1, 1), ((1, 4),)): QQ('1'),
    ((-2, 0, 1, 1, 2), ((1, 6),)): QQ('43/5760'),
    ((-2, -2, 0, 1, 1, 2), ((1, 1), (2, 4))): QQ('29/24'),
    ((-2, -2, 0, 1, 1, 2), ((1, 2), (2, 3))): QQ('7/4'),
    ((-2, -2, -2, 0, 1, 1, 2), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-4, 0, 0, 1, 3), ((1, 4),)): QQ('3/8'),
    ((-4, 0, 0, 0, 1, 1), ((1, 3),)): QQ('1'),
    ((-2, 0, 0, 0, 1, 1), ((1, 5),)): QQ('1/24'),
    ((-2, -2, 0, 0, 0, 1, 1), ((1, 1), (2, 3))): QQ('4'),
    ((-2, -2, 0, 0, 0, 1, 1), ((1, 2), (2, 2))): QQ('6'),
    ((-6, 0, 0, 1, 3), ((1, 2),)): QQ('1'),
    ((-3, -3, 1, 2, 3), ((1, 4),)): QQ('11/12'),
    ((-3, 0, 0, 0, 1), ((1, 2),)): QQ('1'),
    ((-3, 0, 1, 2), ((1, 3),)): QQ('1/6'),
    ((-3, -2, 0, 0, 3), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -2, 0, 0, 3), ((1, 2),)): QQ('1'),
    ((-5, 0, 0, 3), ((1, 1),)): QQ('1'),
    ((-3, -3, 0, 0, 1, 3), ((1, 3),)): QQ('1'),
    ((-3, 0, 0, 3), ((1, 3),)): QQ('1/3'),
    ((-2, -2, -2, 0, 0, 1, 3), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-2, -2, -2, 0, 0, 1, 3), ((1, 2), (2, 2))): QQ('6'),
    ((-3, -3, 0, 1, 1, 2), ((1, 3),)): QQ('1'),
    ((-4, 1, 1, 4), ((1, 5),)): QQ('59/640'),
    ((-2, -2, -2, 1, 1, 4), ((1, 5),)): QQ('25/24'),
    ((-4, -2, 1, 1, 4), ((2, 4),)): QQ('11/8'),
    ((-3, -2, 1, 4), ((1, 1), (2, 2))): QQ('15/8'),
    ((-3, -2, -2, 1, 4), ((2, 2),)): QQ('1'),
    ((-2, -2, -2, -2, 1, 1, 4), ((1, 2), (2, 2))): QQ('6'),
    ((-4, -2, -2, 1, 1, 4), ((2, 1), (3, 2))): QQ('3'),
    ((-6, -2, 1, 1, 4), ((2, 2),)): QQ('1'),
    ((-4, -2, -2, 1, 1, 4), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -3, -2, 1, 1, 4), ((1, 1), (3, 2))): QQ('3'),
    ((-3, -2, 1, 4), ((1, 2), (2, 1))): QQ('5/3'),
    ((-6, -2, 1, 1, 4), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -2, 1, 1, 4), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-3, -3, -2, 1, 1, 4), ((1, 2), (3, 1))): QQ('3'),
    ((-3, -2, -2, 1, 4), ((1, 2),)): QQ('1'),
    ((-3, -2, 1, 4), ((1, 3),)): QQ('5/6'),
    ((-3, -3, -2, 1, 1, 4), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -3, -2, 1, 1, 4), ((1, 3),)): QQ('1'),
    ((-5, -3, 1, 1, 4), ((2, 2),)): QQ('1'),
    ((-2, -2, 1, 1, 4), ((1, 6),)): QQ('271/1152'),
    ((-2, -2, -2, 1, 1, 4), ((1, 1), (2, 4))): QQ('109/24'),
    ((-2, -2, -2, -2, 1, 1, 4), ((1, 4),)): QQ('1'),
    ((-4, -2, 1, 1, 4), ((1, 1), (2, 3))): QQ('7/2'),
    ((-4, -2, -2, 1, 1, 4), ((2, 3),)): QQ('1'),
    ((-3, -2, 1, 4), ((2, 3),)): QQ('25/24'),
    ((-3, -3, -2, 1, 1, 4), ((3, 3),)): QQ('1'),
    ((-2, -2, -2, -2, 1, 1, 4), ((1, 1), (2, 3))): QQ('4'),
    ((-2, -2, -2, 1, 1, 4), ((1, 1), (2, 1), (3, 3))): QQ('79/6'),
    ((-2, -2, -2, 1, 1, 4), ((1, 2), (2, 3))): QQ('101/12'),
    ((-4, -2, 1, 1, 4), ((1, 2), (2, 2))): QQ('15/4'),
    ((-2, -2, -2, -2, 1, 1, 4), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-2, -2, -2, 1, 1, 4), ((1, 1), (2, 2), (3, 2))): QQ('69/4'),
    ((-4, -2, -2, 1, 1, 4), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-3, -2, -2, 1, 4), ((2, 1), (3, 1))): QQ('2'),
    ((-4, -2, 1, 1, 4), ((1, 3), (2, 1))): QQ('5/2'),
    ((-2, -2, -2, -2, 1, 1, 4), ((1, 1), (2, 1), (3, 1), (4, 1))): QQ('24'),
    ((-5, -3, 1, 1, 4), ((1, 1), (2, 1))): QQ('2'),
    ((-5, -3, 1, 1, 4), ((1, 2),)): QQ('1'),
    ((-8, 1, 1, 4), ((1, 1),)): QQ('1'),
    ((-2, 1, 1, 4), ((1, 7),)): QQ('8801/2903040'),
    ((-2, -2, 1, 1, 4), ((1, 1), (2, 5))): QQ('2113/2880'),
    ((-2, -2, 1, 1, 4), ((1, 2), (2, 4))): QQ('7157/5760'),
    ((-2, -2, 1, 1, 4), ((1, 3), (2, 3))): QQ('2143/1440'),
    ((-3, -3, 1, 1, 4), ((1, 4),)): QQ('13/12'),
    ((-3, 1, 4), ((1, 4),)): QQ('23/360'),
    ((-5, 1, 4), ((1, 2),)): QQ('2/3'),
    ((-2, -2, -2, -2, 2, 2, 2), ((1, 2), (2, 2))): QQ('6'),
    ((-6, -2, 2, 2, 2), ((2, 2),)): QQ('1'),
    ((-6, -2, 2, 2, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, -2, 2, 2, 2), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-2, -2, 2, 2, 2), ((1, 6),)): QQ('983/5760'),
    ((-2, -2, -2, 2, 2, 2), ((1, 1), (2, 4))): QQ('79/24'),
    ((-4, -2, 2, 2, 2), ((2, 4),)): QQ('9/8'),
    ((-2, -2, -2, -2, 2, 2, 2), ((1, 4),)): QQ('1'),
    ((-4, -2, 2, 2, 2), ((1, 1), (2, 3))): QQ('5/2'),
    ((-4, -2, -2, 2, 2, 2), ((2, 3),)): QQ('1'),
    ((-3, -3, -2, 2, 2, 2), ((3, 3),)): QQ('1'),
    ((-2, -2, -2, -2, 2, 2, 2), ((1, 1), (2, 3))): QQ('4'),
    ((-2, -2, -2, 2, 2, 2), ((1, 2), (2, 3))): QQ('71/12'),
    ((-4, -2, -2, 2, 2, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-4, -2, 2, 2, 2), ((1, 2), (2, 2))): QQ('9/4'),
    ((-3, -3, -2, 2, 2, 2), ((1, 1), (3, 2))): QQ('3'),
    ((-4, -2, -2, 2, 2, 2), ((2, 1), (3, 2))): QQ('3'),
    ((-4, -2, -2, 2, 2, 2), ((1, 2), (2, 1))): QQ('3'),
    ((-4, -2, 2, 2, 2), ((1, 3), (2, 1))): QQ('3/2'),
    ((-4, -4, 2, 2, 2), ((1, 2),)): QQ('1'),
    ((-3, -3, -2, 2, 2, 2), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-3, -3, -2, 2, 2, 2), ((1, 2), (3, 1))): QQ('3'),
    ((-4, -2, -2, 2, 2, 2), ((1, 3),)): QQ('1'),
    ((-4, -4, 2, 2, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-6, -2, 2, 2, 2), ((1, 2),)): QQ('1'),
    ((-4, -2, 2, 2, 2), ((1, 4),)): QQ('5/8'),
    ((-3, -3, -2, 2, 2, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -3, 0, 2, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -2, 2, 2, 2), ((1, 3),)): QQ('1'),
    ((-5, -3, 2, 2, 2), ((2, 2),)): QQ('1'),
    ((-2, -2, -2, 2, 2, 2), ((1, 5),)): QQ('19/24'),
    ((-4, 2, 2, 2), ((1, 5),)): QQ('133/1920'),
    ((-8, 2, 2, 2), ((1, 1),)): QQ('1'),
    ((-6, 2, 2, 2), ((1, 3),)): QQ('11/24'),
    ((-2, 2, 2, 2), ((1, 7),)): QQ('8591/2903040'),
    ((-2, -2, 2, 2, 2), ((1, 1), (2, 5))): QQ('1477/2880'),
    ((-2, -2, 2, 2, 2), ((1, 2), (2, 4))): QQ('5417/5760'),
    ((-2, -2, -2, 2, 2, 2), ((1, 1), (2, 1), (3, 3))): QQ('49/6'),
    ((-2, -2, 2, 2, 2), ((1, 3), (2, 3))): QQ('1723/1440'),
    ((-2, -2, -2, 2, 2, 2), ((1, 1), (2, 2), (3, 2))): QQ('39/4'),
    ((-2, -2, 0, 0, 0, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-2, -2, -2, -2, 2, 2, 2), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-2, 0, 0, 2, 2), ((1, 6),)): QQ('103/5760'),
    ((-2, -2, 0, 0, 2, 2), ((1, 1), (2, 4))): QQ('13/8'),
    ((-2, -2, -2, 0, 0, 2, 2), ((1, 4),)): QQ('1'),
    ((-2, -2, -2, 0, 0, 2, 2), ((1, 1), (2, 3))): QQ('4'),
    ((-4, -2, 0, 0, 2, 2), ((2, 3),)): QQ('1'),
    ((-2, -2, 0, 0, 2, 2), ((1, 2), (2, 3))): QQ('31/12'),
    ((-4, -2, 0, 0, 2, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-2, -2, -2, 0, 0, 2, 2), ((1, 2), (2, 2))): QQ('6'),
    ((-4, -2, 0, 0, 2, 2), ((1, 2), (2, 1))): QQ('3'),
    ((-2, -2, -2, 0, 0, 2, 2), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-4, -2, 0, 0, 2, 2), ((1, 3),)): QQ('1'),
    ((-2, -2, 0, 0, 2, 2), ((1, 5),)): QQ('11/24'),
    ((-6, 0, 0, 2, 2), ((1, 2),)): QQ('1'),
    ((-5, -3, 2, 2, 2), ((1, 2),)): QQ('1'),
    ((-2, 0, 0, 0, 0, 2), ((1, 5),)): QQ('1/8'),
    ((-3, -3, 2, 2, 2), ((1, 4),)): QQ('5/6'),
    ((-5, -3, 2, 2, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-4, 0, 0, 0, 0, 2), ((1, 3),)): QQ('1'),
    ((-4, 0, 0, 2, 2), ((1, 4),)): QQ('7/24'),
    ((-2, 0, 0, 0, 0, 0, 0), ((1, 4),)): QQ('1'),
    ((-2, -2, -2, -2, 2, 2, 2), ((1, 1), (2, 1), (3, 1), (4, 1))): QQ('24'),
    ((-3, -3, 0, 0, 2, 2), ((1, 3),)): QQ('1'),
    ((-2, -2, 0, 0, 0, 0, 2), ((1, 4),)): QQ('1'),
    ((-6, 0, 6), ((1, 2),)): QQ('35/24'),
    ((-3, -3, 8), ((1, 4),)): QQ('99/40'),
    ((-4, 0, 6), ((1, 4),)): QQ('231/640'),
    ((-4, -2, 0, 6), ((1, 3),)): QQ('13/8'),
    ((-4, -2, -2, 0, 6), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -4, 0, 6), ((1, 1),)): QQ('1'),
    ((-4, -2, -2, 0, 6), ((2, 1), (4, 1))): QQ('2'),
    ((-6, -2, 0, 6), ((3, 1),)): QQ('1'),
    ((-4, -4, 0, 6), ((3, 1),)): QQ('1'),
    ((-2, -2, 0, 6), ((1, 5),)): QQ('3623/5760'),
    ((-2, -2, -2, 0, 6), ((1, 1), (2, 3))): QQ('13/2'),
    ((-2, -2, -2, -2, 0, 6), ((1, 3),)): QQ('1'),
    ((-4, -2, 0, 6), ((2, 3),)): QQ('17/8'),
    ((-2, -2, -2, 0, 6), ((1, 1), (2, 2), (4, 1))): QQ('113/6'),
    ((-2, -2, -2, -2, 0, 6), ((1, 2), (5, 1))): QQ('3'),
    ((-4, -2, 0, 6), ((2, 2), (3, 1))): QQ('51/8'),
    ((-2, -2, -2, -2, 0, 6), ((1, 1), (2, 2))): QQ('3'),
    ((-4, -2, -2, 0, 6), ((2, 2),)): QQ('1'),
    ((-4, -2, 0, 6), ((1, 1), (2, 2))): QQ('35/8'),
    ((-3, -3, -2, 0, 6), ((3, 2),)): QQ('1'),
    ((-6, -2, 0, 6), ((2, 1),)): QQ('1'),
    ((-2, -2, -2, 0, 6), ((1, 1), (2, 1), (4, 2))): QQ('79/4'),
    ((-3, -3, -2, 0, 6), ((4, 2),)): QQ('1'),
    ((-4, -2, -2, 0, 6), ((4, 2),)): QQ('1'),
    ((-2, -2, -2, -2, 0, 6), ((1, 1), (5, 2))): QQ('3'),
    ((-4, -2, 0, 6), ((2, 1), (3, 2))): QQ('13/2'),
    ((-5, -3, 0, 6), ((3, 1),)): QQ('1'),
    ((-6, -2, 0, 6), ((1, 1),)): QQ('1'),
    ((-5, -3, 0, 6), ((2, 1),)): QQ('1'),
    ((-2, -2, -2, -2, 0, 6), ((1, 1), (2, 1), (5, 1))): QQ('6'),
    ((-3, -3, -2, 0, 6), ((1, 1), (3, 1))): QQ('2'),
    ((-4, -2, -2, 0, 6), ((2, 1), (3, 1))): QQ('2'),
    ((-4, -2, 0, 6), ((1, 2), (2, 1))): QQ('31/8'),
    ((-3, -3, -2, 0, 6), ((1, 1), (4, 1))): QQ('2'),
    ((-4, -2, -2, 0, 6), ((1, 1), (4, 1))): QQ('2'),
    ((-2, -2, -2, 0, 6), ((1, 1), (4, 3))): QQ('15/2'),
    ((-4, -2, 0, 6), ((3, 3),)): QQ('55/24'),
    ((-2, -2, -2, -2, 0, 6), ((5, 3),)): QQ('1'),
    ((-6, 0, 6), ((2, 2),)): QQ('35/12'),
    ((-6, 0, 6), ((1, 1), (2, 1))): QQ('35/12'),
    ((-3, -3, -2, 0, 6), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -2, 0, 6), ((1, 2),)): QQ('1'),
    ((-4, -2, 0, 6), ((1, 1), (3, 2))): QQ('11/2'),
    ((-3, -3, -2, 0, 6), ((3, 1), (4, 1))): QQ('2'),
    ((-2, 0, 6), ((1, 6),)): QQ('6449/414720'),
    ((-2, -2, 0, 6), ((1, 1), (2, 4))): QQ('1259/640'),
    ((-2, -2, -2, 0, 6), ((1, 4),)): QQ('43/24'),
    ((-2, -2, 0, 6), ((1, 2), (2, 3))): QQ('9163/2880'),
    ((-2, -2, -2, 0, 6), ((1, 1), (2, 1), (3, 1), (4, 1))): QQ('23'),
    ((-4, -2, 0, 6), ((1, 1), (2, 1), (3, 1))): QQ('27/4'),
    ((-4, -2, 0, 6), ((1, 2), (3, 1))): QQ('39/8'),
    ((-5, -3, 0, 6), ((1, 1),)): QQ('1'),
    ((-4, -2, -2, 0, 6), ((1, 2),)): QQ('1'),
    ((-3, -3, 0, 6), ((1, 3),)): QQ('11/6'),
    ((-2, -2, -2, -2, 0, 6), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-2, -2, -2, 0, 6), ((1, 1), (2, 1), (3, 2))): QQ('91/6'),
    ((-2, -2, -2, 0, 6), ((1, 2), (2, 2))): QQ('113/12'),
    ((-2, 0, 0, 0, 0, 0), ((1, 2), (2, 1))): QQ('3'),
    ((-2, 0, 0, 0, 0, 0), ((1, 1), (2, 2))): QQ('3'),
    ((-2, 0, 0, 0, 0, 0), ((2, 3),)): QQ('1'),
    ((0, 0, 0, 0, 0), ((1, 5),)): QQ('1/24'),
    ((-4, -4, 1, 1, 2, 2), ((1, 3),)): QQ('1'),
    ((-4, -3, 1, 2, 2), ((1, 2),)): QQ('1'),
    ((-4, -2, 1, 1, 2, 2), ((1, 5),)): QQ('13/24'),
    ((-4, -2, -2, 1, 1, 2, 2), ((1, 4),)): QQ('1'),
    ((-4, -4, 1, 1, 2, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-2, -2, -2, 1, 1, 2, 2), ((1, 6),)): QQ('17/24'),
    ((-4, -2, 1, 1, 2, 2), ((1, 1), (2, 4))): QQ('77/24'),
    ((-3, -2, 1, 2, 2), ((2, 4),)): QQ('17/24'),
    ((-4, -2, -2, 1, 1, 2, 2), ((2, 4),)): QQ('1'),
    ((-3, -3, -2, 1, 1, 2, 2), ((3, 4),)): QQ('1'),
    ((-3, -3, -2, 1, 1, 2, 2), ((1, 1), (3, 3))): QQ('4'),
    ((-3, -2, -2, 1, 2, 2), ((2, 3),)): QQ('1'),
    ((-6, -2, 1, 1, 2, 2), ((2, 3),)): QQ('1'),
    ((-2, -2, -2, -2, 1, 1, 2, 2), ((1, 2), (2, 3))): QQ('10'),
    ((-4, -2, -2, 1, 1, 2, 2), ((2, 1), (3, 3))): QQ('4'),
    ((-4, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 3))): QQ('4'),
    ((-3, -2, 1, 2, 2), ((1, 1), (2, 3))): QQ('19/12'),
    ((-3, -3, -2, 1, 1, 2, 2), ((1, 2), (3, 2))): QQ('6'),
    ((-5, -2, 1, 2, 2), ((2, 2),)): QQ('1'),
    ((-3, -3, -2, 1, 1, 2, 2), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-3, -2, -2, 1, 2, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-6, -2, 1, 1, 2, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -2, 1, 2, 2), ((1, 2), (2, 2))): QQ('37/24'),
    ((-4, -2, -2, 1, 1, 2, 2), ((1, 2), (2, 2))): QQ('6'),
    ((-5, -2, 1, 2, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -2, 1, 1, 2, 2), ((1, 1), (2, 2), (3, 1))): QQ('12'),
    ((-3, -3, -2, 1, 1, 2, 2), ((1, 3), (3, 1))): QQ('4'),
    ((-4, -3, 1, 2, 2), ((2, 2),)): QQ('1'),
    ((-3, -2, -2, 1, 2, 2), ((1, 2), (2, 1))): QQ('3'),
    ((-6, -2, 1, 1, 2, 2), ((1, 2), (2, 1))): QQ('3'),
    ((-3, -2, 1, 2, 2), ((1, 3), (2, 1))): QQ('7/6'),
    ((-4, -3, 1, 2, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, -2, 1, 1, 2, 2), ((1, 3), (2, 1))): QQ('4'),
    ((-2, -2, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 4))): QQ('5'),
    ((-4, -2, -2, 1, 1, 2, 2), ((1, 2), (2, 1), (3, 1))): QQ('12'),
    ((-3, -2, -2, 1, 2, 2), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-3, -3, -2, 1, 1, 2, 2), ((1, 1), (2, 3))): QQ('4'),
    ((-3, -3, 0, 1, 1, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -3, -2, 1, 1, 2, 2), ((1, 2), (2, 2))): QQ('6'),
    ((-3, -3, -2, 1, 1, 2, 2), ((1, 4),)): QQ('1'),
    ((-5, -3, 1, 1, 2, 2), ((2, 3),)): QQ('1'),
    ((-3, -2, -2, 1, 2, 2), ((1, 3),)): QQ('1'),
    ((-5, -2, 1, 2, 2), ((1, 2),)): QQ('1'),
    ((-6, -2, 1, 1, 2, 2), ((1, 3),)): QQ('1'),
    ((-3, -2, 1, 2, 2), ((1, 4),)): QQ('1/2'),
    ((-2, -2, -2, -2, 1, 1, 2, 2), ((1, 5),)): QQ('1'),
    ((-2, -2, -2, 0, 2, 2), ((1, 2), (4, 1))): QQ('3'),
    ((-4, -2, 0, 2, 2), ((1, 1), (3, 1))): QQ('2'),
    ((-4, 1, 1, 2, 2), ((1, 6),)): QQ('259/5760'),
    ((-2, 1, 1, 2), ((1, 2), (2, 3))): QQ('137/720'),
    ((-2, -2, -2, 0, 2, 2), ((1, 1), (2, 1), (4, 1))): QQ('6'),
    ((-4, -2, 0, 2, 2), ((2, 1), (3, 1))): QQ('2'),
    ((0, 0, 0, 0, 0), ((1, 2), (2, 3))): QQ('7/24'),
    ((0, 0, 0, 0, 0), ((1, 1), (2, 4))): QQ('1/6'),
    ((-2, 0, 0, 0, 0, 0), ((2, 1), (3, 2))): QQ('3'),
    ((-2, 0, 0, 0, 0, 0), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-4, 0, 0, 0, 2), ((1, 1), (2, 1))): QQ('2'),
    ((-4, 0, 0, 0, 2), ((2, 2),)): QQ('1'),
    ((-2, -2, 0, 0, 0, 2), ((1, 1), (2, 1), (3, 1))): QQ('6'),
    ((-2, -2, 0, 0, 0, 2), ((1, 2), (3, 1))): QQ('3'),
    ((-2, -2, 0, 0, 0, 2), ((1, 1), (3, 2))): QQ('3'),
    ((-2, -2, 0, 0, 0, 2), ((3, 3),)): QQ('1'),
    ((0, 0, 0, 0, 0), ((1, 1), (2, 2), (3, 2))): QQ('2/3'),
    ((0, 0, 0, 0, 0), ((1, 1), (2, 1), (3, 3))): QQ('1/2'),
    ((-2, 0, 0, 0, 0, 0), ((2, 1), (3, 1), (4, 1))): QQ('6'),
    ((-2, 0, 0, 0, 2), ((1, 3), (2, 1))): QQ('1/2'),
    ((-2, 0, 0, 0, 2), ((1, 2), (2, 2))): QQ('7/8'),
    ((-2, 0, 0, 0, 2), ((1, 1), (2, 3))): QQ('3/4'),
    ((-2, 0, 0, 0, 2), ((2, 4),)): QQ('1/4'),
    ((0, 0, 0, 2), ((1, 6),)): QQ('11/1920'),
    ((-8, 1, 1, 2, 2), ((1, 2),)): QQ('1'),
    ((-2, 0, 0, 0, 2), ((1, 2), (2, 1), (3, 1))): QQ('3/2'),
    ((-2, 0, 0, 0, 2), ((1, 1), (2, 1), (3, 2))): QQ('2'),
    ((-4, 0, 0, 0, 2), ((2, 1), (3, 1))): QQ('2'),
    ((-2, 0, 0, 0, 2), ((2, 2), (3, 2))): QQ('3/2'),
    ((-2, 0, 0, 0, 2), ((2, 1), (3, 3))): QQ('1'),
    ((-2, -2, 0, 0, 0, 2), ((3, 1), (4, 2))): QQ('3'),
    ((-2, -2, 0, 0, 0, 2), ((1, 1), (3, 1), (4, 1))): QQ('6'),
    ((0, 0, 0, 2), ((1, 3), (2, 3))): QQ('7/80'),
    ((0, 0, 0, 2), ((1, 2), (2, 4))): QQ('1/15'),
    ((0, 0, 0, 2), ((1, 1), (2, 5))): QQ('11/384'),
    ((0, 0, 0, 0, 0), ((1, 1), (2, 1), (3, 1), (4, 2))): QQ('1'),
    ((-6, 0, 2, 2), ((2, 1),)): QQ('1'),
    ((-2, -2, -2, 0, 2, 2), ((1, 1), (4, 2))): QQ('3'),
    ((-4, -2, 0, 2, 2), ((3, 2),)): QQ('1'),
    ((-2, -2, -2, 0, 2, 2), ((4, 3),)): QQ('1'),
    ((-2, 0, 2, 2), ((1, 4), (2, 1))): QQ('103/1152'),
    ((-2, -2, 0, 2, 2), ((1, 1), (2, 2), (3, 1))): QQ('17/6'),
    ((-2, 0, 2, 2), ((1, 3), (2, 2))): QQ('2/9'),
    ((-2, -2, 0, 2, 2), ((1, 1), (2, 1), (3, 2))): QQ('15/4'),
    ((-3, -3, 0, 2, 2), ((1, 1), (3, 1))): QQ('2'),
    ((-3, -3, 0, 2, 2), ((3, 2),)): QQ('1'),
    ((-2, 0, 2, 2), ((1, 2), (2, 3))): QQ('167/576'),
    ((-2, -2, 0, 2, 2), ((1, 1), (3, 3))): QQ('13/6'),
    ((-2, 0, 0, 0, 2), ((1, 1), (2, 1), (3, 1), (4, 1))): QQ('3'),
    ((-2, -2, 0, 2, 2), ((1, 3), (3, 1))): QQ('11/6'),
    ((-2, -2, 0, 2, 2), ((1, 2), (3, 2))): QQ('23/8'),
    ((-4, 0, 2, 2), ((1, 2), (2, 1))): QQ('7/8'),
    ((-4, 0, 2, 2), ((1, 1), (2, 2))): QQ('3/2'),
    ((-4, 0, 2, 2), ((2, 3),)): QQ('23/24'),
    ((-2, 0, 2, 2), ((1, 1), (2, 4))): QQ('31/144'),
    ((-2, 0, 0, 0, 2), ((2, 1), (3, 1), (4, 2))): QQ('3'),
    ((-2, -2, 0, 0, 0, 2), ((3, 1), (4, 1), (5, 1))): QQ('6'),
    ((-2, -2, 0, 2, 2), ((3, 4),)): QQ('5/8'),
    ((-2, 0, 2, 2), ((2, 5),)): QQ('461/5760'),
    ((0, 0, 0, 2), ((1, 1), (2, 2), (3, 3))): QQ('7/32'),
    ((0, 0, 0, 2), ((1, 1), (2, 1), (3, 4))): QQ('11/96'),
    ((0, 0, 0, 0, 0), ((1, 1), (2, 1), (3, 1), (4, 1), (5, 1))): QQ('1'),
    ((0, 0, 0, 2), ((1, 2), (2, 2), (3, 2))): QQ('5/16'),
    ((0, 2, 2), ((1, 7),)): QQ('2669/2903040'),
    ((-2, 1, 1, 2, 2), ((1, 8),)): QQ('853/580608'),
    ((-2, -2, 1, 1, 2, 2), ((1, 1), (2, 6))): QQ('2717/5760'),
    ((-2, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 5))): QQ('43/12'),
    ((-4, -2, 1, 1, 2, 2), ((2, 5),)): QQ('25/24'),
    ((-2, -2, 1, 1, 2, 2), ((1, 2), (2, 5))): QQ('5351/5760'),
    ((-2, -2, -2, 1, 1, 2, 2), ((1, 2), (2, 4))): QQ('191/24'),
    ((-2, -2, 1, 1, 2, 2), ((1, 3), (2, 4))): QQ('2603/1920'),
    ((-2, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 2), (3, 3))): QQ('113/6'),
    ((-2, -2, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 1), (3, 3))): QQ('20'),
    ((-2, -2, -2, 1, 1, 2, 2), ((1, 3), (2, 3))): QQ('61/6'),
    ((-4, -2, 1, 1, 2, 2), ((1, 2), (2, 3))): QQ('47/12'),
    ((-4, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 1), (3, 2))): QQ('12'),
    ((-3, -2, -2, 1, 2, 2), ((2, 1), (3, 2))): QQ('3'),
    ((-2, -2, -2, 1, 1, 2, 2), ((1, 2), (2, 2), (3, 2))): QQ('87/4'),
    ((-4, -2, -2, 1, 1, 2, 2), ((2, 2), (3, 2))): QQ('6'),
    ((-2, -2, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 2), (3, 2))): QQ('30'),
    ((-4, -2, 1, 1, 2, 2), ((1, 3), (2, 2))): QQ('35/12'),
    ((-2, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 1), (3, 4))): QQ('49/4'),
    ((-4, -2, 1, 1, 2, 2), ((1, 4), (2, 1))): QQ('41/24'),
    ((-2, -2, 1, 1, 2, 2), ((1, 7),)): QQ('763/5760'),
    ((-6, 1, 1, 2, 2), ((1, 4),)): QQ('3/8'),
    ((-7, 1, 2, 2), ((1, 1),)): QQ('1'),
    ((-2, -2, -2, 0, 0, 1, 1, 2), ((1, 1), (2, 4))): QQ('5'),
    ((-3, -2, 0, 0, 1, 2), ((2, 3),)): QQ('1'),
    ((-3, -2, 0, 0, 1, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-3, -2, 0, 0, 1, 2), ((1, 2), (2, 1))): QQ('3'),
    ((-3, -2, 0, 0, 1, 2), ((1, 3),)): QQ('1'),
    ((-5, 1, 2, 2), ((1, 3),)): QQ('1/3'),
    ((-5, -3, 1, 1, 2, 2), ((1, 1), (2, 2))): QQ('3'),
    ((-5, -3, 1, 1, 2, 2), ((1, 2), (2, 1))): QQ('3'),
    ((-5, -3, 1, 1, 2, 2), ((1, 3),)): QQ('1'),
    ((-4, 0, 0, 0, 0, 1, 1), ((1, 4),)): QQ('1'),
    ((-3, -3, 1, 1, 2, 2), ((1, 5),)): QQ('3/4'),
    ((-3, 1, 2, 2), ((1, 5),)): QQ('11/360'),
    ((-2, 0, 0, 1, 1, 2), ((1, 7),)): QQ('43/5760'),
    ((-2, -2, 0, 0, 1, 1, 2), ((1, 1), (2, 5))): QQ('19/12'),
    ((-2, -2, -2, 0, 0, 1, 1, 2), ((1, 5),)): QQ('1'),
    ((-2, -2, 0, 0, 1, 1, 2), ((1, 2), (2, 4))): QQ('71/24'),
    ((-4, -2, 0, 0, 1, 1, 2), ((2, 4),)): QQ('1'),
    ((-4, -2, 0, 0, 1, 1, 2), ((1, 1), (2, 3))): QQ('4'),
    ((-2, -2, 0, 0, 1, 1, 2), ((1, 3), (2, 3))): QQ('7/2'),
    ((-2, -2, -2, 0, 0, 1, 1, 2), ((1, 2), (2, 3))): QQ('10'),
    ((-4, -2, 0, 0, 1, 1, 2), ((1, 2), (2, 2))): QQ('6'),
    ((-2, -2, -2, 0, 0, 1, 1, 2), ((1, 1), (2, 2), (3, 2))): QQ('30'),
    ((-4, -2, 0, 0, 1, 1, 2), ((1, 3), (2, 1))): QQ('4'),
    ((-2, -2, -2, 0, 0, 1, 1, 2), ((1, 1), (2, 1), (3, 3))): QQ('20'),
    ((-4, -2, 0, 0, 1, 1, 2), ((1, 4),)): QQ('1'),
    ((-2, -2, 0, 0, 1, 1, 2), ((1, 6),)): QQ('3/8'),
    ((-4, 0, 0, 1, 1, 2), ((1, 5),)): QQ('5/24'),
    ((-2, 0, 0, 0, 0, 1, 1), ((1, 6),)): QQ('1/24'),
    ((-2, -2, 0, 0, 0, 0, 1, 1), ((1, 1), (2, 4))): QQ('5'),
    ((-2, -2, 0, 0, 0, 0, 1, 1), ((1, 2), (2, 3))): QQ('10'),
    ((-2, -2, 0, 0, 0, 0, 1, 1), ((1, 5),)): QQ('1'),
    ((-6, 0, 0, 1, 1, 2), ((1, 3),)): QQ('1'),
    ((-2, -2, -2, -2, 1, 1, 2, 2), ((1, 1), (2, 1), (3, 1), (4, 2))): QQ('60'),
    ((-5, 0, 0, 1, 2), ((1, 2),)): QQ('1'),
    ((-3, 0, 0, 1, 2), ((1, 4),)): QQ('1/6'),
    ((-3, -3, 0, 0, 1, 1, 2), ((1, 4),)): QQ('1'),
    ((-3, 0, 0, 0, 0, 1), ((1, 3),)): QQ('1'),
    ((-11, 1, 4, 4), ((3, 1),)): QQ('1'),
    ((-9, 1, 3, 3), ((3, 1),)): QQ('1'),
    ((-15, 15), ((1, 1),)): QQ('28/3'),
    ((-6, -4, 1, 7), ((2, 1),)): QQ('1'),
    ((-10, 0, 1, 7), ((1, 1),)): QQ('1'),
    ((-7, -3, 1, 7), ((1, 1),)): QQ('1'),
    ((-11, 1, 3, 5), ((3, 1),)): QQ('1'),
    ((-6, -5, 1, 8), ((1, 1),)): QQ('1'),
    ((-9, 9), ((1, 1),)): QQ('10/3'),
    ((-6, -4, 1, 7), ((1, 1),)): QQ('1'),
    ((-7, 1, 1, 3), ((2, 1),)): QQ('1'),
    ((-10, 1, 3, 4), ((1, 1),)): QQ('1'),
    ((-9, 0, 1, 6), ((2, 1),)): QQ('1'),
    ((-13, 13), ((1, 1),)): QQ('7'),
    ((-8, -2, 1, 7), ((2, 1),)): QQ('1'),
    ((-7, -5, 1, 9), ((2, 1),)): QQ('1'),
    ((-5, 0, 1, 2), ((2, 1),)): QQ('1'),
    ((-7, 0, 1, 4), ((3, 1),)): QQ('1'),
    ((-11, 1, 1, 7), ((1, 1),)): QQ('1'),
    ((-9, 9), ((2, 1),)): QQ('10/3'),
    ((-6, -5, 1, 8), ((2, 1),)): QQ('1'),
    ((-8, -4, 1, 9), ((1, 1),)): QQ('1'),
    ((-10, 1, 3, 4), ((3, 1),)): QQ('1'),
    ((-6, 0, 1, 3), ((4, 1),)): QQ('1'),
    ((-19, 19), ((1, 1),)): QQ('15'),
    ((-11, 0, 1, 8), ((1, 1),)): QQ('1'),
    ((-8, 0, 1, 5), ((1, 1),)): QQ('1'),
    ((-7, -2, 1, 6), ((2, 1),)): QQ('1'),
    ((-11, 1, 3, 5), ((4, 1),)): QQ('1'),
    ((-7, 7), ((2, 1),)): QQ('2'),
    ((-9, 1, 8), ((1, 2),)): QQ('8/3'),
    ((-10, 1, 2, 5), ((1, 1),)): QQ('1'),
    ((-17, -13, 5, 23), ((1, 1),)): QQ('1'),
    ((-11, 1, 10), ((1, 2),)): QQ('25/6'),
    ((-9, 1, 1, 5), ((4, 1),)): QQ('1'),
    ((-11, 1, 4, 4), ((1, 1),)): QQ('1'),
    ((-9, 1, 2, 4), ((4, 1),)): QQ('1'),
    ((-7, 0, 1, 4), ((4, 1),)): QQ('1'),
    ((-8, -3, 1, 8), ((2, 1),)): QQ('1'),
    ((-9, 1, 1, 5), ((1, 1),)): QQ('1'),
    ((-7, 0, 1, 4), ((2, 1),)): QQ('1'),
    ((-7, 7), ((1, 1),)): QQ('2'),
    ((-7, -6, 1, 10), ((1, 1),)): QQ('1'),
    ((-11, 1, 3, 5), ((1, 1),)): QQ('1'),
    ((-2, -1, 0, 1), ((1, 1),)): QQ('1'),
    ((-8, -2, 1, 7), ((1, 1),)): QQ('1'),
    ((-11, -2, 1, 10), ((1, 1),)): QQ('1'),
    ((-17, 17), ((1, 1),)): QQ('12'),
    ((-8, -5, 1, 10), ((1, 1),)): QQ('1'),
    ((-8, -3, 1, 8), ((1, 1),)): QQ('1'),
    ((-6, 1, 1, 2), ((4, 1),)): QQ('1'),
    ((-7, -4, 1, 8), ((1, 1),)): QQ('1'),
    ((-3, 3), ((2, 1),)): QQ('1/3'),
    ((-10, 0, 1, 7), ((2, 1),)): QQ('1'),
    ((-9, 1, 3, 3), ((1, 1),)): QQ('1'),
    ((-7, -2, 1, 6), ((1, 1),)): QQ('1'),
    ((-8, -4, 1, 9), ((2, 1),)): QQ('1'),
    ((-9, -2, 1, 8), ((1, 1),)): QQ('1'),
    ((-10, 1, 2, 5), ((3, 1),)): QQ('1'),
    ((-10, -2, 1, 9), ((1, 1),)): QQ('1'),
    ((-5, -4, 1, 6), ((1, 1),)): QQ('1'),
    ((-5, -5, 1, 7), ((1, 1),)): QQ('1'),
    ((-8, 8), ((2, 1),)): QQ('21/8'),
    ((-10, 1, 1, 6), ((1, 1),)): QQ('1'),
    ((-9, 1, 2, 4), ((1, 1),)): QQ('1'),
    ((-11, 0, 1, 8), ((2, 1),)): QQ('1'),
    ((-11, 1, 1, 7), ((2, 1),)): QQ('1'),
    ((-7, 1, 2, 2), ((2, 1),)): QQ('1'),
    ((-6, -6, 1, 9), ((1, 1),)): QQ('1'),
    ((-9, -4, 1, 10), ((1, 1),)): QQ('1'),
    ((-10, 1, 9), ((1, 2),)): QQ('27/8'),
    ((-10, 10), ((2, 1),)): QQ('33/8'),
    ((-2, -1, 0, 1), ((4, 1),)): QQ('1'),
    ((-11, 1, 2, 6), ((1, 1),)): QQ('1'),
    ((-14, 14), ((1, 1),)): QQ('65/8'),
    ((-5, 5), ((2, 1),)): QQ('1'),
    ((-7, 0, 1, 4), ((1, 1),)): QQ('1'),
    ((-7, 1, 2, 2), ((3, 1),)): QQ('1'),
    ((-8, -5, 1, 10), ((2, 1),)): QQ('1'),
    ((-6, -3, 1, 6), ((1, 1),)): QQ('1'),
    ((-2, -1, 0, 1), ((3, 1),)): QQ('1'),
    ((-9, -3, 1, 9), ((1, 1),)): QQ('1'),
    ((-10, -3, 1, 10), ((2, 1),)): QQ('1'),
    ((-5, -4, 1, 6), ((2, 1),)): QQ('1'),
    ((-9, -4, 1, 10), ((2, 1),)): QQ('1'),
    ((-10, 10), ((1, 1),)): QQ('33/8'),
    ((-8, 1, 1, 4), ((4, 1),)): QQ('1'),
    ((-9, -3, 1, 9), ((2, 1),)): QQ('1'),
    ((-7, 1, 1, 3), ((1, 1),)): QQ('1'),
    ((-18, 18), ((1, 1),)): QQ('323/24'),
    ((-6, -3, 1, 6), ((2, 1),)): QQ('1'),
    ((-11, 1, 2, 6), ((3, 1),)): QQ('1'),
    ((-7, 1, 1, 3), ((4, 1),)): QQ('1'),
    ((-9, 0, 1, 6), ((1, 1),)): QQ('1'),
    ((-7, -3, 1, 7), ((2, 1),)): QQ('1'),
    ((-16, 16), ((1, 1),)): QQ('85/8'),
    ((-11, 11), ((1, 1),)): QQ('5'),
    ((-8, 0, 1, 5), ((4, 1),)): QQ('1'),
    ((-7, -6, 1, 10), ((2, 1),)): QQ('1'),
    ((-6, 0, 1, 3), ((2, 1),)): QQ('1'),
    ((-10, -3, 1, 10), ((1, 1),)): QQ('1'),
    ((-10, 1, 1, 6), ((4, 1),)): QQ('1'),
    ((-12, 12), ((1, 1),)): QQ('143/24'),
    ((-2, -2, -1, 3), ((1, 1),)): QQ('1'),
    ((-5, 1, 1, 1), ((2, 1),)): QQ('1'),
    ((-7, -4, 1, 8), ((2, 1),)): QQ('1'),
    ((-7, 1, 6), ((1, 2),)): QQ('3/2'),
    ((-8, 1, 2, 3), ((3, 1),)): QQ('1'),
    ((-7, -5, 1, 9), ((1, 1),)): QQ('1'),
    ((-11, 1, 1, 7), ((4, 1),)): QQ('1'),
    ((-8, 1, 7), ((1, 2),)): QQ('49/24'),
    ((-2, -1, 3), ((1, 2),)): QQ('3/8'),
    ((-2, -1, -1, 2), ((1, 1),)): QQ('1'),
    ((-5, -2, -1, 8), ((1, 3),)): QQ('17/6'),
    ((-5, -1, 6), ((1, 2),)): QQ('3/2'),
    ((-5, -4, -1, 8), ((2, 1),)): QQ('1'),
    ((-5, -2, -2, 7), ((2, 1),)): QQ('1'),
    ((-5, -2, -1, 6), ((2, 1),)): QQ('1'),
    ((-5, -2, -2, -1, 8), ((2, 1), (3, 1))): QQ('2'),
    ((-3, -2, -1, 4), ((1, 1),)): QQ('1'),
    ((-5, -2, -1, 2, 4), ((1, 2),)): QQ('1'),
    ((-5, -1, 2, 2), ((1, 1),)): QQ('1'),
    ((-5, -1, 0, 4), ((1, 1),)): QQ('1'),
    ((-5, -2, -1, 3, 3), ((1, 2),)): QQ('1'),
    ((-5, -1, 1, 3), ((1, 1),)): QQ('1'),
    ((-5, -4, -1, 8), ((1, 1),)): QQ('1'),
    ((-4, -3, -2, 7), ((1, 1),)): QQ('1'),
    ((-5, -2, 7), ((1, 2),)): QQ('13/6'),
    ((-5, -2, -2, -1, 8), ((1, 1), (2, 1))): QQ('2'),
    ((-7, -2, -1, 8), ((2, 1),)): QQ('1'),
    ((-5, -2, -1, 0, 6), ((1, 1), (2, 1))): QQ('2'),
    ((-5, -2, -1, 6), ((1, 1),)): QQ('1'),
    ((-6, -3, -1, 8), ((2, 1),)): QQ('1'),
    ((-5, -2, -1, 1, 5), ((1, 2),)): QQ('1'),
    ((-4, -3, -2, -1, 8), ((2, 2),)): QQ('1'),
    ((-4, -3, -1, 6), ((2, 1),)): QQ('1'),
    ((-5, 0, 5), ((1, 2),)): QQ('1'),
    ((-7, -2, -1, 8), ((1, 1),)): QQ('1'),
    ((-5, -2, 0, 5), ((2, 1),)): QQ('1'),
    ((-5, -2, 0, 5), ((1, 1),)): QQ('1'),
    ((-4, -3, 0, 5), ((1, 1),)): QQ('1'),
    ((-5, -2, -2, -1, 8), ((1, 2),)): QQ('1'),
    ((-5, -2, -1, 0, 6), ((1, 2),)): QQ('1'),
    ((-5, -2, -2, 7), ((1, 1),)): QQ('1'),
    ((-3, -2, -1, 4), ((2, 1),)): QQ('1'),
    ((-7, -1, 2, 4), ((1, 1),)): QQ('1'),
    ((-7, -1, 8), ((1, 2),)): QQ('8/3'),
    ((-7, -1, 3, 3), ((1, 1),)): QQ('1'),
    ((-7, -1, 0, 6), ((1, 1),)): QQ('1'),
    ((-7, -1, 1, 5), ((1, 1),)): QQ('1'),
    ((-5, -2, -2, -1, 8), ((2, 2),)): QQ('1'),
    ((-4, -3, -2, 7), ((2, 1),)): QQ('1'),
    ((-4, -3, -1, 6), ((1, 1),)): QQ('1'),
    ((-5, -2, -1, 0, 6), ((2, 2),)): QQ('1'),
    ((-5, -1, 2, 4), ((1, 3),)): QQ('5/6'),
    ((-5, -1, 0, 2, 2), ((1, 2),)): QQ('1'),
    ((-5, -1, 0, 0, 4), ((1, 2),)): QQ('1'),
    ((-5, -1, 1, 1, 2), ((1, 2),)): QQ('1'),
    ((-4, -3, -1, 2, 4), ((1, 2),)): QQ('1'),
    ((-3, -1, 0, 2), ((1, 1),)): QQ('1'),
    ((-3, -1, 1, 1), ((1, 1),)): QQ('1'),
    ((-5, -1, 3, 3), ((1, 3),)): QQ('3/4'),
    ((-4, -3, -1, 3, 3), ((1, 2),)): QQ('1'),
    ((-5, -1, 0, 1, 3), ((1, 2),)): QQ('1'),
    ((-4, -1, 0, 3), ((1, 1),)): QQ('1'),
    ((-3, -3, -3, -1, 8), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -3, -1, 8), ((1, 2),)): QQ('1'),
    ((-3, -3, -3, 7), ((1, 1),)): QQ('1'),
    ((-4, -3, -1, 8), ((1, 3),)): QQ('73/24'),
    ((-4, -3, -2, -1, 8), ((1, 2),)): QQ('1'),
    ((-4, -3, 7), ((1, 2),)): QQ('19/8'),
    ((-4, -3, -1, 0, 6), ((1, 2),)): QQ('1'),
    ((-4, -3, -1, 1, 5), ((1, 2),)): QQ('1'),
    ((-4, -1, 5), ((1, 2),)): QQ('25/24'),
    ((-4, -3, -2, -1, 8), ((1, 1), (2, 1))): QQ('2'),
    ((-4, -2, -1, 5), ((1, 1),)): QQ('1'),
    ((-4, -1, 1, 2), ((1, 1),)): QQ('1'),
    ((-4, -3, -1, 1, 5), ((1, 1), (2, 1))): QQ('2'),
    ((-3, -3, -1, 5), ((1, 1),)): QQ('1'),
    ((-4, -2, -1, 5), ((2, 1),)): QQ('1'),
    ((-4, -3, 0, 5), ((2, 1),)): QQ('1'),
    ((-4, -3, -1, 1, 5), ((2, 2),)): QQ('1'),
    ((-5, 7), ((1, 3),)): QQ('34/45'),
    ((-5, -1, 0, 6), ((1, 3),)): QQ('3/2'),
    ((-5, -1, 1, 5), ((1, 3),)): QQ('13/12'),
    ((-5, -1, 8), ((1, 4),)): QQ('68/45'),
    ((1, 1, 2), ((1, 1), (2, 5), (3, 1))): QQ('5/2016'),
    ((-2, 1, 1, 2), ((2, 1), (3, 3), (4, 1))): QQ('1/3'),
    ((-2, 1, 1, 2), ((1, 1), (2, 1), (3, 2), (4, 1))): QQ('3/4'),
    ((-2, -2, 1, 1, 2), ((3, 1), (4, 2), (5, 1))): QQ('17/6'),
    ((-2, 1, 1, 2), ((1, 2), (2, 1), (3, 1), (4, 1))): QQ('31/48'),
    ((-3, 1, 2), ((2, 1), (3, 1))): QQ('1/2'),
    ((-4, 1, 1, 2), ((2, 1), (3, 1), (4, 1))): QQ('5/2'),
    ((-2, -2, -2, 1, 1, 2), ((4, 1), (5, 1), (6, 1))): QQ('6'),
    ((-2, -2, 1, 1, 2), ((1, 1), (3, 1), (4, 1), (5, 1))): QQ('6'),
    ((1, 1, 2), ((1, 2), (2, 4), (3, 1))): QQ('1/315'),
    ((-2, 1, 1, 2), ((2, 2), (3, 2), (4, 1))): QQ('5/12'),
    ((-2, 1, 1, 2), ((1, 2), (2, 2), (4, 1))): QQ('11/24'),
    ((-3, -2, 1, 2), ((4, 1),)): QQ('1'),
    ((-4, 1, 1, 2), ((2, 2), (4, 1))): QQ('2'),
    ((-2, -2, -2, 1, 1, 2), ((4, 2), (6, 1))): QQ('3'),
    ((-3, 1, 2), ((1, 1), (3, 1))): QQ('1/2'),
    ((-2, -2, 1, 1, 2), ((1, 1), (3, 2), (5, 1))): QQ('13/3'),
    ((1, 1, 2), ((1, 4), (3, 3))): QQ('1/672'),
    ((-2, 1, 1, 2), ((2, 2), (4, 3))): QQ('3/16'),
    ((-2, 1, 1, 2), ((1, 1), (2, 1), (4, 3))): QQ('5/16'),
    ((-2, -2, 1, 1, 2), ((3, 1), (5, 3))): QQ('5/4'),
    ((-2, 1, 1, 2), ((1, 2), (4, 3))): QQ('133/960'),
    ((-4, 1, 1, 2), ((4, 3),)): QQ('17/24'),
    ((-2, -2, -2, 1, 1, 2), ((6, 3),)): QQ('1'),
    ((-2, -2, 1, 1, 2), ((1, 1), (5, 3))): QQ('3/2'),
    ((-2, -1, -1, 0, 2), ((1, 2),)): QQ('1'),
    ((-2, -1, -1, 1, 1), ((1, 2),)): QQ('1'),
    ((-4, -1, -1, 4), ((1, 1),)): QQ('1'),
    ((-2, -2, -1, -1, 4), ((1, 2),)): QQ('1'),
    ((-2, -1, -1, 4), ((1, 3),)): QQ('17/24'),
    ((-3, -3, 1, 1, 1, 1), ((1, 1), (2, 2))): QQ('3'),
    ((-32, -2, 1, 31), ((1, 1),)): QQ('1'),
    ((-31, -3, 1, 31), ((2, 1),)): QQ('1'),
    ((-30, -4, 1, 31), ((1, 1),)): QQ('1'),
    ((-29, -5, 1, 31), ((2, 1),)): QQ('1'),
    ((-28, -6, 1, 31), ((2, 1),)): QQ('1'),
    ((-27, -7, 1, 31), ((1, 1),)): QQ('1'),
    ((-26, -8, 1, 31), ((2, 1),)): QQ('1'),
    ((-25, -9, 1, 31), ((2, 1),)): QQ('1'),
    ((-24, -10, 1, 31), ((2, 1),)): QQ('1'),
    ((-23, -11, 1, 31), ((1, 1),)): QQ('1'),
    ((-22, -12, 1, 31), ((1, 1),)): QQ('1'),
    ((-21, -13, 1, 31), ((2, 1),)): QQ('1'),
    ((-20, -14, 1, 31), ((1, 1),)): QQ('1'),
    ((-19, -15, 1, 31), ((2, 1),)): QQ('1'),
    ((-18, -16, 1, 31), ((1, 1),)): QQ('1'),
    ((-17, -17, 1, 31), ((1, 1),)): QQ('1'),
    ((-32, 0, 1, 29), ((1, 1),)): QQ('1'),
    ((-32, 1, 1, 28), ((1, 1),)): QQ('1'),
    ((-32, 1, 2, 27), ((1, 1),)): QQ('1'),
    ((-32, 1, 3, 26), ((1, 1),)): QQ('1'),
    ((-32, 1, 4, 25), ((1, 1),)): QQ('1'),
    ((-32, 1, 5, 24), ((1, 1),)): QQ('1'),
    ((-32, 1, 6, 23), ((1, 1),)): QQ('1'),
    ((-32, 1, 7, 22), ((1, 1),)): QQ('1'),
    ((-32, 1, 8, 21), ((1, 1),)): QQ('1'),
    ((-32, 1, 9, 20), ((1, 1),)): QQ('1'),
    ((-32, 1, 10, 19), ((1, 1),)): QQ('1'),
    ((-32, 1, 11, 18), ((1, 1),)): QQ('1'),
    ((-32, 1, 12, 17), ((1, 1),)): QQ('1'),
    ((-32, 1, 13, 16), ((1, 1),)): QQ('1'),
    ((-32, 1, 14, 15), ((1, 1),)): QQ('1'),
    ((-12, -2, 1, 11), ((1, 1),)): QQ('1'),
    ((-11, -3, 1, 11), ((2, 1),)): QQ('1'),
    ((-10, -4, 1, 11), ((2, 1),)): QQ('1'),
    ((-9, -5, 1, 11), ((1, 1),)): QQ('1'),
    ((-8, -6, 1, 11), ((2, 1),)): QQ('1'),
    ((-7, -7, 1, 11), ((1, 1),)): QQ('1'),
    ((-12, 0, 1, 9), ((1, 1),)): QQ('1'),
    ((-12, 1, 1, 8), ((1, 1),)): QQ('1'),
    ((-12, 1, 2, 7), ((1, 1),)): QQ('1'),
    ((-12, 1, 3, 6), ((1, 1),)): QQ('1'),
    ((-12, 1, 4, 5), ((1, 1),)): QQ('1'),
    ((-2, -2, 1, 3), ((1, 1), (2, 1), (4, 1))): QQ('2'),
    ((-2, -2, 1, 3), ((1, 2), (4, 1))): QQ('11/8'),
    ((-2, -2, -2, 1, 3), ((1, 1), (5, 1))): QQ('2'),
    ((-4, -2, 1, 3), ((4, 1),)): QQ('1'),
    ((-3, -3, 1, 3), ((4, 1),)): QQ('1'),
    ((-2, -2, -2, 1, 3), ((4, 1), (5, 1))): QQ('2'),
    ((-4, 1, 3), ((1, 1), (3, 1))): QQ('1'),
    ((-2, -2, 1, 3), ((1, 1), (3, 1), (4, 1))): QQ('2'),
    ((-4, 1, 3), ((2, 1), (3, 1))): QQ('1'),
    ((-2, -2, 1, 3), ((3, 2), (4, 1))): QQ('1'),
    ((-2, 1, 3), ((1, 3), (3, 1))): QQ('23/360'),
    ((-2, 1, 3), ((1, 1), (2, 2), (3, 1))): QQ('23/90'),
    ((-2, 1, 3), ((2, 3), (3, 1))): QQ('11/90'),
    ((-2, 1, 3), ((1, 2), (2, 1), (3, 1))): QQ('71/360'),
    ((-2, -2, 1, 3), ((1, 1), (4, 2))): QQ('7/6'),
    ((-2, -2, -2, 1, 3), ((5, 2),)): QQ('1'),
    ((-4, 1, 3), ((3, 2),)): QQ('2/3'),
    ((-2, 1, 3), ((1, 2), (3, 2))): QQ('19/180'),
    ((-2, 1, 3), ((2, 2), (3, 2))): QQ('4/45'),
    ((-2, 1, 3), ((1, 1), (2, 1), (3, 2))): QQ('7/45'),
    ((-2, -2, 1, 3), ((3, 1), (4, 2))): QQ('2/3'),
    ((-2, -2, 1, 3), ((4, 3),)): QQ('1/3'),
    ((-2, 1, 3), ((1, 1), (3, 3))): QQ('7/90'),
    ((-2, 1, 3), ((2, 1), (3, 3))): QQ('2/45'),
    ((-98, -2, 100), ((1, 1), (3, 1))): QQ('9803/12'),
    ((-87, -13, -2, 100), ((4, 1),)): QQ('1'),
    ((-76, -24, -2, 100), ((4, 1),)): QQ('1'),
    ((-77, -23, -2, 100), ((4, 1),)): QQ('1'),
    ((-85, -15, -2, 100), ((4, 1),)): QQ('1'),
    ((-91, -9, -2, 100), ((4, 1),)): QQ('1'),
    ((-59, -41, -2, 100), ((4, 1),)): QQ('1'),
    ((-65, -35, -2, 100), ((4, 1),)): QQ('1'),
    ((-82, -18, -2, 100), ((4, 1),)): QQ('1'),
    ((-79, -21, -2, 100), ((4, 1),)): QQ('1'),
    ((-89, -11, -2, 100), ((4, 1),)): QQ('1'),
    ((-56, -44, -2, 100), ((4, 1),)): QQ('1'),
    ((-92, -8, -2, 100), ((4, 1),)): QQ('1'),
    ((-54, -46, -2, 100), ((4, 1),)): QQ('1'),
    ((-83, -17, -2, 100), ((4, 1),)): QQ('1'),
    ((-66, -34, -2, 100), ((4, 1),)): QQ('1'),
    ((-90, -10, -2, 100), ((4, 1),)): QQ('1'),
    ((-80, -20, -2, 100), ((4, 1),)): QQ('1'),
    ((-88, -12, -2, 100), ((4, 1),)): QQ('1'),
    ((-71, -29, -2, 100), ((4, 1),)): QQ('1'),
    ((-95, -5, -2, 100), ((4, 1),)): QQ('1'),
    ((-97, -3, -2, 100), ((4, 1),)): QQ('1'),
    ((-93, -7, -2, 100), ((4, 1),)): QQ('1'),
    ((-55, -45, -2, 100), ((4, 1),)): QQ('1'),
    ((-61, -39, -2, 100), ((4, 1),)): QQ('1'),
    ((-58, -42, -2, 100), ((4, 1),)): QQ('1'),
    ((-74, -26, -2, 100), ((4, 1),)): QQ('1'),
    ((-64, -36, -2, 100), ((4, 1),)): QQ('1'),
    ((-84, -16, -2, 100), ((4, 1),)): QQ('1'),
    ((-70, -30, -2, 100), ((4, 1),)): QQ('1'),
    ((-57, -43, -2, 100), ((4, 1),)): QQ('1'),
    ((-60, -40, -2, 100), ((4, 1),)): QQ('1'),
    ((-96, -4, -2, 100), ((4, 1),)): QQ('1'),
    ((-98, -2, -2, 100), ((4, 1),)): QQ('1'),
    ((-67, -33, -2, 100), ((4, 1),)): QQ('1'),
    ((-69, -31, -2, 100), ((4, 1),)): QQ('1'),
    ((-62, -38, -2, 100), ((4, 1),)): QQ('1'),
    ((-52, -48, -2, 100), ((4, 1),)): QQ('1'),
    ((-78, -22, -2, 100), ((4, 1),)): QQ('1'),
    ((-63, -37, -2, 100), ((4, 1),)): QQ('1'),
    ((-53, -47, -2, 100), ((4, 1),)): QQ('1'),
    ((-94, -6, -2, 100), ((4, 1),)): QQ('1'),
    ((-86, -14, -2, 100), ((4, 1),)): QQ('1'),
    ((-75, -25, -2, 100), ((4, 1),)): QQ('1'),
    ((-68, -32, -2, 100), ((4, 1),)): QQ('1'),
    ((-50, -50, -2, 100), ((4, 1),)): QQ('1'),
    ((-73, -27, -2, 100), ((4, 1),)): QQ('1'),
    ((-51, -49, -2, 100), ((4, 1),)): QQ('1'),
    ((-72, -28, -2, 100), ((4, 1),)): QQ('1'),
    ((-81, -19, -2, 100), ((4, 1),)): QQ('1'),
}
