"""
This module contains precomputed values for levelstratum.top_xi_at_level
to facilitate faster computation.

It contains many (meromorphic) low-genus strata that were computed to
a large part on a computer of the MPIM (requiring significant memory).
"""

from sage.rings.rational_field import QQ  # pylint: disable=import-error

XI_TOP_CACHE = {
    (((4,),), ()): QQ('305/580608'),
    (((0,), (0, 0)), ()): QQ('0'),
    (((0,),), ()): QQ('1/24'),
    (((-2, 4),), (((0, 0),),)): QQ('-23/1152'),
    (((0, 2),), ()): QQ('0'),
    (((0, 0, 0),), ()): QQ('0'),
    (((0, 0),), ()): QQ('0'),
    (((2,),), ()): QQ('-1/640'),
    (((-4, 4),), (((0, 0),),)): QQ('-15/8'),
    (((1, 1),), ()): QQ('0'),
    (((0,), (0,)), ()): QQ('-1/576'),
    (((-2, -2, 4),), (((0, 0),), ((0, 1),))): QQ('-11/12'),
    (((-2, 0, 2),), (((0, 0),),)): QQ('1/8'),
    (((-4, -2, 4),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-2, 0, 0, 0),), (((0, 0),),)): QQ('-1'),
    (((-2, -2, -2, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('-4'),
    (((-2, 0, 0),), (((0, 0),),)): QQ('1'),
    (((-2, -2, -2, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('1'),
    (((-4, 1, 1),), (((0, 0),),)): QQ('1'),
    (((-3, -3, 4),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-2, -2, 1, 1),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-2, -2, 4),), (((0, 0), (0, 1)),)): QQ('13/8'),
    (((-2, 2),), (((0, 0),),)): QQ('-1/8'),
    (((-2, 1, 1),), (((0, 0),),)): QQ('0'),
    (((0,), (-2, 0, 0)), (((1, 0),),)): QQ('-1/24'),
    (((-4, 0, 2),), (((0, 0),),)): QQ('1'),
    (((-2, -2, 2),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-2, -2, 0, 2),), (((0, 0), (0, 1)),)): QQ('-2'),
    (((-2, -2, 1, 1),), (((0, 0), (0, 1)),)): QQ('-1'),
    (((1, 3),), ()): QQ('0'),
    (((-2, 1, 3),), (((0, 0),),)): QQ('0'),
    (((-2, -2, 1, 3),), (((0, 0),), ((0, 1),))): QQ('4/3'),
    (((0,), (2,)), ()): QQ('1/15360'),
    (((-4, -2, 1, 3),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((0, 1, 1),), ()): QQ('0'),
    (((-4, 1, 3),), (((0, 0),),)): QQ('10/3'),
    (((-6, 1, 3),), (((0, 0),),)): QQ('1'),
    (((-3, 3),), (((0, 0),),)): QQ('-2/3'),
    (((-2, -2, -2, 1, 3),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-4'),
    (((-2, -2, 0, 1, 1),), (((0, 0),), ((0, 1),))): QQ('-2'),
    (((-3, -2, 3),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-4, -2, 1, 3),), (((0, 0), (0, 1)),)): QQ('-3'),
    (((-3, -3, 1, 3),), (((0, 0), (0, 1)),)): QQ('-3'),
    (((-4, 0, 1, 1),), (((0, 0),),)): QQ('-3'),
    (((-2, -2, -2, 1, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('6'),
    (((-2, 0, 1, 1),), (((0, 0),),)): QQ('0'),
    (((-2, -2, 1, 3),), (((0, 0), (0, 1)),)): QQ('-4/3'),
    (((0,), (-2, 2)), (((1, 0),),)): QQ('1/192'),
    (((-3, 0, 1),), (((0, 0),),)): QQ('1'),
    (((0,), (-2, -2, 2)), (((1, 0), (1, 1)),)): QQ('-1/24'),
    (((-2, -2, 0, 1, 1),), (((0, 0), (0, 1)),)): QQ('2'),
    (((1, 1, 2),), ()): QQ('0'),
    (((-2, 1, 1, 2),), (((0, 0),),)): QQ('0'),
    (((0,), (0,), (0,)), ()): QQ('1/13824'),
    (((-2, -2, -2, 1, 1, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-6'),
    (((-6, 1, 1, 2),), (((0, 0),),)): QQ('-5'),
    (((2, 2),), ()): QQ('0'),
    (((0,), (1, 1)), ()): QQ('0'),
    (((-4, -2, 1, 1, 2),), (((0, 0),), ((0, 1),))): QQ('-6'),
    (((-4, 1, 1, 2),), (((0, 0),),)): QQ('-43/8'),
    (((-2, -2, 1, 1, 2),), (((0, 0),), ((0, 1),))): QQ('-5/4'),
    (((0, 0), (0, 0)), ()): QQ('0'),
    (((0,), (0, 0, 0)), ()): QQ('0'),
    (((0, 0, 0, 0),), ()): QQ('0'),
    (((0, 0, 1, 1),), ()): QQ('0'),
    (((0,), (0, 2)), ()): QQ('0'),
    (((0, 0, 2),), ()): QQ('0'),
    (((-4, -2, 2, 2),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-2, 0, 0, 1, 1),), (((0, 0),),)): QQ('0'),
    (((-3, -2, 1, 2),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((0, 0), (-2, 0, 0)), (((1, 0),),)): QQ('0'),
    (((-4, 1, 1), (-2, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, 0, 0, 2),), (((0, 0),),)): QQ('-1/8'),
    (((-5, 1, 2),), (((0, 0),),)): QQ('1'),
    (((-2, -2, 1, 1), (-2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1/8'),
    (((0,), (-2, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-4, -2, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('9'),
    (((-3, 1, 2),), (((0, 0),),)): QQ('5/8'),
    (((-2, -2, 2, 2),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-4, 0, 0, 2),), (((0, 0),),)): QQ('-3'),
    (((-4, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-3, -2, 1, 2),), (((0, 0), (0, 1)),)): QQ('-2'),
    (((0,), (-2, -2, 1, 1)), (((1, 0),), ((1, 1),))): QQ('-1/24'),
    (((0,), (-2, 0, 0, 0)), (((1, 0),),)): QQ('1/24'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-1'),
    (((0,), (-4, 1, 1)), (((1, 0),),)): QQ('-1/24'),
    (((-2, -2, -2, 1, 1, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('-12'),
    (((-2, -2, 0, 0, 1, 1),), (((0, 0),), ((0, 1),))): QQ('4'),
    (((-2, -2, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('5/4'),
    (((-3, -3, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('8'),
    (((-4, 2, 2),), (((0, 0),),)): QQ('31/12'),
    (((-2, -2, -2, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('2'),
    (((-2, -2, 1, 1), (-2, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('1/8'),
    (((-2, 1, 1), (-2, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, -2, 1, 1, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('10'),
    (((-6, 2, 2),), (((0, 0),),)): QQ('1'),
    (((0,), (-4, 0, 2)), (((1, 0),),)): QQ('-1/24'),
    (((-2, 0, 0, 0, 0),), (((0, 0),),)): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('1'),
    (((-2, 2, 2),), (((0, 0),),)): QQ('1/64'),
    (((-4, 0, 0, 1, 1),), (((0, 0),),)): QQ('9'),
    (((-2, 0, 0), (-2, 0, 0)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-1'),
    (((0,), (-2, 0, 2)), (((1, 0),),)): QQ('-1/192'),
    (((-2, 0, 0), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, 0, 0), (-2, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, 0, 0), (-4, 1, 1)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('1/8'),
    (((-2, -2, -2, 1, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-4'),
    (((-2, -2, -2, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-4'),
    (((-2, -2, 0, 0, 2),), (((0, 0), (0, 1)),)): QQ('4'),
    (((0,), (-2, -2, 0, 2)), (((1, 0), (1, 1)),)): QQ('1/12'),
    (((-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('1'),
    (((-4, -2, 2, 2),), (((0, 0), (0, 1)),)): QQ('-3'),
    (((-2, 0, 0), (-2, 1, 1)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, 0, 0), (-2, 0, 0)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-3, -3, 2, 2),), (((0, 0), (0, 1)),)): QQ('-2'),
    (((0,), (-2, -2, 1, 1)), (((1, 0), (1, 1)),)): QQ('1/24'),
    (((-2, 2), (-2, 2)), (((0, 0), (1, 0)),)): QQ('-1/64'),
    (((-3, 0, 0, 1),), (((0, 0),),)): QQ('-2'),
    (((-3, 0, 1), (-3, 0, 1)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, -2, 2, 2),), (((0, 0), (0, 1)),)): QQ('-3/2'),
    (((-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0), (1, 1)),)): QQ('1'),
    (((-2, -2, -2, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('8'),
    (((-2, -2, 2), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, 0, 0, 1, 1),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((1, 1, 1, 1),), ()): QQ('0'),
    (((0,), (0,), (0, 0)), ()): QQ('0'),
    (((-4, -2, 1, 1, 1, 1),), (((0, 0),), ((0, 1),))): QQ('27'),
    (((-2, -2, -2, 1, 1, 1, 1),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('24'),
    (((-2, -2, 1, 1, 1, 1),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((0,), (0, 1, 1)), ()): QQ('0'),
    (((-4, 1, 1, 1, 1),), (((0, 0),),)): QQ('9'),
    (((-6, 1, 1, 1, 1),), (((0, 0),),)): QQ('25'),
    (((-2, 1, 1, 1, 1),), (((0, 0),),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('1'),
    (((-4, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-4, -2, 1, 1, 1, 1),), (((0, 0), (0, 1)),)): QQ('-27'),
    (((-3, -2, 1, 1, 1),), (((0, 0),), ((0, 1),))): QQ('-4'),
    (((-4, 1, 1), (-4, 1, 1)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((0,), (0,), (-2, 0, 0)), (((2, 0),),)): QQ('1/576'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((0, 1), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-4, 1, 1), (-2, 1, 1)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-5, 1, 1, 1),), (((0, 0),),)): QQ('-4'),
    (((-4, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 0), (1, 1)),)): QQ('1'),
    (((0,), (-2, 0, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, -2, -2, 1, 1, 1, 1),), (((0, 0), (0, 1), (0, 2)),)): QQ('24'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('1'),
    (((-4, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-3, -3, 1, 1, 1, 1),), (((0, 0), (0, 1)),)): QQ('-24'),
    (((-2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((0,), (-4, 0, 1, 1)), (((1, 0),),)): QQ('1/8'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('1'),
    (((0,), (-2, -2, 0, 1, 1)), (((1, 0),), ((1, 1),))): QQ('1/12'),
    (((-3, 1, 1, 1),), (((0, 0),),)): QQ('-1/2'),
    (((-2, 1, 1), (-2, 1, 1)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((0, 1), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 1)), ((1, 0),))): QQ('0'),
    (((-2, -2, -2, 1, 1, 1, 1),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-24'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('1'),
    (((-3, -2, 1, 1, 1),), (((0, 0), (0, 1)),)): QQ('4'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('1'),
    (((-2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 0)), ((1, 1),))): QQ('0'),
    (((-2, -2, 1, 1, 1, 1),), (((0, 0), (0, 1)),)): QQ('-1'),
    (((0,), (-3, 0, 1)), (((1, 0),),)): QQ('-1/24'),
    (((-2, -2, -2, 1, 1, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('10'),
    (((0,), (-2, -2, 0, 1, 1)), (((1, 0), (1, 1)),)): QQ('-1/12'),
    (((-2, -2, 1, 1), (-2, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('1/8'),
    (((-2, 1, 1, 1, 1),), ()): QQ('0'),
    (((-2, 0, 2), (0,)), ()): QQ('-1/192'),
    (((-4, 1, 1), (-2, -2, 1, 1)), (((1, 1),),)): QQ('-1'),
    (((-2, 0, 0),), ()): QQ('1'),
    (((-2, 1, 1), (-2, 1, 1)), ()): QQ('0'),
    (((-2, 0, 0), (0, 0)), ()): QQ('0'),
    (((-2, 2, 2),), ()): QQ('1/64'),
    (((-4, 1, 1), (-4, 1, 1)), ()): QQ('-1'),
    (((-2, 0, 0), (0,), (0,)), ()): QQ('1/576'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((1, 1),))): QQ('-1'),
    (((-2, 0, 1, 1),), ()): QQ('0'),
    (((-2, 0, 0, 0, 0),), ()): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), ()): QQ('-1'),
    (((0,), (-2, 0, 1, 1)), ()): QQ('0'),
    (((-2, 0, 2),), ()): QQ('1/8'),
    (((-4, -2, 1, 1, 1, 1),), ()): QQ('-27'),
    (((0,), (-2, 1, 1)), ()): QQ('0'),
    (((-2, 2), (0,)), ()): QQ('1/192'),
    (((-4, -2, 1, 1, 1, 1),), (((0, 1),),)): QQ('27'),
    (((-2, 1, 3),), ()): QQ('0'),
    (((-2, -2, -2, 1, 1, 1, 1),), (((0, 1),), ((0, 2),))): QQ('24'),
    (((-2, 0, 0, 2),), ()): QQ('-1/8'),
    (((-4, 1, 1), (-2, -2, 1, 1)), ()): QQ('1'),
    (((-4, 1, 1), (-2, -2, 1, 1)), (((1, 0),),)): QQ('-1'),
    (((-2, 0, 0, 0), (0,)), ()): QQ('1/24'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((1, 1),),)): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 1),), ((1, 1),))): QQ('-1'),
    (((-2, 1, 1, 2),), ()): QQ('0'),
    (((-2, 0, 0, 0),), ()): QQ('-1'),
    (((-2, 1, 1), (-2, -2, 1, 1)), ()): QQ('0'),
    (((-2, 0, 0, 1, 1),), ()): QQ('0'),
    (((-2, 1, 1),), ()): QQ('0'),
    (((-4, 1, 1), (-2, 1, 1)), ()): QQ('0'),
    (((-2, 0, 0), (0,)), ()): QQ('-1/24'),
    (((-2, 1, 1), (-2, -2, 1, 1)), (((1, 1),),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),),)): QQ('1'),
    (((-2, 1, 1), (-2, -2, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((1, 0),),)): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 1),),)): QQ('1'),
    (((-2, 4),), ()): QQ('-23/1152'),
    (((-6, 1, 1, 1, 1),), ()): QQ('25'),
    (((-2, -2, -2, 1, 1, 1, 1),), ()): QQ('24'),
    (((-2, -2, 1, 1, 1, 1),), (((0, 1),),)): QQ('1'),
    (((-2, -2, -2, 1, 1, 1, 1),), (((0, 0),),)): QQ('-24'),
    (((-2, -2, 1, 1, 1, 1),), ()): QQ('-1'),
    (((-4, -2, 1, 1, 1, 1),), (((0, 0),),)): QQ('27'),
    (((-2, 2),), ()): QQ('-1/8'),
    (((-4, 1, 1, 1, 1),), ()): QQ('9'),
    (((-4, 1, 1),), ()): QQ('1'),
    (((-2, -2, 1, 1),), ()): QQ('-1'),
    (((0,), (-2, -2, 1, 1)), (((1, 1),),)): QQ('-1/24'),
    (((-2, -2, 1, 1),), (((0, 1),),)): QQ('1'),
    (((-2, -2, 1, 1, 2),), (((0, 1),),)): QQ('-5/4'),
    (((-4, 0, 0, 1, 1),), ()): QQ('9'),
    (((-4, 0, 1, 1),), ()): QQ('-3'),
    (((-6, 2, 2),), ()): QQ('1'),
    (((-2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 1)),)): QQ('0'),
    (((-4, -2, 1, 1, 2),), (((0, 0),),)): QQ('-6'),
    (((-6, 1, 3),), ()): QQ('1'),
    (((-5, 1, 1, 1),), ()): QQ('-4'),
    (((-2, -2, 0, 0, 2),), ()): QQ('4'),
    (((-2, -2, -2, 2, 2),), (((0, 0),),)): QQ('-4'),
    (((-2, 0, 0), (-2, 2)), ()): QQ('1/8'),
    (((-2, 0, 0), (-2, 1, 1)), ()): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (0, 1), (1, 1)),)): QQ('1'),
    (((-2, -2, 4),), ()): QQ('13/8'),
    (((-2, -2, 1, 1), (-2, 2)), ()): QQ('-1/8'),
    (((0,), (-2, 2)), ()): QQ('1/192'),
    (((-4, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 1)),)): QQ('-1'),
    (((-4, 0, 2),), ()): QQ('1'),
    (((-4, -2, 2, 2),), (((0, 1),),)): QQ('1'),
    (((-2, 2), (-2, -2, 2)), ()): QQ('1/8'),
    (((-6, 1, 1, 2),), ()): QQ('-5'),
    (((0,), (-2, -2, 0, 1, 1)), ()): QQ('-1/12'),
    (((-2, -2, 1, 1),), (((0, 0),),)): QQ('1'),
    (((-2, -2, 2),), ()): QQ('1'),
    (((-2, 1, 1), (-2, 2)), ()): QQ('0'),
    (((-3, -2, 1, 1, 1),), (((0, 1),),)): QQ('-4'),
    (((-2, -2, 0, 1, 1),), ()): QQ('2'),
    (((-2, -2, 1, 1), (-2, 2)), (((0, 1),),)): QQ('1/8'),
    (((0,), (-4, 0, 1, 1)), ()): QQ('1/8'),
    (((-2, -2, 0, 2),), ()): QQ('-2'),
    (((-2, -2, 0, 0, 1, 1),), (((0, 1),),)): QQ('4'),
    (((0,), (-2, -2, 1, 1)), ()): QQ('1/24'),
    (((-4, 1, 1), (-2, 2)), ()): QQ('1/8'),
    (((-2, -2, -2, 1, 3),), (((0, 1),),)): QQ('-4'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 1)), ((0, 1),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((0, 1), (1, 1)))): QQ('-1'),
    (((0,), (-2, 0, 0)), ()): QQ('-1/24'),
    (((-3, 1, 1, 1),), ()): QQ('-1/2'),
    (((-3, -2, 1, 1, 1),), (((0, 0),),)): QQ('-4'),
    (((-2, 0, 0), (-2, 0, 0)), ()): QQ('-1'),
    (((0,), (-4, 1, 1)), ()): QQ('-1/24'),
    (((-4, -2, 2, 2),), ()): QQ('-3'),
    (((-2, -2, 1, 1), (-2, -2, 2)), ()): QQ('1'),
    (((-2, 0, 0), (-2, -2, 1, 1)), ()): QQ('1'),
    (((-2, -2, -2, 1, 1, 1, 1),), (((0, 1), (0, 2)),)): QQ('-24'),
    (((-2, 0, 0), (-4, 1, 1)), ()): QQ('-1'),
    (((-4, -2, 1, 3),), (((0, 0),),)): QQ('1'),
    (((-2, -2, 0, 1, 1),), (((0, 1),),)): QQ('-2'),
    (((-3, -2, 1, 1, 1),), ()): QQ('4'),
    (((-4, -2, 1, 3),), ()): QQ('-3'),
    (((-2, -2, 0, 1, 1),), (((0, 0),),)): QQ('-2'),
    (((-4, -2, 1, 1, 2),), (((0, 1),),)): QQ('-6'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 1), (1, 0), (1, 1)),)): QQ('1'),
    (((-2, -2, -2, 1, 1, 2),), ()): QQ('-12'),
    (((-4, 4),), ()): QQ('-15/8'),
    (((-2, -2, -2, 1, 3),), ()): QQ('6'),
    (((-2, -2, 2, 2),), ()): QQ('-3/2'),
    (((0,), (-2, -2, 0, 2)), ()): QQ('1/12'),
    (((-2, -2, -2, 2, 2),), (((0, 1),), ((0, 2),))): QQ('2'),
    (((-4, 1, 3),), ()): QQ('10/3'),
    (((-2, 0, 0), (-2, -2, 2)), ()): QQ('-1'),
    (((-4, 1, 1, 2),), ()): QQ('-43/8'),
    (((-2, -2, -2, 1, 1, 2),), (((0, 1),), ((0, 2),))): QQ('-6'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 1),),)): QQ('-1'),
    (((0,), (-2, -2, 0, 1, 1)), (((1, 1),),)): QQ('1/12'),
    (((-4, 0, 0, 2),), ()): QQ('-3'),
    (((-2, -2, 0, 0, 1, 1),), ()): QQ('-4'),
    (((-2, 2), (-2, 2)), ()): QQ('-1/64'),
    (((-4, -2, 1, 3),), (((0, 1),),)): QQ('1'),
    (((-2, -2, 2), (-2, -2, 2)), ()): QQ('-1'),
    (((-2, -2, 2, 2),), (((0, 1),),)): QQ('1'),
    (((-4, 1, 1), (-2, -2, 2)), ()): QQ('-1'),
    (((0,), (-2, -2, 2)), ()): QQ('-1/24'),
    (((-4, 2, 2),), ()): QQ('31/12'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 1), (1, 1)),)): QQ('1'),
    (((0,), (-4, 0, 2)), ()): QQ('-1/24'),
    (((-2, 1, 1), (-2, -2, 2)), ()): QQ('0'),
    (((-2, 0, 0), (-2, -2, 1, 1)), (((1, 0),),)): QQ('-1'),
    (((-2, 0, 0), (-2, 0, 0)), (((1, 0),),)): QQ('-1'),
    (((-4, -2, 1, 1, 2),), ()): QQ('9'),
    (((-2, -2, -2, 2, 2),), ()): QQ('8'),
    (((-2, -2, 1, 3),), ()): QQ('-4/3'),
    (((-4, -2, 2, 2),), (((0, 0),),)): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 1)),)): QQ('1'),
    (((0,), (-2, 0, 2)), ()): QQ('-1/192'),
    (((-2, -2, 1, 3),), (((0, 1),),)): QQ('4/3'),
    (((-2, -2, -2, 1, 1, 2),), (((0, 0),),)): QQ('10'),
    (((-2, -2, 4),), (((0, 1),),)): QQ('-11/12'),
    (((-2, -2, -2, 4),), ()): QQ('-4'),
    (((-2, -2, 1, 1, 2),), ()): QQ('5/4'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 1), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-3, -3, 1, 1, 1, 1),), ()): QQ('-24'),
    (((-4, -2, 4),), ()): QQ('1'),
    (((-2, -2, -2, 4),), (((0, 1),),)): QQ('1'),
    (((0,), (-3, 0, 1)), ()): QQ('-1/24'),
    (((-5, 1, 2),), ()): QQ('1'),
    (((-3, -2, 1, 2),), (((0, 1),),)): QQ('1'),
    (((-3, 0, 1),), ()): QQ('1'),
    (((-3, 0, 1), (-3, 0, 1)), ()): QQ('-1'),
    (((-3, -3, 1, 3),), ()): QQ('-3'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, 2), (-2, -2, 2)), (((0, 1), (1, 0)),)): QQ('1'),
    (((-3, -2, 1, 2),), (((0, 0),),)): QQ('1'),
    (((-3, -2, 3),), ()): QQ('1'),
    (((-2, -2, 1, 1), (-2, 2)), (((0, 1), (1, 0)),)): QQ('1/8'),
    (((-2, -2, -2, 1, 3),), (((0, 1), (0, 2)),)): QQ('-4'),
    (((-3, 1, 2),), ()): QQ('5/8'),
    (((-3, 3),), ()): QQ('-2/3'),
    (((-2, -2, -2, 1, 1, 2),), (((0, 1), (0, 2)),)): QQ('10'),
    (((-3, -3, 1, 1, 2),), ()): QQ('8'),
    (((-3, -2, 1, 2),), ()): QQ('-2'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 1), (1, 0), (1, 1)),)): QQ('-1'),
    (((-3, 0, 0, 1),), ()): QQ('-2'),
    (((-3, -3, 2, 2),), ()): QQ('-2'),
    (((-2, -2, -2, 2, 2),), (((0, 2),),)): QQ('-4'),
    (((-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, -2, 2, 2),), (((0, 1), (0, 2)),)): QQ('-4'),
    (((-2, -2, -2, 4),), (((0, 1), (0, 2)),)): QQ('1'),
    (((-3, -3, 4),), ()): QQ('1'),
    (((-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0)),)): QQ('1'),
    (((-2, -2, -2, 1, 1, 1, 1),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-24'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 0)), ((0, 1),), ((1, 1),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (1, 1)), ((0, 1),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('-1'),
    (((-2, -2, -2, 1, 1, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('10'),
    (((-2, -2, -2, 1, 3),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-4'),
    (((-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('1'),
    (((-2, -2, -2, 2, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-4'),
    (((-2, -2, -2, 4),), (((0, 0),), ((0, 1), (0, 2)))): QQ('1'),
    (((-5, 5),), ()): QQ('-4'),
    (((-5, 0, 3),), ()): QQ('1'),
    (((-5, -2, 5),), ()): QQ('1'),
    (((-4, -3, 5),), ()): QQ('1'),
    (((-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-4, -1, 5),), ()): QQ('28/3'),
    (((-4, -2, -1, 5),), ()): QQ('-5'),
    (((-4, -2, -1, 5),), (((0, 1),),)): QQ('1'),
    (((-4, -1, 1, 2),), ()): QQ('-3'),
    (((-4, -1, 3),), ()): QQ('1'),
    (((-4, -1, 0, 3),), ()): QQ('-3'),
    (((-3, -3, -1, 5),), ()): QQ('-5'),
    (((-6, -1, 5),), ()): QQ('1'),
    (((-3, -1, 2),), ()): QQ('1'),
    (((-2, -1, 1),), ()): QQ('1'),
    (((-4, -2, 1, 5),), (((0, 0), (0, 1)),)): QQ('-38'),
    (((-2, -2, -2, 2, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('69/2'),
    (((-2, -2, 1, 5),), (((0, 0), (0, 1)),)): QQ('-21/10'),
    (((-4, 0, 0, 4),), (((0, 0),),)): QQ('-135/8'),
    (((-4, -2, -2, 2, 4),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-7'),
    (((-2, -2, -2, 1, 5),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('18'),
    (((-3, -3, -2, 2, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-6'),
    (((6,),), ()): QQ('-87983/199065600'),
    (((-2, -2, 2), (-4, -2, 4)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('1'),
    (((-2, -2, 6),), (((0, 0), (0, 1)),)): QQ('5273/1920'),
    (((-2, 0, 0), (0, 2)), (((0, 0),),)): QQ('0'),
    (((-2, -2, 2), (-2, -2, 4)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('11/12'),
    (((-4, -2, 0, 1, 3),), (((0, 0), (0, 1)),)): QQ('12'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 2)), ((1, 1),))): QQ('-1'),
    (((-3, -3, 0, 4),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((0, 0), (-2, 0, 0, 0)), (((1, 0),),)): QQ('0'),
    (((-2, -2, -2, 2, 4),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-617/24'),
    (((-4, 0, 1, 3),), (((0, 0),),)): QQ('-10'),
    (((-6, 6),), (((0, 0),),)): QQ('-175/24'),
    (((2,), (2,)), ()): QQ('-1/409600'),
    (((-4, -2, -2, 2, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('20'),
    (((-2, 0, 4),), (((0, 0),),)): QQ('23/1152'),
    (((-3, -3, -2, 6),), (((0, 0), (0, 1), (0, 2)),)): QQ('-6'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 3)), ((0, 1),), ((0, 2),))): QQ('-12'),
    (((0,), (0,), (-2, 2)), (((2, 0),),)): QQ('-1/4608'),
    (((-5, -3, 1, 5),), (((0, 0), (0, 1)),)): QQ('-5'),
    (((-3, -2, -2, 5),), (((0, 0), (0, 1), (0, 2)),)): QQ('-5'),
    (((0,), (0, 0, 0, 0)), ()): QQ('0'),
    (((-2, -2, -2, 6),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-23/4'),
    (((-2, -2, 0, 0, 4),), (((0, 0),), ((0, 1),))): QQ('-11/3'),
    (((-4, -2, 0, 1, 3),), (((0, 0),), ((0, 1),))): QQ('-4'),
    (((-3, -3, 0, 1, 3),), (((0, 0), (0, 1)),)): QQ('12'),
    (((-2, -2, 2), (-4, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-1'),
    (((-3, -3, -2, 1, 5),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-8'),
    (((-2, -2, -2, 2, 4),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-617/24'),
    (((-2, 2), (-3, -3, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('1/8'),
    (((-2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 1)), ((1, 0), (1, 2)))): QQ('1/8'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('60'),
    (((-2, 2), (-2, -2, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('13/64'),
    (((-2, 2), (-2, -2, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('1/8'),
    (((0,), (0, 0), (0, 0)), ()): QQ('0'),
    (((0,), (-2, 4)), (((1, 0),),)): QQ('23/27648'),
    (((-6, 0, 2, 2),), (((0, 0),),)): QQ('-5'),
    (((0,), (-2, 0, 0, 2)), (((1, 0),),)): QQ('1/192'),
    (((-5, -2, 5),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-2, -2, -2, 0, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-6'),
    (((-3, 0, 1), (-3, -2, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, 2), (-2, -2, 4)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('11/12'),
    (((-2, -2, -2, 0, 1, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('12'),
    (((0,), (-2, 0, 0), (-2, 0, 0)), (((1, 0),), ((2, 0),))): QQ('1/24'),
    (((-5, 0, 3),), (((0, 0),),)): QQ('1'),
    (((-4, -2, 1, 5),), (((0, 0),), ((0, 1),))): QQ('24'),
    (((-2, 2), (-4, -2, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('1/8'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('30'),
    (((-3, -3, -2, 2, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('16'),
    (((-2, 0, 0), (-2, -2, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-1'),
    (((0, 0), (-2, -2, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-5, 5),), (((0, 0),),)): QQ('-4'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 2)), ((1, 0), (1, 1)))): QQ('-1'),
    (((-2, 2, 4),), (((0, 0),),)): QQ('23/9216'),
    (((-3, 0, 3),), (((0, 0),),)): QQ('4/3'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 1)), ((1, 2),))): QQ('1'),
    (((0, 0, 0, 2),), ()): QQ('0'),
    (((-3, -2, -2, 5),), (((0, 0), (0, 2)), ((0, 1),))): QQ('1'),
    (((-2, 2), (-2, -2, 4)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-11/96'),
    (((-2, -2, 2), (-2, -2, 4)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('13/8'),
    (((0,), (-2, -2, 4)), (((1, 0), (1, 1)),)): QQ('-13/192'),
    (((-2, -2, 2), (-4, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('1'),
    (((0,), (-2, -2, -2, 4)), (((1, 0),), ((1, 1), (1, 2)))): QQ('-1/24'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 1)), ((0, 1), (1, 2)), ((1, 0),))): QQ('1'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 2)), ((0, 1),), ((0, 3),))): QQ('-16'),
    (((0,), (-4, 0, 0, 2)), (((1, 0),),)): QQ('1/8'),
    (((-2, 0, 0, 0, 2),), (((0, 0),),)): QQ('1/8'),
    (((-2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('1/8'),
    (((8,),), ()): QQ('339849/504627200'),
    (((-2, 0, 0), (-2, -2, 1, 1)), (((0, 0),), ((1, 0), (1, 1)))): QQ('1'),
    (((0, 0), (-4, 1, 1)), (((1, 0),),)): QQ('0'),
    (((0,), (-4, 4)), (((1, 0),),)): QQ('5/64'),
    (((-6, -2, 2, 4),), (((0, 0), (0, 1)),)): QQ('-5'),
    (((-4, -2, -2, 1, 5),), (((0, 0), (0, 1), (0, 2)),)): QQ('20'),
    (((-2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('1/8'),
    (((-2, -2, 0, 4),), (((0, 0), (0, 1)),)): QQ('-13/4'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 3)), ((0, 1), (0, 2)))): QQ('60'),
    (((-3, -3, 6),), (((0, 0), (0, 1)),)): QQ('335/24'),
    (((-4, 6),), (((0, 0),),)): QQ('-6097/640'),
    (((-4, -2, 0, 4),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 1), (1, 2)),)): QQ('4'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 1)), ((0, 1), (1, 0), (1, 2)))): QQ('-4'),
    (((-2, -2, -2, 1, 5),), (((0, 0), (0, 1), (0, 2)),)): QQ('36'),
    (((0,), (4,)), ()): QQ('-305/13934592'),
    (((-3, -3, -2, 1, 5),), (((0, 0), (0, 1), (0, 2)),)): QQ('20'),
    (((-6, -2, 2, 4),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((0, 0), (-2, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, -2, 0, 1, 3),), (((0, 0), (0, 1)),)): QQ('8/3'),
    (((0, 0), (-4, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-4, -2, -2, 6),), (((0, 0), (0, 1)), ((0, 2),))): QQ('1'),
    (((-2, 1, 5),), (((0, 0),),)): QQ('0'),
    (((-2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('1/8'),
    (((0,), (-2, 0, 0, 0, 0)), (((1, 0),),)): QQ('-1/24'),
    (((-2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('1/8'),
    (((-2, -2, -2, 1, 5),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-30'),
    (((-2, 2), (-4, 4)), (((0, 0), (1, 0)),)): QQ('-15/64'),
    (((0,), (-2, -2, 4)), (((1, 0),), ((1, 1),))): QQ('11/288'),
    (((-2, -2, 2), (-2, -2, 2)), (((0, 0), (0, 1)), ((1, 0), (1, 1)))): QQ('-1'),
    (((-2, 0, 0, 0, 0, 0),), (((0, 0),),)): QQ('-1'),
    (((-2, 0, 0), (-2, 2)), (((0, 0),), ((1, 0),))): QQ('1/8'),
    (((0,), (0,), (2,)), ()): QQ('-1/368640'),
    (((-2, 0, 0, 4),), (((0, 0),),)): QQ('-23/1152'),
    (((-6, 0, 0, 4),), (((0, 0),),)): QQ('-5'),
    (((-4, -2, 6),), (((0, 0),), ((0, 1),))): QQ('-27/4'),
    (((0, 0), (0, 0, 0)), ()): QQ('0'),
    (((-4, -4, 1, 5),), (((0, 0), (0, 1)),)): QQ('-5'),
    (((-2, 0, 0), (-2, 0, 0, 0)), (((0, 0),), ((1, 0),))): QQ('1'),
    (((-3, -2, -2, 5),), (((0, 0), (0, 1)), ((0, 2),))): QQ('1'),
    (((-3, -3, 2, 4),), (((0, 0), (0, 1)),)): QQ('-95/4'),
    (((-2, -2, -2, 0, 4),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-3'),
    (((-2, -2, -2, 6),), (((0, 0),), ((0, 1), (0, 2)))): QQ('401/24'),
    (((-2, 0, 0), (-2, 0, 2)), (((0, 0),), ((1, 0),))): QQ('-1/8'),
    (((-6, -2, 6),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-3, -2, -2, 5),), (((0, 0),), ((0, 1), (0, 2)))): QQ('2'),
    (((2,), (-2, 2)), (((1, 0),),)): QQ('-1/5120'),
    (((-4, 1, 5),), (((0, 0),),)): QQ('141/10'),
    (((0,), (-2, -2, -2, 4)), (((1, 0), (1, 1), (1, 2)),)): QQ('1/6'),
    (((-2, 2), (-2, -2, 4)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-11/96'),
    (((-6, 0, 1, 3),), (((0, 0),),)): QQ('-5'),
    (((-4, -4, 2, 4),), (((0, 0),), ((0, 1),))): QQ('2'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 3)), ((0, 1), (0, 2)))): QQ('48'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('-21'),
    (((-6, -2, 1, 5),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-4, -2, -2, 1, 5),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-12'),
    (((-2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('1/8'),
    (((-2, -2, -2, 2, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-617/24'),
    (((0, 0), (-2, -2, 1, 1)), (((1, 0),), ((1, 1),))): QQ('0'),
    (((0, 0), (-2, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-4, -2, -2, 2, 4),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('2'),
    (((-2, -2, 2), (-3, -3, 4)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, 0, 0), (2,)), (((0, 0),),)): QQ('1/640'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((0, 1), (1, 0), (1, 1)))): QQ('-4'),
    (((-3, -2, 0, 3),), (((0, 0), (0, 1)),)): QQ('-3'),
    (((-3, -3, -2, 6),), (((0, 0), (0, 1)), ((0, 2),))): QQ('1'),
    (((-2, -2, 1, 5),), (((0, 0),), ((0, 1),))): QQ('21/10'),
    (((-2, -2, 2, 4),), (((0, 0), (0, 1)),)): QQ('-1193/576'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('-60'),
    (((-4, -2, 2, 4),), (((0, 0), (0, 1)),)): QQ('-251/8'),
    (((-2, -2, -2, 4),), (((0, 0), (0, 2)), ((0, 1),))): QQ('1'),
    (((-2, -2, 0, 4),), (((0, 0),), ((0, 1),))): QQ('11/6'),
    (((-5, -3, 6),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-2, -2, 2), (-4, 4)), (((0, 0), (0, 1), (1, 0)),)): QQ('15/8'),
    (((-2, 6),), (((0, 0),),)): QQ('-2837/414720'),
    (((0, 0), (1, 1)), ()): QQ('0'),
    (((0, 0), (2,)), ()): QQ('0'),
    (((2,), (-2, -2, 2)), (((1, 0), (1, 1)),)): QQ('1/640'),
    (((0, 0, 0, 0, 0),), ()): QQ('0'),
    (((-2, -2, 2, 4),), (((0, 0),), ((0, 1),))): QQ('89/48'),
    (((-6, 0, 4),), (((0, 0),),)): QQ('1'),
    (((-4, 0, 0, 0, 2),), (((0, 0),),)): QQ('9'),
    (((-4, -2, -2, 2, 4),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-15'),
    (((-2, -2, 2), (-2, 4)), (((0, 0), (0, 1), (1, 0)),)): QQ('23/1152'),
    (((-4, 2, 4),), (((0, 0),),)): QQ('12881/1152'),
    (((-8, 1, 5),), (((0, 0),),)): QQ('1'),
    (((-4, 0, 4),), (((0, 0),),)): QQ('45/8'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 1)), ((1, 2),))): QQ('-1'),
    (((-2, 0, 0), (1, 1)), (((0, 0),),)): QQ('0'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 1)), ((1, 0), (1, 2)))): QQ('-1'),
    (((-4, -3, 5),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-4, -4, 2, 4),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((0, 2, 2),), ()): QQ('0'),
    (((0, 0), (-2, 2)), (((1, 0),),)): QQ('0'),
    (((-2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('-1/2'),
    (((-2, 0, 0), (-2, -2, 1, 1)), (((0, 0),), ((1, 0),), ((1, 1),))): QQ('-1'),
    (((0, 1, 3),), ()): QQ('0'),
    (((1, 5),), ()): QQ('0'),
    (((-4, -2, 0, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-4'),
    (((-4, -2, -2, 1, 5),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-8'),
    (((-2, 0, 0), (-4, 1, 1)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-3, 5),), (((0, 0),),)): QQ('-21/20'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 3)), ((0, 1),), ((0, 2),))): QQ('-16'),
    (((-6, -2, 1, 5),), (((0, 0), (0, 1)),)): QQ('-5'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((0, 1), (1, 0)), ((1, 1),))): QQ('1'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((0, 1), (1, 1)), ((1, 0),))): QQ('1'),
    (((-6, 2, 4),), (((0, 0),),)): QQ('79/4'),
    (((-3, -3, 1, 5),), (((0, 0), (0, 1)),)): QQ('-33'),
    (((-6, 1, 5),), (((0, 0),),)): QQ('26'),
    (((0,), (0, 0, 2)), ()): QQ('0'),
    (((-2, 0, 2, 2),), (((0, 0),),)): QQ('-1/64'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 1), (0, 3)), ((0, 2),))): QQ('36'),
    (((-2, -2, 0, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-2'),
    (((-2, -2, -2, 0, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('12'),
    (((-3, -2, 5),), (((0, 0),), ((0, 1),))): QQ('-3'),
    (((0,), (0, 0), (-2, 0, 0)), (((2, 0),),)): QQ('0'),
    (((-2, -2, -2, -2, 6),), (((0, 0),), ((0, 1), (0, 2), (0, 3)))): QQ('-10'),
    (((-4, -2, 2, 4),), (((0, 0),), ((0, 1),))): QQ('421/24'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 1)), ((0, 2), (0, 3)))): QQ('60'),
    (((-4, -2, -2, 6),), (((0, 0),), ((0, 1), (0, 2)))): QQ('3'),
    (((-2, 0, 0), (-4, 0, 2)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 0, 1, 3),), (((0, 0),), ((0, 1),))): QQ('-8/3'),
    (((-4, -2, -2, 6),), (((0, 0), (0, 1), (0, 2)),)): QQ('-6'),
    (((-4, -4, 1, 5),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-2, 0, 0), (-2, 1, 1)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((0, 4),), ()): QQ('0'),
    (((0,), (-3, -3, 4)), (((1, 0), (1, 1)),)): QQ('-1/24'),
    (((-2, 2), (-2, 4)), (((0, 0), (1, 0)),)): QQ('-23/9216'),
    (((-2, -2, -2, 2, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-4'),
    (((0, 0), (0, 2)), ()): QQ('0'),
    (((-2, -2, -2, 6),), (((0, 0), (0, 1), (0, 2)),)): QQ('-155/6'),
    (((-2, -2, -2, 2, 4),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('57/4'),
    (((-5, -3, 2, 4),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((0, 0), (-2, -2, 1, 1)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, 2), (-2, 2)), (((0, 0),), ((1, 0),))): QQ('-1/64'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0),), ((0, 1),), ((0, 2), (0, 3)))): QQ('-16'),
    (((-2, -2, 2), (-2, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('13/8'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0),), ((0, 1), (0, 2), (0, 3)))): QQ('36'),
    (((-4, -2, 6),), (((0, 0), (0, 1)),)): QQ('395/24'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('-72'),
    (((-8, 2, 4),), (((0, 0),),)): QQ('1'),
    (((-2, -2, -2, 0, 1, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('-18'),
    (((-4, -2, -2, 1, 5),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-8'),
    (((0,), (-4, -2, 4)), (((1, 0), (1, 1)),)): QQ('-1/24'),
    (((-2, -2, 6),), (((0, 0),), ((0, 1),))): QQ('-3487/1440'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('36'),
    (((-2, 0, 0), (0, 0, 0)), (((0, 0),),)): QQ('0'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),))): QQ('-16'),
    (((-3, -2, 5),), (((0, 0), (0, 1)),)): QQ('6'),
    (((-2, -2, 2), (-2, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-13/8'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 3)), ((0, 1),), ((0, 2),))): QQ('2'),
    (((-4, -2, -2, 2, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-7'),
    (((-2, 0, 1, 3),), (((0, 0),),)): QQ('0'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 2), (0, 3)), ((0, 1),))): QQ('36'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 1), (1, 2)))): QQ('-4'),
    (((2, 4),), ()): QQ('0'),
    (((-3, 0, 1), (-3, 3)), (((0, 0), (1, 0)),)): QQ('2/3'),
    (((-4, -4, 6),), (((0, 0), (0, 1)),)): QQ('1'),
    (((0, 0, 4),), ()): QQ('0'),
    (((-4, 0, 2, 2),), (((0, 0),),)): QQ('-31/4'),
    (((0,), (0,), (0, 0, 0)), ()): QQ('0'),
    (((0,), (0,), (1, 1)), ()): QQ('0'),
    (((0,), (0,), (0,), (0, 0)), ()): QQ('0'),
    (((0, 0, 0), (2,)), ()): QQ('0'),
    (((-2, -2, -2, 8),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-2583/32'),
    (((0,), (0, 0), (2,)), ()): QQ('0'),
    (((0,), (0,), (0,), (0,)), ()): QQ('-1/331776'),
    (((-2, -2, -2, -2, 8),), (((0, 0),), ((0, 1),), ((0, 2),), ((0, 3),))): QQ('-39'),
    (((0,), (0, 4)), ()): QQ('0'),
    (((2,), (0, 2)), ()): QQ('0'),
    (((-4, -4, 8),), (((0, 0),), ((0, 1),))): QQ('-141/4'),
    (((0,), (0,), (0, 2)), ()): QQ('0'),
    (((-6, 8),), (((0, 0),),)): QQ('-22275/128'),
    (((-6, -2, 8),), (((0, 0),), ((0, 1),))): QQ('-85/4'),
    (((0, 6),), ()): QQ('0'),
    (((-2, -2, 8),), (((0, 0),), ((0, 1),))): QQ('-86697/17920'),
    (((0,), (2, 2)), ()): QQ('0'),
    (((0,), (1, 3)), ()): QQ('0'),
    (((1, 1), (2,)), ()): QQ('0'),
    (((0, 0), (4,)), ()): QQ('0'),
    (((-2, 8),), (((0, 0),),)): QQ('7083/5734400'),
    (((-4, -2, -2, 8),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-129/4'),
    (((-4, -2, 8),), (((0, 0),), ((0, 1),))): QQ('-21073/160'),
    (((3, 3),), ()): QQ('0'),
    (((-8, 8),), (((0, 0),),)): QQ('-147/8'),
    (((-4, 8),), (((0, 0),),)): QQ('-1749717/35840'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 1), (1, 2)), ((1, 0),))): QQ('-1'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0),), ((0, 1), (0, 2)), ((0, 3),))): QQ('-16'),
    (((-2, -2, 0, 0, 0, 2),), (((0, 0), (0, 1)),)): QQ('-8'),
    (((-2, 0, 0), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1/8'),
    (((-2, 0, 0, 0), (-2, 2)), (((0, 0), (1, 0)),)): QQ('-1/8'),
    (((-2, 0, 0), (-2, -2, 0, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('2'),
    (((-2, 0, 0), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((0,), (-2, -2, 0, 0, 2)), (((1, 0), (1, 1)),)): QQ('-1/6'),
    (((-2, -2, -2, 0, 0, 4),), (((0, 0),), ((0, 1), (0, 2)))): QQ('9'),
    (((-4, -2, 0, 0, 4),), (((0, 0), (0, 1)),)): QQ('16'),
    (((-2, -2, 0, 2, 2),), (((0, 0), (0, 1)),)): QQ('3'),
    (((-2, 2), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('1/64'),
    (((-2, 0, 0), (-4, -2, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, 0, 0), (-2, -2, 4)), (((0, 0), (1, 1)), ((1, 0),))): QQ('11/12'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('-1'),
    (((-2, 0, 0), (-2, 4)), (((0, 0), (1, 0)),)): QQ('23/1152'),
    (((0,), (-2, 0, 0), (-2, 2)), (((1, 0), (2, 0)),)): QQ('-1/192'),
    (((-2, 0, 0), (-3, -3, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, 2), (-4, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1'),
    (((-2, 0, 0), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 0, 0, 0), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, 0, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-2'),
    (((-4, -2, -2, 6),), (((0, 0), (0, 2)), ((0, 1),))): QQ('1'),
    (((-2, -2, 2), (-2, -2, 0, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),))): QQ('2'),
    (((-2, 2), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, -2, 2), (-2, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1/8'),
    (((-2, -2, -2, 0, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('-24'),
    (((-2, 2), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1/4'),
    (((0,), (0,), (-2, -2, 2)), (((2, 0), (2, 1)),)): QQ('1/576'),
    (((-2, 0, 0), (-2, 0, 0, 0)), (((0, 0), (1, 0)),)): QQ('1'),
    (((0,), (-2, 0, 0), (-2, -2, 2)), (((1, 0), (2, 0), (2, 1)),)): QQ('1/24'),
    (((-2, -2, -2, 0, 2, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('12'),
    (((-3, -3, 0, 0, 4),), (((0, 0), (0, 1)),)): QQ('16'),
    (((-2, -2, -2, 0, 4),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-3'),
    (((0,), (-2, 0, 0), (-2, 0, 0)), (((1, 0), (2, 0)),)): QQ('1/24'),
    (((-3, -3, 0, 2, 2),), (((0, 0), (0, 1)),)): QQ('8'),
    (((-2, -2, -2, 0, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-3'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('4'),
    (((-2, 0, 0), (-2, -2, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('-13/8'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('-1'),
    (((0, 0), (-2, -2, 0, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 2), (0, 3)), ((0, 1),))): QQ('-10'),
    (((-2, -2, -2, 0, 0, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('-36'),
    (((0,), (-2, -2, -2, 4)), (((1, 0), (1, 2)), ((1, 1),))): QQ('-1/24'),
    (((-4, -2, 0, 2, 2),), (((0, 0), (0, 1)),)): QQ('12'),
    (((-2, -2, 0, 0, 4),), (((0, 0), (0, 1)),)): QQ('13/2'),
    (((-2, -2, -2, 6),), (((0, 0), (0, 1)), ((0, 2),))): QQ('401/24'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 3)), ((0, 1), (0, 2)))): QQ('-21'),
    (((-2, 0, 0), (-4, 4)), (((0, 0), (1, 0)),)): QQ('15/8'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0),), ((0, 1),), ((0, 2),), ((0, 3),))): QQ('6'),
    (((-2, -2, 3, 3),), (((0, 0),), ((0, 1),))): QQ('16/9'),
    (((-2, -2, -2, 3, 3),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('12'),
    (((-8, 3, 3),), (((0, 0),),)): QQ('1'),
    (((-6, -2, 3, 3),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-4, -2, -2, 3, 3),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('2'),
    (((-4, -4, 3, 3),), (((0, 0),), ((0, 1),))): QQ('3'),
    (((-4, -2, 3, 3),), (((0, 0),), ((0, 1),))): QQ('47/3'),
    (((-2, 3, 3),), (((0, 0),),)): QQ('0'),
    (((-4, 3, 3),), (((0, 0),),)): QQ('100/9'),
    (((-6, 3, 3),), (((0, 0),),)): QQ('53/3'),
    (((-4, -2, 3, 3),), (((0, 0), (0, 1)),)): QQ('-29'),
    (((-4, -4, 3, 3),), (((0, 0), (0, 1)),)): QQ('-3'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0),), ((0, 1), (0, 3)), ((0, 2),))): QQ('-14'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('54'),
    (((-3, -3, 3, 3),), (((0, 0), (0, 1)),)): QQ('-49/2'),
    (((-5, -3, 3, 3),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((-2, -2, -2, 3, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('28'),
    (((-3, -3, -2, 3, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('18'),
    (((-3, 3), (-3, -2, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('2/3'),
    (((-2, -2, 3, 3),), (((0, 0), (0, 1)),)): QQ('-16/9'),
    (((-2, -2, -2, 3, 3),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-68/3'),
    (((-4, -2, -2, 3, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-6'),
    (((-3, -2, 3), (-3, -2, 3)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('1'),
    (((-4, -2, -2, 3, 3),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-18'),
    (((-6, -2, 3, 3),), (((0, 0), (0, 1)),)): QQ('-5'),
    (((-3, -2, 3), (-3, -2, 3)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-1'),
    (((-3, 3), (-3, 3)), (((0, 0), (1, 0)),)): QQ('-4/9'),
    (((-3, -3, -2, 3, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-6'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0), (0, 2), (0, 3)), ((0, 1),))): QQ('30'),
    (((-4, -2, -2, 3, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('18'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('-54'),
    (((-2, -2, -2, -2, 6),), (((0, 0),), ((0, 1),), ((0, 2), (0, 3)))): QQ('2'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 1), (0, 3)), ((0, 2),))): QQ('-10'),
    (((-2, -2, -2, 0, 1, 3),), (((0, 0), (0, 2)), ((0, 1),))): QQ('12'),
    (((1, 2, 3),), ()): QQ('0'),
    (((0, 0, 0, 1, 1),), ()): QQ('0'),
    (((0, 0), (0, 1, 1)), ()): QQ('0'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0),), ((0, 1),), ((0, 2),), ((0, 3),))): QQ('-24'),
    (((0, 1, 1, 2),), ()): QQ('0'),
    (((-4, -4, 1, 2, 3),), (((0, 0),), ((0, 1),))): QQ('-14'),
    (((-4, -2, -2, 1, 2, 3),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-16'),
    (((-2, -2, -2, 1, 2, 3),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-32'),
    (((-2, 1, 2, 3),), (((0, 0),),)): QQ('0'),
    (((0, 0, 1, 3),), ()): QQ('0'),
    (((-4, 1, 2, 3),), (((0, 0),),)): QQ('-215/12'),
    (((-4, -2, 1, 2, 3),), (((0, 0),), ((0, 1),))): QQ('-105/2'),
    (((-6, 1, 2, 3),), (((0, 0),),)): QQ('-1615/24'),
    (((-8, 1, 2, 3),), (((0, 0),),)): QQ('-7'),
    (((-6, -2, 1, 2, 3),), (((0, 0),), ((0, 1),))): QQ('-10'),
    (((-2, -2, 1, 2, 3),), (((0, 0),), ((0, 1),))): QQ('-5/3'),
    (((-5, 1, 2), (-3, -2, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, 2), (-3, 3)), (((0, 0), (0, 1), (1, 0)),)): QQ('2/3'),
    (((-2, 0, 0, 0), (-2, 2)), (((0, 0),), ((1, 0),))): QQ('-1/8'),
    (((-2, -2, 2), (-4, -2, 1, 3)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-3, -2, -2, 2, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-5'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 1)), ((0, 1), (1, 0)), ((1, 2),))): QQ('-4'),
    (((-3, -2, -2, 2, 3),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('2'),
    (((-2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('3/4'),
    (((-2, -2, 0, 1, 1, 2),), (((0, 0),), ((0, 1),))): QQ('5/2'),
    (((-3, -2, 1, 2), (-3, -2, 3)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-2'),
    (((-3, 1, 2), (-3, -2, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('-5/8'),
    (((-2, 2), (-4, -2, 1, 3)), (((0, 0), (1, 0)), ((1, 1),))): QQ('1/8'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('-102'),
    (((-3, -2, 1, 2), (-3, 3)), (((0, 0), (1, 0)), ((0, 1),))): QQ('2/3'),
    (((-5, -2, 2, 3),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((-2, -2, 2), (-4, -2, 1, 3)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('3'),
    (((-6, -2, 1, 2, 3),), (((0, 0), (0, 1)),)): QQ('25'),
    (((-3, -2, 2, 3),), (((0, 0),), ((0, 1),))): QQ('16/3'),
    (((-5, -3, 1, 2, 3),), (((0, 0), (0, 1)),)): QQ('20'),
    (((0,), (-6, 2, 2)), (((1, 0),),)): QQ('-1/24'),
    (((-3, 2, 3),), (((0, 0),),)): QQ('5/6'),
    (((-4, -2, 0, 0, 1, 3),), (((0, 0),), ((0, 1),))): QQ('16'),
    (((-3, 1, 2), (-3, 3)), (((0, 0), (1, 0)),)): QQ('5/12'),
    (((-2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('-1/2'),
    (((-3, -2, 1, 2), (-3, -2, 3)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-1'),
    (((-2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('-1/2'),
    (((0, 0), (-4, 0, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-5, 2, 3),), (((0, 0),),)): QQ('191/24'),
    (((-2, 0, 0, 1, 3),), (((0, 0),),)): QQ('0'),
    (((-2, -2, 2), (-3, -3, 1, 3)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, -2, 2), (-2, 1, 3)), (((0, 0), (0, 1), (1, 0)),)): QQ('0'),
    (((0,), (-4, 1, 3)), (((1, 0),),)): QQ('-5/36'),
    (((-5, -2, 2, 3),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-2, 2), (-4, -2, 1, 3)), (((0, 0), (1, 1)), ((1, 0),))): QQ('1/8'),
    (((-2, -2, 2), (-4, -2, 1, 3)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-3'),
    (((-2, 2), (-4, 1, 3)), (((0, 0), (1, 0)),)): QQ('5/12'),
    (((-4, -2, -2, 1, 2, 3),), (((0, 0), (0, 2)), ((0, 1),))): QQ('36'),
    (((-6, 0, 1, 1, 2),), (((0, 0),),)): QQ('25'),
    (((-2, 0, 0), (-4, 0, 1, 1)), (((0, 0),), ((1, 0),))): QQ('3'),
    (((-2, -2, 2), (-3, -2, 3)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('1'),
    (((0,), (-4, 2, 2)), (((1, 0),),)): QQ('-31/288'),
    (((-2, 2), (-6, 1, 3)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-3, -2, -2, 2, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('12'),
    (((0, 0, 0), (-2, 2)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0, 0), (2,)), (((0, 0),),)): QQ('-1/640'),
    (((-3, -2, 1, 2), (-3, 3)), (((0, 0), (0, 1), (1, 0)),)): QQ('-4/3'),
    (((-4, 0, 1, 1, 2),), (((0, 0),),)): QQ('129/8'),
    (((-2, 1, 1), (-2, 2)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((-2, -2, 1, 1), (2,)), (((0, 0),), ((0, 1),))): QQ('1/640'),
    (((-4, -3, 2, 3),), (((0, 0),), ((0, 1),))): QQ('2'),
    (((-7, 2, 3),), (((0, 0),),)): QQ('1'),
    (((-2, -2, 2), (-6, 1, 3)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1'),
    (((-2, 2), (-4, 0, 2)), (((0, 0),), ((1, 0),))): QQ('1/8'),
    (((-2, -2, 2), (-2, -2, 1, 3)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('-4/3'),
    (((0,), (-6, 1, 3)), (((1, 0),),)): QQ('-1/24'),
    (((-2, -2, -2, 1, 2, 3),), (((0, 0),), ((0, 1), (0, 2)))): QQ('257/6'),
    (((-2, 2), (-3, -3, 1, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('-3/8'),
    (((-2, -2, 1, 2, 3),), (((0, 0), (0, 1)),)): QQ('5/3'),
    (((-2, 2), (-2, -2, 1, 3)), (((0, 0), (1, 1)), ((1, 0),))): QQ('1/6'),
    (((-2, -2, 2), (-4, -2, 1, 3)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-2, -2, 2), (-4, 1, 3)), (((0, 0), (0, 1), (1, 0)),)): QQ('-10/3'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (0, 1), (1, 1), (1, 2)), ((1, 0),))): QQ('4'),
    (((-4, -3, 2, 3),), (((0, 0), (0, 1)),)): QQ('-3'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 1), (1, 2)), ((0, 1), (1, 0)))): QQ('6'),
    (((-3, -3, -2, 1, 2, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('32'),
    (((0,), (-2, -2, -2, 2, 2)), (((1, 0),), ((1, 1),), ((1, 2),))): QQ('-1/12'),
    (((-2, 2), (-3, 3)), (((0, 0), (1, 0)),)): QQ('-1/12'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0),), ((0, 1), (0, 2)), ((0, 3),))): QQ('64'),
    (((-2, 2), (-2, 0, 2)), (((0, 0),), ((1, 0),))): QQ('1/64'),
    (((-4, -2, -2, 1, 2, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('-66'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (0, 1), (1, 0), (1, 1), (1, 2)),)): QQ('-6'),
    (((-5, 1, 2), (-3, 3)), (((0, 0), (1, 0)),)): QQ('2/3'),
    (((-2, 2), (-3, -2, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('1/8'),
    (((-2, -2, -2, 0, 1, 1, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('18'),
    (((-3, -2, 1, 2), (-3, -2, 3)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 2), (-2, -2, 1, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1/6'),
    (((0,), (0,), (-2, -2, 1, 1)), (((2, 0),), ((2, 1),))): QQ('1/576'),
    (((-2, -2, 1, 1), (-2, 2)), (((0, 0),), ((0, 1),), ((1, 0),))): QQ('1/8'),
    (((-4, -2, 0, 1, 1, 2),), (((0, 0),), ((0, 1),))): QQ('24'),
    (((-2, -2, 0, 0, 0, 1, 1),), (((0, 0),), ((0, 1),))): QQ('-8'),
    (((-2, -2, 2), (-3, -2, 3)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-1'),
    (((-3, -2, 2, 3),), (((0, 0), (0, 1)),)): QQ('-193/24'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('144'),
    (((-3, -3, -2, 1, 2, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('-60'),
    (((0,), (-4, -2, 2, 2)), (((1, 0),), ((1, 1),))): QQ('-1/24'),
    (((-2, 0, 1, 1, 2),), (((0, 0),),)): QQ('0'),
    (((0,), (-4, -2, 1, 3)), (((1, 0),), ((1, 1),))): QQ('-1/24'),
    (((0,), (-2, 1, 3)), (((1, 0),),)): QQ('0'),
    (((1, 1), (-2, 2)), (((1, 0),),)): QQ('0'),
    (((-2, 1, 1), (2,)), (((0, 0),),)): QQ('0'),
    (((-4, -2, -2, 1, 2, 3),), (((0, 0),), ((0, 1), (0, 2)))): QQ('60'),
    (((0,), (-2, 2, 2)), (((1, 0),),)): QQ('-1/1536'),
    (((-2, -2, 2), (-2, -2, 1, 3)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('4/3'),
    (((-4, -4, 1, 2, 3),), (((0, 0), (0, 1)),)): QQ('18'),
    (((-4, -2, 1, 2, 3),), (((0, 0), (0, 1)),)): QQ('147/2'),
    (((-2, 0, 0), (-2, 0, 1, 1)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((0, 0), (-2, -2, 0, 1, 1)), (((1, 0),), ((1, 1),))): QQ('0'),
    (((-4, 0, 0, 1, 3),), (((0, 0),),)): QQ('30'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0), (0, 1)), ((0, 2), (0, 3)))): QQ('-136'),
    (((0, 0), (-2, 0, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0), (0, 1, 1)), (((0, 0),),)): QQ('0'),
    (((-2, -2, 0, 0, 1, 3),), (((0, 0),), ((0, 1),))): QQ('16/3'),
    (((0,), (-2, -2, 1, 3)), (((1, 0),), ((1, 1),))): QQ('-1/18'),
    (((-2, 0, 0), (-2, -2, 0, 1, 1)), (((0, 0),), ((1, 0),), ((1, 1),))): QQ('2'),
    (((0,), (0,), (-4, 1, 1)), (((2, 0),),)): QQ('1/576'),
    (((-4, 0, 0, 0, 1, 1),), (((0, 0),),)): QQ('-27'),
    (((-2, 2), (-4, -2, 1, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('-3/8'),
    (((-2, -2, 2), (-2, -2, 1, 3)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-4/3'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (0, 1), (1, 2)), ((1, 0), (1, 1)))): QQ('4'),
    (((-2, -2, -2, 1, 2, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('-193/4'),
    (((-2, 0, 0, 0, 1, 1),), (((0, 0),),)): QQ('0'),
    (((0,), (0,), (-2, 1, 1)), (((2, 0),),)): QQ('0'),
    (((-6, 0, 0, 1, 3),), (((0, 0),),)): QQ('25'),
    (((-4, 1, 1), (-2, 2)), (((0, 0),), ((1, 0),))): QQ('1/8'),
    (((-3, -3, 1, 2, 3),), (((0, 0), (0, 1)),)): QQ('361/6'),
    (((2,), (-4, 0, 2)), (((1, 0),),)): QQ('1/640'),
    (((-2, 2), (0, 2)), (((0, 0),),)): QQ('0'),
    (((2,), (-2, 0, 2)), (((1, 0),),)): QQ('1/5120'),
    (((-3, -2, -2, 2, 3),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-10'),
    (((-2, 2), (-2, 1, 3)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-4, 1, 1), (2,)), (((0, 0),),)): QQ('1/640'),
    (((0,), (-2, -2, 2, 2)), (((1, 0),), ((1, 1),))): QQ('-1/24'),
    (((-2, -2, -2, 0, 1, 3),), (((0, 0),), ((0, 1), (0, 2)))): QQ('12'),
    (((-3, 0, 0, 0, 1),), (((0, 0),),)): QQ('4'),
    (((-2, -2, -2, 0, 0, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('9'),
    (((-3, 0, 1), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-2, 0, 0), (-2, -2, 1, 3)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-4/3'),
    (((0, 0, 0), (-2, -2, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((0,), (-3, -2, 3)), (((1, 0), (1, 1)),)): QQ('-1/24'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0),), ((0, 1), (0, 3)), ((0, 2),))): QQ('-12'),
    (((-2, -2, -2, 0, 0, 1, 3),), (((0, 0), (0, 1), (0, 2)),)): QQ('54'),
    (((0,), (-4, -2, 2, 2)), (((1, 0), (1, 1)),)): QQ('1/8'),
    (((-3, 0, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-3, 0, 1), (-5, 0, 3)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((0, 0), (-2, -2, 0, 1, 1)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-4, 0, 1, 1), (-2, 2)), (((0, 0), (1, 0)),)): QQ('-3/8'),
    (((-3, 0, 0, 1), (-3, -2, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 0, 0, 0), (-2, -2, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('1'),
    (((-2, 0, 0), (-2, -2, 0, 1, 1)), (((0, 0), (1, 0), (1, 1)),)): QQ('-2'),
    (((-2, -2, 2), (-2, -2, 0, 2)), (((0, 0), (0, 1)), ((1, 0), (1, 1)))): QQ('2'),
    (((-3, 0, 0, 1), (-3, 3)), (((0, 0), (1, 0)),)): QQ('-4/3'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0), (0, 1)), ((0, 2), (0, 3)))): QQ('54'),
    (((-5, 0, 1, 2),), (((0, 0),),)): QQ('-4'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (0, 1)), ((1, 0), (1, 1)))): QQ('1'),
    (((-2, 0, 0), (-3, -3, 1, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, 0, 0), (-4, 0, 1, 1)), (((0, 0), (1, 0)),)): QQ('3'),
    (((-2, 0, 0, 0), (-4, 1, 1)), (((0, 0), (1, 0)),)): QQ('1'),
    (((-2, 0, 0), (-3, 0, 1)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, -2, 2), (-4, 0, 2)), (((0, 0), (0, 1)), ((1, 0),))): QQ('-1'),
    (((-2, 1, 1), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-4, -2, 0, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('-36'),
    (((-4, 1, 1), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1/8'),
    (((-2, -2, -2, 0, 0, 1, 3),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-36'),
    (((-4, 1, 1), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, 0, 0), (-4, -2, 1, 3)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-2, 1, 1), (-2, -2, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('0'),
    (((-2, -2, 1, 1), (-2, 2)), (((0, 0), (0, 1)), ((1, 0),))): QQ('-1/8'),
    (((0,), (-3, -3, 2, 2)), (((1, 0), (1, 1)),)): QQ('1/12'),
    (((-2, -2, -2, 3, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-68/3'),
    (((-2, 0, 0), (-6, 1, 3)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((0,), (-3, -3, 1, 3)), (((1, 0), (1, 1)),)): QQ('1/8'),
    (((-3, -2, 0, 1, 2),), (((0, 0),), ((0, 1),))): QQ('-3'),
    (((-2, 0, 0), (-2, -2, 0, 1, 1)), (((0, 0), (1, 1)), ((1, 0),))): QQ('2'),
    (((-2, 0, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-3, 0, 1), (-3, -2, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 0, 0), (-2, 1, 3)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 1, 1), (-4, 0, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('-1'),
    (((-3, 0, 1), (-5, 1, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, 0, 0), (-2, -2, -2, 1, 3)), (((0, 0), (1, 1)), ((1, 0), (1, 2)))): QQ('4'),
    (((0,), (-4, -2, 1, 3)), (((1, 0), (1, 1)),)): QQ('1/8'),
    (((0,), (-3, 3)), (((1, 0),),)): QQ('1/36'),
    (((0,), (-2, -2, 2, 2)), (((1, 0), (1, 1)),)): QQ('1/16'),
    (((-3, -2, 0, 1, 2),), (((0, 0), (0, 1)),)): QQ('6'),
    (((-2, 0, 0), (-3, 0, 1)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-2, 0, 0), (-2, -2, 1, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('4/3'),
    (((-2, -2, -2, 6),), (((0, 0), (0, 2)), ((0, 1),))): QQ('401/24'),
    (((0,), (-2, -2, 1, 3)), (((1, 0), (1, 1)),)): QQ('1/18'),
    (((-2, -2, 1, 1), (-2, -2, 2)), (((0, 0),), ((0, 1),), ((1, 0), (1, 1)))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('2'),
    (((-3, 0, 1), (-3, -2, 0, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0),), ((0, 1), (0, 3)), ((0, 2),))): QQ('-16'),
    (((-2, 0, 0), (-4, -2, 1, 3)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-5, 0, 0, 3),), (((0, 0),),)): QQ('-4'),
    (((0, 0), (-3, 0, 1)), (((1, 0),),)): QQ('0'),
    (((-3, 0, 1, 2),), (((0, 0),),)): QQ('-5/4'),
    (((-4, -2, 0, 0, 1, 3),), (((0, 0), (0, 1)),)): QQ('-48'),
    (((-2, 1, 1), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 0, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('-5/2'),
    (((-2, -2, 0, 1, 1), (-2, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('-1/4'),
    (((-2, 0, 0), (-4, -2, 1, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, -2, -2, 0, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('12'),
    (((-2, 0, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0)), ((1, 1),))): QQ('1'),
    (((-2, 0, 0), (-2, -2, 0, 1, 1)), (((0, 0), (1, 0)), ((1, 1),))): QQ('2'),
    (((-2, 0, 0), (-4, 1, 3)), (((0, 0), (1, 0)),)): QQ('-10/3'),
    (((-3, 0, 1), (-3, 1, 2)), (((0, 0), (1, 0)),)): QQ('-5/8'),
    (((-2, -2, 2), (0, 2)), (((0, 0), (0, 1)),)): QQ('0'),
    (((2,), (-2, -2, 0, 2)), (((1, 0), (1, 1)),)): QQ('-1/320'),
    (((-3, 0, 1), (-3, 0, 3)), (((0, 0), (1, 0)),)): QQ('-4/3'),
    (((-3, -3, 0, 0, 1, 3),), (((0, 0), (0, 1)),)): QQ('-48'),
    (((-2, 0, 0), (-2, -2, -2, 1, 3)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('4'),
    (((-3, 0, 1), (-2, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 1)), ((0, 1), (1, 0)), ((1, 2),))): QQ('1'),
    (((-4, 1, 1), (-2, -2, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-1'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0),), ((0, 1), (0, 2), (0, 3)))): QQ('30'),
    (((0,), (-2, 2), (-2, 2)), (((1, 0), (2, 0)),)): QQ('1/1536'),
    (((-4, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, -2, 1, 1), (-4, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('1'),
    (((-2, -2, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('2'),
    (((-2, -2, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('2'),
    (((-2, -2, 1, 1), (-2, -2, 0, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-2'),
    (((-3, -2, 0, 0, 3),), (((0, 0), (0, 1)),)): QQ('9'),
    (((0,), (0,), (-2, -2, 1, 1)), (((2, 0), (2, 1)),)): QQ('-1/576'),
    (((-3, 0, 0, 3),), (((0, 0),),)): QQ('-8/3'),
    (((-2, -2, 0, 0, 1, 3),), (((0, 0), (0, 1)),)): QQ('-16/3'),
    (((1, 1), (-2, -2, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, 1, 1), (2,)), (((0, 0), (0, 1)),)): QQ('-1/640'),
    (((-2, 0, 0), (-2, 0, 1, 1)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-3, 0, 1), (-3, 0, 0, 1)), (((0, 0), (1, 0)),)): QQ('2'),
    (((-3, -3, 0, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('-32'),
    (((-2, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-2, 0, 0), (-3, -2, 3)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, 0, 0), (-2, -2, 0, 1, 1)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-2'),
    (((-2, 0, 0), (-3, 3)), (((0, 0), (1, 0)),)): QQ('2/3'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0), (1, 1)), ((1, 0), (1, 2)))): QQ('-1'),
    (((0,), (-2, -2, -2, 1, 3)), (((1, 0),), ((1, 1), (1, 2)))): QQ('1/6'),
    (((0,), (-2, -2, -2, 2, 2)), (((1, 0), (1, 1)), ((1, 2),))): QQ('1/6'),
    (((-2, 0, 0, 0), (-2, 1, 1)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 0, 0, 0, 1, 1),), (((0, 0), (0, 1)),)): QQ('8'),
    (((-2, -2, -2, 0, 1, 1, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-30'),
    (((-2, -2, 1, 1), (-2, 0, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('-1/8'),
    (((-2, -2, -2, 1, 5),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-30'),
    (((-2, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, -2, 0, 1, 1, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('36'),
    (((-2, -2, 1, 1), (-2, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('1/8'),
    (((-2, -2, 2), (-2, 0, 2)), (((0, 0), (0, 1)), ((1, 0),))): QQ('-1/8'),
    (((-2, 2), (-2, -2, 0, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-1/4'),
    (((0,), (-2, -2, 2), (-2, -2, 2)), (((1, 0), (2, 1)), ((1, 1), (2, 0)))): QQ('-1/24'),
    (((-2, 0, 0), (-2, -2, -2, 1, 3)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('-6'),
    (((0,), (-2, -2, -2, 2, 2)), (((1, 0), (1, 1), (1, 2)),)): QQ('-1/3'),
    (((0,), (-2, -2, -2, 1, 3)), (((1, 0), (1, 1), (1, 2)),)): QQ('-1/4'),
    (((-2, -2, 0, 1, 1), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-2'),
    (((-2, -2, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('2'),
    (((-2, 0, 1, 1), (-2, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-4, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('3'),
    (((0,), (-2, -2, 2), (-2, -2, 2)), (((1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('1/24'),
    (((-2, -2, 0, 1, 1), (-2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('1/4'),
    (((-2, -2, 2), (-2, -2, 0, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-2'),
    (((0,), (-2, 2), (-2, -2, 2)), (((1, 0), (2, 0), (2, 1)),)): QQ('-1/192'),
    (((-2, 0, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 1)), ((1, 0),))): QQ('1'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('-1'),
    (((-2, -2, -2, 0, 2, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('12'),
    (((-3, -2, -2, 2, 3),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-5'),
    (((-2, -2, 2), (-3, -2, 3)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('1'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0),), ((0, 1), (0, 3)), ((0, 2),))): QQ('64'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 1)), ((0, 1), (1, 0), (1, 2)))): QQ('6'),
    (((-2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('-1/2'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (0, 1), (1, 0), (1, 1)), ((1, 2),))): QQ('4'),
    (((-4, -2, -2, 1, 2, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('36'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0), (0, 1), (0, 3)), ((0, 2),))): QQ('-102'),
    (((-2, -2, -2, 1, 2, 3),), (((0, 0), (0, 2)), ((0, 1),))): QQ('257/6'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 2)), ((0, 1), (1, 1)), ((1, 0),))): QQ('-4'),
    (((-2, -2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (0, 1), (1, 0)), ((1, 1), (1, 2)))): QQ('4'),
    (((-2, 2), (-2, -2, -2, 1, 3)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('-1/2'),
    (((-2, 2), (-2, -2, 1, 3)), (((0, 0), (1, 0)), ((1, 1),))): QQ('1/6'),
    (((-2, 0, 0), (-2, -2, -2, 1, 3)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('4'),
    (((-2, -2, 0, 1, 1), (-2, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('-1/4'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 2)), ((1, 1),))): QQ('1'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 0, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('2'),
    (((-2, -2, 1, 1), (-4, 0, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('-1'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),))): QQ('-14'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 1)), ((0, 2), (0, 3)))): QQ('48'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 2)), ((0, 1),), ((0, 3),))): QQ('2'),
    (((-2, 0, 0), (-2, -2, -2, 1, 3)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('4'),
    (((-2, -2, 1, 1), (-2, 0, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('-1/8'),
    (((-2, -2, -2, 0, 1, 1, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-30'),
    (((-2, -2, -2, -2, 2, 4),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('36'),
    (((0,), (-2, -2, -2, 1, 3)), (((1, 0), (1, 2)), ((1, 1),))): QQ('1/6'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 2), (0, 3)), ((0, 1),))): QQ('36'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('-1'),
    (((1, 1, 4),), ()): QQ('0'),
    (((0,), (0, 0, 1, 1)), ()): QQ('0'),
    (((-4, -2, -2, 1, 1, 4),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-10'),
    (((-4, 1, 1, 4),), (((0, 0),),)): QQ('-7751/384'),
    (((-2, -2, -2, 1, 1, 4),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-169/4'),
    (((-4, -2, 1, 1, 4),), (((0, 0),), ((0, 1),))): QQ('-139/2'),
    (((-2, -2, 1, 1, 4),), (((0, 0),), ((0, 1),))): QQ('-959/576'),
    (((-8, 1, 1, 4),), (((0, 0),),)): QQ('-7'),
    (((-6, -2, 1, 1, 4),), (((0, 0),), ((0, 1),))): QQ('-10'),
    (((-4, -4, 1, 1, 4),), (((0, 0),), ((0, 1),))): QQ('-10'),
    (((-2, 1, 1, 4),), (((0, 0),),)): QQ('0'),
    (((-6, 1, 1, 4),), (((0, 0),),)): QQ('-705/8'),
    (((-5, -2, 1, 4),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((-3, -2, 1, 4),), (((0, 0),), ((0, 1),))): QQ('169/24'),
    (((-3, -3, 1, 1, 4),), (((0, 0), (0, 1)),)): QQ('73'),
    (((-3, -3, -2, 1, 1, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('40'),
    (((-7, 1, 4),), (((0, 0),),)): QQ('1'),
    (((-2, -2, -2, 1, 1, 4),), (((0, 0),), ((0, 1), (0, 2)))): QQ('613/12'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('-11/12'),
    (((-3, 1, 4),), (((0, 0),),)): QQ('959/1152'),
    (((-2, -2, -2, -2, 1, 1, 4),), (((0, 0), (0, 1), (0, 3)), ((0, 2),))): QQ('-108'),
    (((-6, -2, 1, 1, 4),), (((0, 0), (0, 1)),)): QQ('25'),
    (((-4, 1, 1), (-4, -2, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, 1, 1), (-3, -3, 4)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('1'),
    (((0,), (-2, 0, 0, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, -2, 1, 1), (-3, -3, 4)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('-1'),
    (((-4, 1, 1), (-2, 4)), (((0, 0), (1, 0)),)): QQ('23/1152'),
    (((-2, -2, 1, 1), (-2, 4)), (((0, 0), (1, 0)), ((0, 1),))): QQ('23/1152'),
    (((-4, -3, 1, 4),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-2, -2, -2, -2, 1, 1, 4),), (((0, 0), (0, 2)), ((0, 1),), ((0, 3),))): QQ('62'),
    (((-4, 1, 1), (-4, 4)), (((0, 0), (1, 0)),)): QQ('15/8'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 1), (1, 2)), ((0, 1),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('-13/8'),
    (((-3, -2, -2, 1, 4),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-7'),
    (((-2, 1, 1), (-2, 4)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-4, -4, 1, 1, 4),), (((0, 0), (0, 1)),)): QQ('24'),
    (((-4, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('-1'),
    (((-5, -2, 1, 4),), (((0, 0),), ((0, 1),))): QQ('1'),
    (((-3, -2, -2, 1, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-6'),
    (((-4, -3, 1, 4),), (((0, 0), (0, 1)),)): QQ('-4'),
    (((-5, -3, 1, 1, 4),), (((0, 0), (0, 1)),)): QQ('24'),
    (((-2, -2, -2, 1, 1, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('-111/2'),
    (((0,), (-6, 0, 4)), (((1, 0),),)): QQ('-1/24'),
    (((-3, -2, 1, 4),), (((0, 0), (0, 1)),)): QQ('-37/4'),
    (((0,), (-2, -2, 0, 4)), (((1, 0),), ((1, 1),))): QQ('-11/144'),
    (((-5, 1, 4),), (((0, 0),),)): QQ('85/8'),
    (((-3, -3, -2, 1, 1, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('-64'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((0, 1),), ((1, 0), (1, 1)))): QQ('-1'),
    (((-4, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('4'),
    (((-2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('0'),
    (((-2, 1, 1), (-4, 4)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 1, 1), (-4, 4)), (((0, 0), (1, 0)), ((0, 1),))): QQ('15/8'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((0, 1), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-4, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 1)), ((0, 1), (1, 0), (1, 2)))): QQ('4'),
    (((0,), (0,), (-2, 0, 0, 0)), (((2, 0),),)): QQ('-1/576'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-13/8'),
    (((-2, 1, 1), (-2, -2, 4)), (((0, 0), (1, 0)), ((1, 1),))): QQ('0'),
    (((-4, 1, 1), (-2, -2, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('-13/8'),
    (((0,), (-2, 0, 4)), (((1, 0),),)): QQ('-23/27648'),
    (((-4, -2, -2, 1, 1, 4),), (((0, 0), (0, 2)), ((0, 1),))): QQ('41'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 2)), ((1, 1),))): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1), (1, 2)), ((0, 1),))): QQ('4'),
    (((-4, -2, -2, 1, 1, 4),), (((0, 0),), ((0, 1), (0, 2)))): QQ('49'),
    (((-2, -2, 1, 1), (-2, 4)), (((0, 0), (0, 1), (1, 0)),)): QQ('-23/1152'),
    (((-4, 1, 1), (-3, -3, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-4, 1, 1), (-2, -2, 4)), (((0, 0), (1, 0)), ((1, 1),))): QQ('11/12'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('13/8'),
    (((-3, -2, -2, 1, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('12'),
    (((-2, 1, 1), (-2, -2, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-4, -2, -2, 1, 1, 4),), (((0, 0), (0, 1), (0, 2)),)): QQ('-68'),
    (((-2, -2, 1, 1), (-4, -2, 4)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0), (1, 0)), ((0, 1),), ((1, 1),))): QQ('11/12'),
    (((-2, -2, 1, 1), (-4, -2, 4)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-1'),
    (((-2, -2, 1, 1), (-4, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('1'),
    (((-2, -2, 1, 1, 4),), (((0, 0), (0, 1)),)): QQ('959/576'),
    (((0,), (-2, -2, 0, 0, 1, 1)), (((1, 0),), ((1, 1),))): QQ('-1/6'),
    (((-2, 1, 1), (-3, -3, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 0), (1, 1), (1, 2)),)): QQ('-4'),
    (((0,), (-4, 0, 4)), (((1, 0),),)): QQ('-15/64'),
    (((-2, -2, -2, -2, 1, 1, 4),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('144'),
    (((-2, -2, 1, 1), (-4, 4)), (((0, 0), (0, 1), (1, 0)),)): QQ('-15/8'),
    (((-4, -2, 1, 1, 4),), (((0, 0), (0, 1)),)): QQ('693/8'),
    (((-2, -2, -2, -2, 1, 1, 4),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('-124'),
    (((-2, 1, 1), (-4, -2, 4)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 2)), ((1, 0), (1, 1)))): QQ('1'),
    (((0,), (-4, 0, 0, 1, 1)), (((1, 0),),)): QQ('-3/8'),
    (((-2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('0'),
    (((0,), (-2, -2, -2, 0, 4)), (((1, 0), (1, 1)), ((1, 2),))): QQ('1/8'),
    (((0,), (-2, 0, 0), (-4, 1, 1)), (((1, 0), (2, 0)),)): QQ('1/24'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 2)), ((0, 1), (1, 1)))): QQ('-4'),
    (((0,), (-2, 0, 0), (-2, -2, 1, 1)), (((1, 0), (2, 0)), ((2, 1),))): QQ('1/24'),
    (((0,), (-2, -2, 0, 0, 1, 1)), (((1, 0), (1, 1)),)): QQ('1/6'),
    (((0,), (-3, 0, 0, 1)), (((1, 0),),)): QQ('1/12'),
    (((0,), (-2, 0, 0), (-2, 1, 1)), (((1, 0), (2, 0)),)): QQ('0'),
    (((-2, -2, -2, 1, 1, 1, 1),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-24'),
    (((0,), (-3, -3, 0, 4)), (((1, 0), (1, 1)),)): QQ('1/6'),
    (((0,), (-4, -2, 0, 4)), (((1, 0), (1, 1)),)): QQ('1/6'),
    (((0,), (-2, -2, -2, 4)), (((1, 0), (1, 1)), ((1, 2),))): QQ('-1/24'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 2)), ((0, 1),), ((0, 3),))): QQ('-12'),
    (((0,), (-2, -2, -2, 1, 3)), (((1, 0), (1, 1)), ((1, 2),))): QQ('1/6'),
    (((0,), (-2, -2, 0, 4)), (((1, 0), (1, 1)),)): QQ('13/96'),
    (((0,), (-2, 0, 0), (-2, -2, 1, 1)), (((1, 0), (2, 0), (2, 1)),)): QQ('-1/24'),
    (((0,), (-3, 0, 1), (-3, 0, 1)), (((1, 0), (2, 0)),)): QQ('1/24'),
    (((-2, -2, -2, 0, 0, 4),), (((0, 0), (0, 2)), ((0, 1),))): QQ('9'),
    (((0,), (-2, -2, -2, 0, 4)), (((1, 0), (1, 1), (1, 2)),)): QQ('-1/2'),
    (((-2, -2, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('2'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('-10'),
    (((-2, -2, -2, -2, 6),), (((0, 0), (0, 1)), ((0, 2), (0, 3)))): QQ('-21'),
    (((2, 2, 2),), ()): QQ('0'),
    (((0, 0), (0, 0), (0, 0)), ()): QQ('0'),
    (((0, 0), (0, 0, 0, 0)), ()): QQ('0'),
    (((0, 0, 0), (0, 0, 0)), ()): QQ('0'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),), ((0, 3),))): QQ('-24'),
    (((0, 0, 0, 0, 0, 0),), ()): QQ('0'),
    (((0, 0), (0, 0, 2)), ()): QQ('0'),
    (((0, 0, 0, 0, 2),), ()): QQ('0'),
    (((-2, -2, 2, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-7/4'),
    (((-4, -2, -2, 2, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-18'),
    (((-6, -2, 2, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-10'),
    (((0, 0, 2, 2),), ()): QQ('0'),
    (((-4, -2, 2, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-87/2'),
    (((-4, 2, 2, 2),), (((0, 0),),)): QQ('-1009/64'),
    (((-4, -4, 2, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-12'),
    (((-2, -2, -2, 2, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-113/4'),
    (((-8, 2, 2, 2),), (((0, 0),),)): QQ('-7'),
    (((-6, 2, 2, 2),), (((0, 0),),)): QQ('-455/8'),
    (((-2, 2, 2, 2),), (((0, 0),),)): QQ('-1/512'),
    (((-2, -2, 2), (-4, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-3'),
    (((0,), (0,), (-2, 0, 2)), (((2, 0),),)): QQ('1/4608'),
    (((-2, -2, 2), (-4, -2, 2, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-4, -2, -2, 2, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('-72'),
    (((-2, 2), (-6, 2, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 2)), ((1, 1),))): QQ('4'),
    (((-2, 0, 0, 2, 2),), (((0, 0),),)): QQ('1/64'),
    (((-2, -2, 2), (-3, -3, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('2'),
    (((-4, -2, 0, 0, 2, 2),), (((0, 0),), ((0, 1),))): QQ('16'),
    (((-2, -2, 2), (-4, -2, 2, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1), (1, 2)),)): QQ('-8'),
    (((-2, 2), (-4, 2, 2)), (((0, 0), (1, 0)),)): QQ('31/96'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((1, 0),), ((1, 1),))): QQ('1/4'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0), (0, 1)), ((0, 2), (0, 3)))): QQ('-168'),
    (((-2, -2, 2), (-2, 2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1/64'),
    (((-4, -4, 2, 2, 2),), (((0, 0), (0, 1)),)): QQ('18'),
    (((-2, 0, 0), (-2, 0, 0, 2)), (((0, 0),), ((1, 0),))): QQ('1/8'),
    (((-2, 2), (-3, -3, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1/4'),
    (((-2, 2), (-4, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-3/8'),
    (((-2, -2, 2), (-2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-2, -2, 2), (-6, 2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0),), ((0, 1), (0, 2)), ((0, 3),))): QQ('72'),
    (((-2, -2, 2), (-2, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-3/2'),
    (((-2, -2, 2), (-4, 2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-31/12'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),), ((1, 2),))): QQ('1/4'),
    (((-2, 0, 0), (-4, 0, 0, 2)), (((0, 0),), ((1, 0),))): QQ('3'),
    (((-2, 0, 0), (-2, 0, 0, 0, 0)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (0, 1), (1, 1), (2, 0)), ((1, 0), (2, 1)))): QQ('-1'),
    (((-2, -2, 0, 0, 2, 2),), (((0, 0),), ((0, 1),))): QQ('4'),
    (((0,), (0,), (-4, 0, 2)), (((2, 0),),)): QQ('1/576'),
    (((-2, 2), (-2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('1/8'),
    (((-4, -2, 2, 2, 2),), (((0, 0), (0, 1)),)): QQ('135/2'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)), ((1, 2),))): QQ('4'),
    (((-2, -2, 2), (-4, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, 2), (-2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('1/64'),
    (((-2, -2, 2), (-2, -2, 2, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0), (0, 1), (0, 3)), ((0, 2),))): QQ('-120'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0), (1, 2)))): QQ('4'),
    (((-2, 2), (-4, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('1/8'),
    (((0, 0), (-2, 0, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0), (0, 0, 2)), (((0, 0),),)): QQ('0'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('1'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('192'),
    (((-6, 0, 0, 2, 2),), (((0, 0),),)): QQ('25'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((0, 1), (1, 0)), ((1, 1),))): QQ('-4'),
    (((-5, -3, 2, 2, 2),), (((0, 0), (0, 1)),)): QQ('16'),
    (((-4, -2, -2, 2, 2, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('60'),
    (((0, 0), (0, 0), (-2, 0, 0)), (((2, 0),),)): QQ('0'),
    (((-3, -3, -2, 2, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('24'),
    (((-6, -2, 2, 2, 2),), (((0, 0), (0, 1)),)): QQ('25'),
    (((-2, 0, 0, 0, 0, 2),), (((0, 0),),)): QQ('-1/8'),
    (((-2, 2), (-4, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('1/8'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0), (1, 2)))): QQ('8'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('-1/2'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)), ((1, 2),))): QQ('-4'),
    (((-2, 2), (-2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('1/8'),
    (((-3, -3, 2, 2, 2),), (((0, 0), (0, 1)),)): QQ('47'),
    (((0, 0), (-4, 0, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 1)), ((1, 0), (2, 0)))): QQ('1/8'),
    (((-4, 0, 0, 0, 0, 2),), (((0, 0),),)): QQ('-27'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 2)), ((1, 0),), ((1, 1),))): QQ('-2'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('-1/2'),
    (((-2, -2, -2, 2, 2, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('85/2'),
    (((0, 0, 0), (-2, 0, 0, 0)), (((1, 0),),)): QQ('0'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)), ((0, 1), (1, 1)))): QQ('-1'),
    (((-2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('-1/8'),
    (((-2, 2), (-2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-3/16'),
    (((-3, -3, -2, 2, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('-48'),
    (((-2, -2, -2, 0, 0, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('18'),
    (((-4, 0, 0, 2, 2),), (((0, 0),),)): QQ('93/4'),
    (((-2, 0, 0), (0, 0, 0, 0)), (((0, 0),),)): QQ('0'),
    (((0, 0), (-2, 0, 0, 0, 0)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0, 0), (-2, 0, 0, 0)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0)), ((0, 1), (1, 1), (2, 1)))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1), (1, 2)))): QQ('8'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 2)), ((1, 0), (1, 1)))): QQ('4'),
    (((-2, -2, 2), (-2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('3/2'),
    (((-2, 2), (-2, 2), (-2, 2)), (((0, 0), (1, 0), (2, 0)),)): QQ('-1/512'),
    (((-4, -2, -2, 2, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('36'),
    (((-2, 2), (-2, 2, 2)), (((0, 0), (1, 0)),)): QQ('1/512'),
    (((-2, -2, 2), (-2, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-3/2'),
    (((-2, 0, 0, 0, 0, 0, 0),), (((0, 0),),)): QQ('1'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('1'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (2, 0)), ((0, 1), (1, 0), (1, 1), (2, 1)))): QQ('-1'),
    (((0, 0), (-2, 0, 0), (-2, 0, 0)), (((1, 0),), ((2, 0),))): QQ('0'),
    (((-2, -2, -2, 2, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('-53'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('-1/2'),
    (((-2, -2, 2, 2, 2),), (((0, 0), (0, 1)),)): QQ('31/16'),
    (((-2, 0, 0), (-2, 0, 0), (-2, 0, 0)), (((0, 0),), ((1, 0),), ((2, 0),))): QQ('1'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (2, 1)), ((0, 1), (1, 0)), ((1, 1), (2, 0)))): QQ('1'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0), (1, 2)))): QQ('-1/2'),
    (((-2, 0, 0), (-2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-2, 0, 0), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 0)), ((1, 0), (2, 1)))): QQ('-1'),
    (((0,), (-2, -2, -2, 2, 2)), (((1, 0), (1, 2)), ((1, 1),))): QQ('1/6'),
    (((-2, 0, 0), (-2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('-1/8'),
    (((-2, -2, 2), (-2, -2, 0, 0, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-4'),
    (((-2, 0, 0), (-2, 0, 0), (-2, 2)), (((0, 0), (1, 0), (2, 0)),)): QQ('-1/8'),
    (((-2, -2, 2), (-4, 0, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('3'),
    (((-2, 0, 0), (-4, 0, 0, 2)), (((0, 0), (1, 0)),)): QQ('3'),
    (((-2, 0, 0), (-3, -3, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 0, 0, 0, 0), (-2, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, 0, 0), (-4, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, 0, 0), (-2, -2, 0, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-4'),
    (((0, 0), (-2, 0, 0), (-2, -2, 2)), (((1, 0), (2, 0), (2, 1)),)): QQ('0'),
    (((0, 0), (-2, 0, 0), (-2, 0, 0)), (((1, 0), (2, 0)),)): QQ('0'),
    (((-2, 0, 0), (-2, 0, 0), (-2, 0, 0)), (((0, 0), (1, 0)), ((2, 0),))): QQ('1'),
    (((-2, 0, 0), (-4, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-2, 0, 0), (-2, 2), (-2, 2)), (((0, 0), (1, 0), (2, 0)),)): QQ('1/64'),
    (((-2, 0, 0), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('4'),
    (((-2, 0, 0), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),), ((1, 2),))): QQ('-2'),
    (((-2, 0, 0), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('1'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 2)), (((0, 0), (2, 0), (2, 1)), ((1, 0),))): QQ('1'),
    (((0, 0), (-2, -2, 0, 0, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (1, 1), (1, 2)), ((0, 1), (1, 0)))): QQ('-4'),
    (((-2, 0, 0), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('-8'),
    (((-2, 0, 0), (-2, 0, 0, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, -2, 0, 2), (-2, -2, 0, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-4'),
    (((-3, -3, 0, 0, 2, 2),), (((0, 0), (0, 1)),)): QQ('-32'),
    (((-2, 0, 0, 0), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-2'),
    (((-2, 0, 0), (-4, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-2, 2), (-2, 0, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1/64'),
    (((-2, -2, -2, 0, 0, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-36'),
    (((-2, 0, 0), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('4'),
    (((-2, 2), (-4, 0, 0, 2)), (((0, 0), (1, 0)),)): QQ('-3/8'),
    (((-2, -2, 0, 2), (-2, -2, 0, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('4'),
    (((-4, 0, 2), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1/8'),
    (((-4, -2, 0, 0, 2, 2),), (((0, 0), (0, 1)),)): QQ('-48'),
    (((-4, 0, 2), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((0,), (0,), (-2, -2, 0, 2)), (((2, 0), (2, 1)),)): QQ('-1/288'),
    (((-2, 0, 0), (-2, -2, 0, 0, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-4'),
    (((-2, -2, 2), (-2, 0, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('1/8'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('1'),
    (((-2, 0, 2), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('1/4'),
    (((-2, -2, -2, 0, 0, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('72'),
    (((-2, 0, 0), (-2, 0, 0), (-2, 0, 0)), (((0, 0),), ((1, 0), (2, 0)))): QQ('1'),
    (((-2, 0, 0), (-2, 0, 0), (-2, 2)), (((0, 0), (2, 0)), ((1, 0),))): QQ('-1/8'),
    (((-2, -2, 2), (-2, -2, 0, 0, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('4'),
    (((-2, 0, 0), (-2, 0, 0, 0, 0)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, 0, 2), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1/64'),
    (((-2, -2, 0, 0, 2, 2),), (((0, 0), (0, 1)),)): QQ('-6'),
    (((-2, 0, 0), (-2, -2, 4)), (((0, 0), (1, 0)), ((1, 1),))): QQ('11/12'),
    (((0, 0), (-2, 0, 0), (-2, 2)), (((1, 0), (2, 0)),)): QQ('0'),
    (((-4, 0, 2), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 0, 0, 0), (-2, 0, 0, 0)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, 0, 0, 0), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('1'),
    (((-2, -2, 2), (-2, -2, 0, 0, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('4'),
    (((-2, 0, 0, 0, 0), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-2, -2, -2, -2, 6),), (((0, 0),), ((0, 1), (0, 3)), ((0, 2),))): QQ('2'),
    (((-2, 0, 0), (-2, 0, 0), (-2, 0, 0)), (((0, 0), (1, 0), (2, 0)),)): QQ('1'),
    (((-2, 0, 0), (-4, 2, 2)), (((0, 0), (1, 0)),)): QQ('-31/12'),
    (((-2, 0, 0, 0), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, -2, 0, 0, 0, 0, 2),), (((0, 0), (0, 1)),)): QQ('16'),
    (((-2, 0, 0), (-2, 2, 2)), (((0, 0), (1, 0)),)): QQ('-1/64'),
    (((-2, 0, 0), (-6, 2, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, 2), (-2, -2, 0, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('1/2'),
    (((-2, 0, 0), (-2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('3/2'),
    (((-5, -3, 8),), (((0, 0), (0, 1)),)): QQ('469/8'),
    (((-3, -3, -2, -2, 8),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('56'),
    (((-2, -2, -2, 8),), (((0, 0), (0, 1), (0, 2)),)): QQ('-4527/32'),
    (((-6, -4, 8),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-6, -2, 8),), (((0, 0), (0, 1)),)): QQ('581/8'),
    (((-5, -5, 8),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-4, -4, -2, 8),), (((0, 0), (0, 2)), ((0, 1),))): QQ('3'),
    (((-4, -4, 8),), (((0, 0), (0, 1)),)): QQ('1295/24'),
    (((-4, -4, -2, 8),), (((0, 0), (0, 1)), ((0, 2),))): QQ('1'),
    (((-2, -2, -2, -2, -2, 8),), (((0, 0), (0, 1), (0, 3), (0, 4)), ((0, 2),))): QQ('126'),
    (((-4, -2, -2, 8),), (((0, 0),), ((0, 1), (0, 2)))): QQ('1405/8'),
    (((-4, -4, -2, 8),), (((0, 0), (0, 1), (0, 2)),)): QQ('-8'),
    (((-6, 0, 6),), (((0, 0),),)): QQ('875/24'),
    (((-8, -2, 8),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-4, -3, -3, 8),), (((0, 0), (0, 1), (0, 2)),)): QQ('-8'),
    (((-2, 0, 0), (-4, 4)), (((0, 0),), ((1, 0),))): QQ('15/8'),
    (((-6, -2, -2, 8),), (((0, 0),), ((0, 1), (0, 2)))): QQ('5'),
    (((-3, -3, -2, -2, 8),), (((0, 0), (0, 1), (0, 3)), ((0, 2),))): QQ('-14'),
    (((-7, -3, 8),), (((0, 0), (0, 1)),)): QQ('1'),
    (((-4, -2, 8),), (((0, 0), (0, 1)),)): QQ('25807/128'),
    (((-4, -2, -2, 8),), (((0, 0), (0, 2)), ((0, 1),))): QQ('759/8'),
    (((-6, -2, -2, 8),), (((0, 0), (0, 1), (0, 2)),)): QQ('-8'),
    (((-2, 0, 0), (-2, -2, 4)), (((0, 0),), ((1, 0),), ((1, 1),))): QQ('11/12'),
    (((-2, -2, -2, -2, -2, 8),), (((0, 0), (0, 1), (0, 2), (0, 3), (0, 4)),)): QQ('-336'),
    (((-4, -2, -2, -2, 8),), (((0, 0),), ((0, 1), (0, 2), (0, 3)))): QQ('-36'),
    (((-4, -2, -2, -2, 8),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),))): QQ('2'),
    (((-6, -2, -2, 8),), (((0, 0), (0, 1)), ((0, 2),))): QQ('1'),
    (((-4, -2, -2, -2, 8),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('-14'),
    (((-2, -2, -2, -2, 8),), (((0, 0), (0, 2), (0, 3)), ((0, 1),))): QQ('-1245/4'),
    (((-3, -3, -2, 8),), (((0, 0), (0, 1)), ((0, 2),))): QQ('675/8'),
    (((-3, -3, -2, -2, 8),), (((0, 0), (0, 1)), ((0, 2), (0, 3)))): QQ('-41'),
    (((-2, -2, -2, -2, 8),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),))): QQ('333/2'),
    (((-3, -3, 8),), (((0, 0), (0, 1)),)): QQ('20487/128'),
    (((-5, -3, -2, 8),), (((0, 0), (0, 1)), ((0, 2),))): QQ('1'),
    (((-3, -3, -2, -2, 8),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),))): QQ('2'),
    (((-4, -3, -3, 8),), (((0, 0),), ((0, 1), (0, 2)))): QQ('3'),
    (((0,), (0,), (0,), (-2, 0, 0)), (((3, 0),),)): QQ('-1/13824'),
    (((-2, -2, -2, -2, -2, 8),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),), ((0, 4),))): QQ('6'),
    (((-4, 0, 6),), (((0, 0),),)): QQ('18291/640'),
    (((-5, -3, -2, 8),), (((0, 0), (0, 1), (0, 2)),)): QQ('-8'),
    (((-4, -2, -2, -2, 8),), (((0, 0),), ((0, 1), (0, 3)), ((0, 2),))): QQ('6'),
    (((-2, -2, -2, -2, -2, 8),), (((0, 0), (0, 1)), ((0, 2), (0, 4)), ((0, 3),))): QQ('-87'),
    (((-2, -2, 0, 6),), (((0, 0),), ((0, 1),))): QQ('3487/720'),
    (((0, 0), (-4, 4)), (((1, 0),),)): QQ('0'),
    (((-2, -2, -2, -2, -2, 8),), (((0, 0), (0, 2), (0, 4)), ((0, 1),), ((0, 3),))): QQ('-36'),
    (((0,), (-2, 0, 0), (-2, 2)), (((1, 0),), ((2, 0),))): QQ('-1/192'),
    (((-4, -2, -2, -2, 8),), (((0, 0), (0, 3)), ((0, 1), (0, 2)))): QQ('-41'),
    (((-4, -2, 0, 6),), (((0, 0),), ((0, 1),))): QQ('27'),
    (((-4, -2, -2, 8),), (((0, 0), (0, 1), (0, 2)),)): QQ('-847/4'),
    (((-2, -2, -2, 0, 6),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('69/4'),
    (((-2, -2, -2, -2, -2, 8),), (((0, 0), (0, 1)), ((0, 2), (0, 3), (0, 4)))): QQ('276'),
    (((-2, -2, 8),), (((0, 0), (0, 1)),)): QQ('178911/35840'),
    (((0,), (0, 0), (-2, 2)), (((2, 0),),)): QQ('0'),
    (((0,), (-2, 0, 0), (2,)), (((1, 0),),)): QQ('-1/15360'),
    (((-8, 0, 6),), (((0, 0),),)): QQ('1'),
    (((-2, -2, -2, -2, 8),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('-3603/8'),
    (((-2, -2, -2, -2, 8),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('1995/4'),
    (((-2, -2, -2, 8),), (((0, 0),), ((0, 1), (0, 2)))): QQ('76311/640'),
    (((-4, -2, -2, -2, 8),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('56'),
    (((-2, 0, 6),), (((0, 0),),)): QQ('2837/414720'),
    (((0, 0), (-2, -2, 4)), (((1, 0),), ((1, 1),))): QQ('0'),
    (((-2, 0, 0), (-2, 4)), (((0, 0),), ((1, 0),))): QQ('23/1152'),
    (((-3, -3, -2, 8),), (((0, 0), (0, 1), (0, 2)),)): QQ('-735/4'),
    (((0, 0), (-2, 4)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0), (4,)), (((0, 0),),)): QQ('-305/580608'),
    (((-3, -3, -2, 0, 6),), (((0, 0), (0, 1), (0, 2)),)): QQ('30'),
    (((-2, 0, 0), (-4, -2, 4)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-1'),
    (((-2, -2, -2, 1, 5),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-30'),
    (((-4, -4, 0, 6),), (((0, 0), (0, 1)),)): QQ('-6'),
    (((0,), (-2, -2, 2), (-2, -2, 2)), (((1, 0), (2, 0)), ((1, 1), (2, 1)))): QQ('-1/24'),
    (((-5, -3, 0, 6),), (((0, 0), (0, 1)),)): QQ('-6'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0),), ((0, 1), (0, 2), (0, 3)))): QQ('36'),
    (((0, 0), (-2, -2, 4)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-4, -2, 0, 6),), (((0, 0), (0, 1)),)): QQ('-395/6'),
    (((-4, -2, -2, 0, 6),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-5'),
    (((-3, -3, 0, 6),), (((0, 0), (0, 1)),)): QQ('-335/6'),
    (((-2, -2, -2, 0, 6),), (((0, 0), (0, 1), (0, 2)),)): QQ('155/2'),
    (((-2, -2, -2, 3, 3),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-68/3'),
    (((-3, -3, -2, 0, 6),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-5'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0),), ((1, 0),), ((1, 1), (1, 2)))): QQ('-1'),
    (((-4, -2, -2, 0, 6),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-15'),
    (((-2, -2, -2, -2, 0, 6),), (((0, 0), (0, 1), (0, 3)), ((0, 2),))): QQ('40'),
    (((-2, -2, -2, -2, 6),), (((0, 0),), ((0, 1), (0, 2)), ((0, 3),))): QQ('2'),
    (((0,), (-2, -2, -2, 0, 4)), (((1, 0), (1, 2)), ((1, 1),))): QQ('1/8'),
    (((-6, -2, 0, 6),), (((0, 0), (0, 1)),)): QQ('-6'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0), (0, 1), (0, 3)), ((0, 2),))): QQ('30'),
    (((0,), (-2, 0, 0), (-2, -2, 2)), (((1, 0),), ((2, 0), (2, 1)))): QQ('1/24'),
    (((-2, 0, 0), (-2, -2, 4)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-13/8'),
    (((0, 0), (-2, -2, -2, 4)), (((1, 0),), ((1, 1), (1, 2)))): QQ('0'),
    (((-2, 0, 0), (-3, -3, 4)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-1'),
    (((0, 0), (-3, -3, 4)), (((1, 0), (1, 1)),)): QQ('0'),
    (((0, 0), (-2, -2, -2, 4)), (((1, 0), (1, 1), (1, 2)),)): QQ('0'),
    (((0,), (0, 0), (-2, -2, 2)), (((2, 0), (2, 1)),)): QQ('0'),
    (((-4, -2, -2, 0, 6),), (((0, 0), (0, 1), (0, 2)),)): QQ('30'),
    (((0, 0), (-4, -2, 4)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, -2, -2, 0, 6),), (((0, 0), (0, 2)), ((0, 1),), ((0, 3),))): QQ('-8'),
    (((-2, -2, -2, -2, 0, 6),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('-120'),
    (((-2, -2, 0, 6),), (((0, 0), (0, 1)),)): QQ('-5273/960'),
    (((-2, -2, -2, 0, 6),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-401/8'),
    (((-2, -2, -2, -2, 0, 6),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('84'),
    (((-2, 0, 0), (-2, -2, -2, 4)), (((0, 0),), ((1, 0), (1, 1), (1, 2)))): QQ('4'),
    (((1, 1, 2, 2),), ()): QQ('0'),
    (((0,), (0, 0), (0, 0, 0)), ()): QQ('0'),
    (((0,), (0, 0, 0, 0, 0)), ()): QQ('0'),
    (((-4, -4, 1, 1, 2, 2),), (((0, 0),), ((0, 1),))): QQ('78'),
    (((-4, -2, 1, 1, 2, 2),), (((0, 0),), ((0, 1),))): QQ('147'),
    (((-2, -2, -2, 1, 1, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('129/2'),
    (((0, 0), (0, 0, 1, 1)), ()): QQ('0'),
    (((0, 0, 0), (0, 2)), ()): QQ('0'),
    (((0, 0, 0), (1, 1)), ()): QQ('0'),
    (((1, 1), (0, 2)), ()): QQ('0'),
    (((-4, 1, 1, 2, 2),), (((0, 0),),)): QQ('1849/64'),
    (((0,), (1, 1, 2)), ()): QQ('0'),
    (((-2, -2, -2, -2, 1, 1, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),), ((0, 3),))): QQ('144'),
    (((0, 2), (0, 2)), ()): QQ('0'),
    (((0,), (0,), (0, 1, 1)), ()): QQ('0'),
    (((0,), (0, 0, 0, 2)), ()): QQ('0'),
    (((-4, -2, -2, 1, 1, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('110'),
    (((0, 0, 0, 0, 1, 1),), ()): QQ('0'),
    (((1, 1), (1, 1)), ()): QQ('0'),
    (((-6, -2, 1, 1, 2, 2),), (((0, 0),), ((0, 1),))): QQ('75'),
    (((0, 1, 1), (2,)), ()): QQ('0'),
    (((-8, 1, 1, 2, 2),), (((0, 0),),)): QQ('49'),
    (((0, 0, 1, 1, 2),), ()): QQ('0'),
    (((0,), (0, 2, 2)), ()): QQ('0'),
    (((-2, 1, 1, 2, 2),), (((0, 0),),)): QQ('0'),
    (((-6, 1, 1, 2, 2),), (((0, 0),),)): QQ('925/4'),
    (((-2, -2, 1, 1, 2, 2),), (((0, 0),), ((0, 1),))): QQ('25/16'),
    (((-2, 2), (-4, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-3/4'),
    (((-2, 2), (-5, 1, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1/4'),
    (((-5, 1, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-3, -2, 1, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-43/4'),
    (((-2, 2), (-3, -3, 1, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('1'),
    (((-4, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),), ((1, 2),))): QQ('-2'),
    (((-3, -3, -2, 1, 1, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-144'),
    (((-4, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('240'),
    (((-4, 1, 1), (-2, 2, 2)), (((0, 0), (1, 0)),)): QQ('-1/64'),
    (((-2, 0, 0, 0), (-2, 0, 2)), (((0, 0),), ((1, 0),))): QQ('1/8'),
    (((-2, -2, 2), (-2, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('5/4'),
    (((-4, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('-1/8'),
    (((-2, -2, 2), (-3, -2, 1, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-3, -2, 1, 2), (-3, -2, 1, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('2'),
    (((-2, -2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 2), (0, 3)), ((0, 1),))): QQ('312'),
    (((-2, -2, 2), (-5, 1, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1'),
    (((-7, 1, 2, 2),), (((0, 0),),)): QQ('-6'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1), (2, 0), (2, 1)))): QQ('1'),
    (((-3, 1, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-5/8'),
    (((-2, -2, -2, 0, 0, 1, 1, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-54'),
    (((0, 0, 0), (-4, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, 2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('1/64'),
    (((-2, 2), (-4, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('9/8'),
    (((-2, -2, 2), (-4, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('6'),
    (((0,), (-4, 1, 1, 2)), (((1, 0),),)): QQ('43/192'),
    (((-5, 1, 2), (-5, 1, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, -2, 2), (-3, -2, 1, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1),), ((1, 1),))): QQ('-1'),
    (((-2, -2, 2), (-4, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('6'),
    (((-4, -3, 1, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-10'),
    (((-4, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-2, -2, 2), (-3, -2, 1, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-2'),
    (((-5, 1, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((0, 0, 0), (-2, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0, 0), (0, 2)), (((0, 0),),)): QQ('0'),
    (((-3, 1, 2), (-3, 1, 2)), (((0, 0), (1, 0)),)): QQ('-25/64'),
    (((-4, 1, 1), (-4, 0, 2)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-2, 2), (-2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-5/32'),
    (((-5, 1, 2, 2),), (((0, 0),),)): QQ('-21'),
    (((-5, -2, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('16'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((0, 1), (1, 1)), ((1, 0),))): QQ('4'),
    (((-2, 1, 1), (-2, 2), (-2, 2)), (((0, 0), (1, 0), (2, 0)),)): QQ('0'),
    (((-2, -2, 1, 1), (-6, 2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('1'),
    (((0,), (-4, -2, 0, 2, 2)), (((1, 0),), ((1, 1),))): QQ('1/6'),
    (((-2, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('1/8'),
    (((-3, -2, -2, 1, 2, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('28'),
    (((0, 0, 0), (-2, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0, 0), (1, 1)), (((0, 0),),)): QQ('0'),
    (((-3, -2, 1, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('2'),
    (((-2, 2), (-3, -2, 1, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('1/8'),
    (((-2, 1, 1), (-4, 0, 2)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((-4, 1, 1), (-2, 0, 2)), (((0, 0),), ((1, 0),))): QQ('-1/8'),
    (((-5, 1, 2), (-3, 1, 2)), (((0, 0), (1, 0)),)): QQ('-5/8'),
    (((-2, -2, 2), (-2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('5/4'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)), ((0, 1), (1, 1)))): QQ('1'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((1, 0), (1, 2)))): QQ('5/4'),
    (((-3, -3, -2, 1, 1, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('208'),
    (((-2, -2, 1, 1), (-2, 0, 2)), (((0, 0),), ((0, 1),), ((1, 0),))): QQ('-1/8'),
    (((0,), (-2, -2, -2, 1, 1, 2)), (((1, 0),), ((1, 1),), ((1, 2),))): QQ('1/4'),
    (((-2, -2, 1, 1), (-2, 2, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('-1/64'),
    (((-3, -2, 1, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((0, 1),), ((1, 1),))): QQ('-1'),
    (((0,), (-2, -2, 0, 2, 2)), (((1, 0),), ((1, 1),))): QQ('1/12'),
    (((-2, 1, 1), (-3, -3, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-4, 0, 0, 0, 0, 1, 1),), (((0, 0),),)): QQ('81'),
    (((-2, -2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-3/2'),
    (((-4, -3, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('12'),
    (((-2, -2, 1, 1), (0, 2)), (((0, 0),), ((0, 1),))): QQ('0'),
    (((-2, 1, 1), (-2, 0, 2)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((-2, -2, 2), (-3, 1, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-5/8'),
    (((-3, -2, -2, 1, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('-32'),
    (((-2, 2), (-4, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-3/4'),
    (((-2, -2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('1'),
    (((-3, -3, 1, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('-144'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1), (1, 2)))): QQ('-12'),
    (((-4, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1), (2, 0), (2, 1)), ((0, 1),))): QQ('1'),
    (((-2, 2), (-4, 1, 1, 2)), (((0, 0), (1, 0)),)): QQ('-43/64'),
    (((0, 0, 0), (-4, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)), ((1, 2),))): QQ('10'),
    (((-5, -2, 1, 2, 2),), (((0, 0),), ((0, 1),))): QQ('-8'),
    (((-2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('0'),
    (((-3, -2, 1, 2), (-3, -2, 1, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-4'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (2, 0), (2, 1)),)): QQ('1/8'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),), ((1, 2),))): QQ('2'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-3'),
    (((-4, 1, 1), (-6, 2, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, -2, 2), (-4, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-9'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('3'),
    (((-3, 1, 2, 2),), (((0, 0),),)): QQ('-25/32'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)), ((1, 2),))): QQ('-10'),
    (((1, 1), (-4, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0, 1, 1, 2),), (((0, 0),),)): QQ('0'),
    (((-2, 0, 0, 0), (-2, -2, 1, 1)), (((0, 0),), ((1, 0),), ((1, 1),))): QQ('1'),
    (((-2, -2, 2), (-3, -2, 1, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-3, -2, 1, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('4'),
    (((-4, 1, 1), (-4, 2, 2)), (((0, 0), (1, 0)),)): QQ('-31/12'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('5/4'),
    (((-2, -2, 1, 1), (-2, 2), (-2, 2)), (((0, 0), (1, 0)), ((0, 1), (2, 0)))): QQ('1/64'),
    (((1, 1), (-4, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-4, 1, 1), (0, 2)), (((0, 0),),)): QQ('0'),
    (((-2, -2, 1, 1), (-4, 2, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('-31/12'),
    (((-4, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0), (1, 2)))): QQ('4'),
    (((-4, 0, 0, 1, 1, 2),), (((0, 0),),)): QQ('-387/8'),
    (((0,), (-4, -2, 1, 1, 2)), (((1, 0),), ((1, 1),))): QQ('1/4'),
    (((-2, 2), (-2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('5/32'),
    (((-2, -2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1),), ((1, 1),))): QQ('-1'),
    (((-4, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((0,), (-2, 0, 0, 0, 2)), (((1, 0),),)): QQ('-1/192'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1), (1, 2)))): QQ('-8'),
    (((-6, -2, 1, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('-125'),
    (((-2, 2), (-3, 1, 2)), (((0, 0), (1, 0)),)): QQ('5/64'),
    (((-2, -2, 2), (-3, -3, 1, 1, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-8'),
    (((-2, 1, 1), (-6, 2, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 2), (-6, 1, 1, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('5'),
    (((-2, -2, 2), (-4, 1, 1, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('43/8'),
    (((-2, -2, 1, 1), (-3, -3, 2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('2'),
    (((-2, -2, 1, 1), (-6, 2, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('-1'),
    (((-2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('0'),
    (((0, 0, 0), (-2, -2, 1, 1)), (((1, 0),), ((1, 1),))): QQ('0'),
    (((-2, 0, 0, 0), (-2, 1, 1)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((-4, 1, 1), (-3, -3, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 0, 1, 1), (2,)), (((0, 0),),)): QQ('0'),
    (((0, 1, 1), (-2, 2)), (((1, 0),),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, 2), (-2, 2)), (((0, 0),), ((0, 1), (1, 0), (2, 0)))): QQ('1/64'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 2)), ((1, 0), (1, 1)))): QQ('-10'),
    (((-2, 1, 1), (-4, 2, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, 2), (-2, 1, 1, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, 0, 0, 0, 0, 1, 1),), (((0, 0),),)): QQ('0'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-3, 1, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('5/4'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)), ((0, 1),))): QQ('-1/8'),
    (((-2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('0'),
    (((-4, -4, 1, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('-90'),
    (((-2, 0, 0), (-4, 0, 0, 1, 1)), (((0, 0),), ((1, 0),))): QQ('-9'),
    (((-2, -2, 2), (-2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('0'),
    (((-2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),), ((1, 2),))): QQ('0'),
    (((-3, -2, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('27/2'),
    (((-2, -2, 0, 0, 0, 0, 1, 1),), (((0, 0),), ((0, 1),))): QQ('16'),
    (((0, 2), (2,)), ()): QQ('0'),
    (((-2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((1, 0),), ((1, 1),))): QQ('0'),
    (((-3, -2, -2, 1, 2, 2),), (((0, 0),), ((0, 1),), ((0, 2),))): QQ('-12'),
    (((-2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('0'),
    (((-2, -2, 1, 1), (-4, 2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('31/12'),
    (((-2, 2), (-6, 1, 1, 2)), (((0, 0), (1, 0)),)): QQ('-5/8'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 1), (1, 2)), ((1, 0),))): QQ('4'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)), ((1, 2),))): QQ('10'),
    (((-4, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-168'),
    (((-4, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((1, 0),), ((1, 1),))): QQ('-1'),
    (((-3, -3, 2, 2),), (((0, 0),), ((0, 1),))): QQ('2'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 2)), ((1, 0),), ((1, 1),))): QQ('-3/4'),
    (((-2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)), ((1, 2),))): QQ('-4'),
    (((1, 1), (-2, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-2, 1, 1), (0, 2)), (((0, 0),),)): QQ('0'),
    (((-3, -2, -2, 1, 2, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('20'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 1)), ((0, 1), (1, 1), (2, 0)))): QQ('1'),
    (((1, 1), (-2, -2, 1, 1)), (((1, 0),), ((1, 1),))): QQ('0'),
    (((-2, 1, 1), (-2, 1, 1)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((-5, -3, 1, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('-96'),
    (((-4, 0, 1, 1), (-2, 2)), (((0, 0),), ((1, 0),))): QQ('-3/8'),
    (((0,), (-6, 1, 1, 2)), (((1, 0),),)): QQ('5/24'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('3'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((1, 0),), ((1, 2),))): QQ('-3/4'),
    (((-4, -2, -2, 1, 1, 2, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-224'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 2)), ((1, 0),), ((1, 1),))): QQ('-2'),
    (((-4, 0, 2), (-2, 0, 2)), (((0, 0),), ((1, 0),))): QQ('-1/8'),
    (((-2, -2, 2), (-2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('5/4'),
    (((0,), (-4, 0, 0, 0, 2)), (((1, 0),),)): QQ('-3/8'),
    (((-2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('0'),
    (((-2, -2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 2)), ((0, 1),), ((0, 3),))): QQ('-240'),
    (((-4, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('4'),
    (((-2, 0, 2), (-2, 0, 2)), (((0, 0),), ((1, 0),))): QQ('-1/64'),
    (((-4, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 0)), ((1, 0), (2, 1)))): QQ('-1'),
    (((0, 2), (-4, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-3, -2, -2, 1, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('20'),
    (((-4, -2, 0, 0, 1, 1, 2),), (((0, 0),), ((0, 1),))): QQ('-96'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1), (1, 2)),)): QQ('8'),
    (((-2, 0, 0, 0), (-4, 0, 2)), (((0, 0),), ((1, 0),))): QQ('1'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (2, 0), (2, 1)))): QQ('-1/8'),
    (((-2, -2, 1, 1), (-3, -3, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-2'),
    (((0, 2), (-2, 0, 2)), (((1, 0),),)): QQ('0'),
    (((-2, -2, 0, 0, 1, 1, 2),), (((0, 0),), ((0, 1),))): QQ('-5'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),), ((1, 2),))): QQ('6'),
    (((-2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, 2), (-2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('-5/4'),
    (((0,), (-2, 1, 1, 2)), (((1, 0),),)): QQ('0'),
    (((0,), (0,), (-2, -2, 0, 1, 1)), (((2, 0),), ((2, 1),))): QQ('-1/288'),
    (((-4, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('3/2'),
    (((-2, -2, 1, 1), (-4, 0, 2)), (((0, 0),), ((0, 1),), ((1, 0),))): QQ('-1'),
    (((0,), (0,), (-4, 0, 1, 1)), (((2, 0),),)): QQ('-1/192'),
    (((0,), (-2, 0, 0), (-2, 0, 0, 0)), (((1, 0),), ((2, 0),))): QQ('-1/24'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0),), ((0, 1), (1, 1), (2, 1)), ((1, 0), (2, 0)))): QQ('-1'),
    (((0,), (0,), (-2, 0, 1, 1)), (((2, 0),),)): QQ('0'),
    (((-4, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('-8'),
    (((-2, -2, 2), (-4, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('9'),
    (((-2, -2, -2, 1, 1, 2, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-151/2'),
    (((0,), (-2, 0, 0, 0, 0, 0)), (((1, 0),),)): QQ('1/24'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 1)), ((0, 1), (2, 0)))): QQ('-1/8'),
    (((-4, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0), (1, 1), (1, 2)),)): QQ('12'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (2, 1)), ((1, 1), (2, 0)))): QQ('-1'),
    (((0,), (-2, -2, -2, 0, 2, 2)), (((1, 0),), ((1, 1),), ((1, 2),))): QQ('1/4'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (2, 0), (2, 1)), ((0, 1), (1, 0)))): QQ('-1/8'),
    (((0,), (-2, -2, 1, 1, 2)), (((1, 0),), ((1, 1),))): QQ('5/96'),
    (((-4, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('1'),
    (((-2, -2, 2), (-4, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('9'),
    (((-2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('0'),
    (((-4, -2, 1, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('-180'),
    (((1, 1), (-2, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0, 0), (-4, 1, 1)), (((0, 0),), ((1, 0),))): QQ('1'),
    (((-2, -2, 1, 1), (-2, 2), (-2, 2)), (((0, 0), (0, 1), (1, 0), (2, 0)),)): QQ('-1/64'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('1'),
    (((-2, -2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('368'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((0, 1),), ((1, 0),), ((1, 1),))): QQ('-1'),
    (((-2, -2, 0, 1, 1), (-2, 2)), (((0, 0),), ((0, 1),), ((1, 0),))): QQ('-1/4'),
    (((-4, 0, 2), (-4, 0, 2)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0), (1, 2)))): QQ('-4'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('5/4'),
    (((-2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((0,), (-2, 0, 2, 2)), (((1, 0),),)): QQ('1/1536'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('1'),
    (((-4, 1, 1), (-2, 1, 1)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0), (1, 2)))): QQ('-12'),
    (((-2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('0'),
    (((-2, -2, 2), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-2'),
    (((-2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('81'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 0)), ((1, 1), (1, 2)))): QQ('4'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1), (1, 2)))): QQ('-10'),
    (((0,), (-2, 0, 0), (0, 0, 0)), (((1, 0),),)): QQ('0'),
    (((0,), (0, 0), (-2, 0, 0, 0)), (((2, 0),),)): QQ('0'),
    (((-2, 0, 0), (-2, -2, 0, 0, 1, 1)), (((0, 0),), ((1, 0),), ((1, 1),))): QQ('-4'),
    (((-4, 1, 1), (-2, 2), (-2, 2)), (((0, 0), (1, 0), (2, 0)),)): QQ('1/64'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0), (1, 2)), ((1, 1),))): QQ('-10'),
    (((-2, -2, 1, 1), (-2, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('3/2'),
    (((-2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 1)), ((1, 0), (2, 0)))): QQ('0'),
    (((-6, 0, 0, 1, 1, 2),), (((0, 0),),)): QQ('-125'),
    (((-4, 0, 1, 1), (2,)), (((0, 0),),)): QQ('-3/640'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1), (2, 0), (2, 1)))): QQ('1'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('-3/2'),
    (((-2, 0, 0), (-2, 0, 0, 1, 1)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((0, 0), (-2, -2, 0, 0, 1, 1)), (((1, 0),), ((1, 1),))): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 2)), ((0, 1), (1, 1)))): QQ('-8'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('-1'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (2, 1)), ((0, 1), (1, 0), (2, 0)))): QQ('-1/8'),
    (((0, 0), (-4, 0, 0, 1, 1)), (((1, 0),),)): QQ('0'),
    (((0,), (-4, 0, 2, 2)), (((1, 0),),)): QQ('31/96'),
    (((-2, -2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('3/2'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (2, 1)), ((1, 1), (2, 0)))): QQ('1'),
    (((-2, -2, 1, 1, 2, 2),), (((0, 0), (0, 1)),)): QQ('-25/16'),
    (((-2, -2, 0, 1, 1), (2,)), (((0, 0),), ((0, 1),))): QQ('-1/320'),
    (((-2, 0, 1, 1), (-2, 2)), (((0, 0),), ((1, 0),))): QQ('0'),
    (((-2, 1, 1), (-2, 2, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('5/4'),
    (((0, 0), (-2, 0, 0, 1, 1)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0), (0, 0, 1, 1)), (((0, 0),),)): QQ('0'),
    (((-2, -2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 1), (0, 2), (0, 3)),)): QQ('-384'),
    (((-4, 1, 1), (-4, 1, 1)), (((0, 0),), ((1, 0),))): QQ('-1'),
    (((0,), (-6, 0, 2, 2)), (((1, 0),),)): QQ('5/24'),
    (((-3, 0, 1), (-2, -2, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-1'),
    (((-3, 0, 0, 1), (-3, -2, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-4'),
    (((-4, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-1'),
    (((0,), (-3, -2, 1, 2)), (((1, 0),), ((1, 1),))): QQ('-1/24'),
    (((0,), (-3, -3, 0, 2, 2)), (((1, 0), (1, 1)),)): QQ('-1/3'),
    (((-2, 0, 0), (-4, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-9'),
    (((0,), (-2, 1, 1), (-2, 2)), (((1, 0), (2, 0)),)): QQ('0'),
    (((0,), (-2, 2), (-4, 0, 2)), (((1, 0), (2, 0)),)): QQ('-1/192'),
    (((0,), (-3, -2, 1, 2)), (((1, 0), (1, 1)),)): QQ('1/12'),
    (((-2, -2, -2, 0, 1, 1, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-30'),
    (((0,), (-2, 0, 0, 0), (-2, -2, 2)), (((1, 0), (2, 0), (2, 1)),)): QQ('-1/24'),
    (((0,), (-4, -2, 1, 1, 2)), (((1, 0), (1, 1)),)): QQ('-3/8'),
    (((0,), (-4, 1, 1), (-2, -2, 2)), (((1, 0), (2, 0), (2, 1)),)): QQ('1/24'),
    (((-2, 0, 0), (-2, -2, 0, 0, 1, 1)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-4'),
    (((-2, 0, 0, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((0,), (-2, 0, 0), (-2, 0, 0, 0)), (((1, 0), (2, 0)),)): QQ('-1/24'),
    (((-3, -2, 0, 0, 1, 2),), (((0, 0),), ((0, 1),))): QQ('9'),
    (((-2, 0, 0), (-4, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('6'),
    (((-6, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-1'),
    (((-6, 1, 3), (-2, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, -2, 2), (-4, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-3'),
    (((0,), (-2, 0, 0), (-4, 0, 2)), (((1, 0), (2, 0)),)): QQ('1/24'),
    (((0,), (-2, -2, 1, 1), (-2, 2)), (((1, 0), (1, 1), (2, 0)),)): QQ('1/192'),
    (((0,), (-2, -2, 1, 1), (-2, -2, 2)), (((1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('-1/24'),
    (((-4, -2, 1, 3), (-2, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('1/8'),
    (((-3, 0, 1), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, -2, 0, 1, 1), (-2, -2, 2)), (((0, 0), (0, 1)), ((1, 0), (1, 1)))): QQ('-2'),
    (((0,), (-2, -2, 1, 1, 2)), (((1, 0), (1, 1)),)): QQ('-5/96'),
    (((-2, -2, 1, 1), (-4, 0, 0, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('3'),
    (((-2, -2, -2, 1, 1, 4),), (((0, 0), (0, 2)), ((0, 1),))): QQ('613/12'),
    (((0,), (-5, 1, 2)), (((1, 0),),)): QQ('-1/24'),
    (((-2, 0, 0), (-4, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('1'),
    (((-2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-4/3'),
    (((-2, -2, 1, 3), (-2, -2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('-4/3'),
    (((-2, -2, 1, 1), (-2, 0, 2)), (((0, 0), (0, 1)), ((1, 0),))): QQ('1/8'),
    (((-2, 1, 1), (-2, -2, 0, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('0'),
    (((-2, 0, 0), (-6, 1, 1, 2)), (((0, 0), (1, 0)),)): QQ('5'),
    (((-2, -2, -2, 1, 3), (-2, 2)), (((0, 0), (0, 1), (0, 2), (1, 0)),)): QQ('3/4'),
    (((-3, -2, -2, 1, 4),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-6'),
    (((-3, 0, 0, 1), (-3, 0, 0, 1)), (((0, 0), (1, 0)),)): QQ('-4'),
    (((0,), (-2, 2), (-2, -2, 0, 2)), (((1, 0), (2, 0), (2, 1)),)): QQ('1/96'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0), (0, 3)), ((0, 1),), ((0, 2),))): QQ('64'),
    (((-5, 0, 0, 1, 2),), (((0, 0),),)): QQ('16'),
    (((-2, -2, 0, 0, 1, 1), (-2, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('1/2'),
    (((-2, -2, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('2'),
    (((-2, -2, 0, 1, 1), (-4, 0, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('2'),
    (((-4, -2, 1, 3), (-2, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('1/8'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('-1'),
    (((-3, 0, 0, 1), (-5, 1, 2)), (((0, 0), (1, 0)),)): QQ('2'),
    (((-4, 1, 3), (-2, 2)), (((0, 0), (1, 0)),)): QQ('5/12'),
    (((-4, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-3'),
    (((0,), (-2, -2, 1, 1), (-2, -2, 2)), (((1, 0), (2, 0)), ((1, 1), (2, 1)))): QQ('1/24'),
    (((0,), (-3, 1, 2)), (((1, 0),),)): QQ('-5/192'),
    (((-2, 0, 2), (-2, -2, 0, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('1/4'),
    (((-2, 0, 0, 0), (-2, -2, 0, 1, 1)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 0, 0), (-2, -2, 0, 0, 1, 1)), (((0, 0), (1, 0), (1, 1)),)): QQ('4'),
    (((-4, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-10/3'),
    (((-3, 0, 1), (-3, 0, 1), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0),), ((0, 1), (1, 0), (1, 1), (1, 2)))): QQ('4'),
    (((-2, 0, 0), (-3, -2, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)), ((0, 2),))): QQ('-4'),
    (((0,), (-2, -2, -2, 1, 1, 2)), (((1, 0), (1, 1)), ((1, 2),))): QQ('-5/12'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0), (0, 2)), ((0, 1),), ((0, 3),))): QQ('-14'),
    (((0,), (-2, -2, -2, 2, 2)), (((1, 0),), ((1, 1), (1, 2)))): QQ('1/6'),
    (((-2, 0, 0), (-2, -2, 0, 0, 1, 1)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-4'),
    (((-4, 0, 1, 1), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('3'),
    (((-3, 0, 1), (-5, 0, 1, 2)), (((0, 0), (1, 0)),)): QQ('4'),
    (((-2, 0, 0), (-3, 0, 0, 1)), (((0, 0),), ((1, 0),))): QQ('2'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)), ((0, 2),))): QQ('4'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 1), (2, 0), (2, 1)), ((1, 0),))): QQ('1'),
    (((-4, 1, 1), (-2, -2, 0, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-4'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0), (0, 1), (1, 1)), ((1, 0),))): QQ('-11/12'),
    (((-4, 1, 1), (-4, 0, 0, 2)), (((0, 0), (1, 0)),)): QQ('3'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (2, 0)), ((1, 0),), ((2, 1),))): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 0, 2)), (((0, 0),), ((0, 1),), ((1, 0), (1, 1)))): QQ('2'),
    (((-3, 0, 0, 1), (-2, 2)), (((0, 0), (1, 0)),)): QQ('-1/4'),
    (((-2, -2, 0, 1, 1), (-2, -2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('2'),
    (((-2, -2, -2, 1, 3), (-2, 2)), (((0, 0), (0, 1), (1, 0)), ((0, 2),))): QQ('-1/2'),
    (((-2, 0, 0), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-3, -3, 1, 3), (-2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-3/8'),
    (((-2, -2, -2, -2, 3, 3),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('30'),
    (((0,), (-2, -2, 1, 1), (-2, -2, 2)), (((1, 0), (2, 0), (2, 1)), ((1, 1),))): QQ('1/24'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1),), ((1, 2),))): QQ('-2'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 1), (1, 2)), ((1, 0),))): QQ('4'),
    (((-2, 0, 0), (-2, -2, -2, 1, 3)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('4'),
    (((0,), (-2, -2, -2, 1, 1, 2)), (((1, 0), (1, 1), (1, 2)),)): QQ('1/2'),
    (((-3, 0, 0, 1, 2),), (((0, 0),),)): QQ('5/2'),
    (((-4, -2, 0, 0, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('144'),
    (((-4, 0, 1, 1), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('3/8'),
    (((-2, 0, 1, 1), (-4, 0, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, 0, 0), (-5, 1, 2)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-3, 0, 1), (-3, -2, 0, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-6'),
    (((-4, 0, 2), (-2, -2, 0, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('2'),
    (((0,), (-2, -2, -2, 0, 2, 2)), (((1, 0), (1, 1)), ((1, 2),))): QQ('-1/2'),
    (((-2, -2, 0, 0, 1, 1), (-2, -2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('-4'),
    (((-3, 0, 1), (-3, -2, 0, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('3'),
    (((0, 2), (-2, -2, 0, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-3, 0, 1), (-2, 2)), (((0, 0),), ((1, 0),))): QQ('1/8'),
    (((-2, -2, 1, 3), (-2, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('1/6'),
    (((-2, -2, -2, -2, 1, 1, 4),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),))): QQ('62'),
    (((0,), (-2, 1, 1), (-2, -2, 2)), (((1, 0), (2, 0), (2, 1)),)): QQ('0'),
    (((-4, 1, 1), (-2, 0, 0, 2)), (((0, 0), (1, 0)),)): QQ('1/8'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 2)), ((1, 0),))): QQ('-4'),
    (((-2, 0, 0), (-4, 0, 0, 1, 1)), (((0, 0), (1, 0)),)): QQ('-9'),
    (((-3, 0, 0, 1), (-3, -2, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('2'),
    (((-3, -3, 0, 0, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('128'),
    (((-3, 0, 1), (-3, 0, 1, 2)), (((0, 0), (1, 0)),)): QQ('5/4'),
    (((-3, 0, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0), (2, 0)), ((2, 1),))): QQ('1'),
    (((-2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0)), ((1, 1), (2, 1)))): QQ('1/8'),
    (((-2, -2, 1, 1), (-4, 0, 2)), (((0, 0), (0, 1)), ((1, 0),))): QQ('1'),
    (((-4, 1, 1), (-2, -2, 0, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('2'),
    (((0,), (-2, 2), (-2, 0, 2)), (((1, 0), (2, 0)),)): QQ('-1/1536'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 1)), ((1, 2),))): QQ('-1'),
    (((-2, -2, 0, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-4'),
    (((-2, -2, -2, 0, 0, 1, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-36'),
    (((0,), (-2, -2, -2, 1, 1, 2)), (((1, 0), (1, 2)), ((1, 1),))): QQ('-5/12'),
    (((-2, -2, 1, 1), (-2, 0, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1/8'),
    (((-2, 0, 0), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 1)), ((1, 1), (2, 0)))): QQ('-1'),
    (((-3, 0, 0, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('2'),
    (((-2, -2, 1, 1), (-2, -2, 0, 0, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-4'),
    (((0,), (-2, 0, 0), (-2, -2, 0, 2)), (((1, 0), (2, 0), (2, 1)),)): QQ('-1/12'),
    (((0,), (-2, 0, 0), (-2, 0, 2)), (((1, 0), (2, 0)),)): QQ('1/192'),
    (((0,), (-2, -2, 0, 0, 0, 2)), (((1, 0), (1, 1)),)): QQ('1/3'),
    (((0,), (-2, -2, 1, 1), (-2, 2)), (((1, 0), (2, 0)), ((1, 1),))): QQ('-1/192'),
    (((-2, -2, 1, 1), (-2, -2, 0, 0, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('4'),
    (((-4, -2, 1, 3), (-2, -2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('-1'),
    (((0, 0), (-2, 0, 0), (-4, 1, 1)), (((1, 0), (2, 0)),)): QQ('0'),
    (((-2, -2, 0, 2), (-2, -2, 0, 2)), (((0, 0), (0, 1)), ((1, 0), (1, 1)))): QQ('-4'),
    (((-3, 0, 1), (-3, 0, 1), (-2, 2)), (((0, 0), (1, 0), (2, 0)),)): QQ('-1/8'),
    (((-2, 0, 0, 0), (-2, -2, 0, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-2'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-13/8'),
    (((-4, -2, -2, 3, 3),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-6'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)), ((1, 2),))): QQ('-4'),
    (((-2, 0, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, 0, 1, 1), (-2, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1/4'),
    (((-2, -2, -2, 0, 0, 1, 1, 2),), (((0, 0), (0, 1), (0, 2)),)): QQ('-108'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (2, 1)), ((1, 0), (2, 0)))): QQ('1'),
    (((-2, 0, 0), (-2, 0, 0), (-4, 1, 1)), (((0, 0), (2, 0)), ((1, 0),))): QQ('1'),
    (((0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((1, 0), (2, 0), (2, 1)),)): QQ('0'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('-1'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1), (0, 2)))): QQ('4'),
    (((-4, -2, 1, 3), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, -2, -2, 1, 3), (-2, 2)), (((0, 0), (1, 0)), ((0, 1), (0, 2)))): QQ('-1/2'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0),), ((0, 1), (1, 0), (1, 2)), ((1, 1),))): QQ('-1'),
    (((-4, 0, 1, 1), (-2, -2, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('3'),
    (((0, 0), (-3, 0, 0, 1)), (((1, 0),),)): QQ('0'),
    (((0,), (-4, -2, 0, 2, 2)), (((1, 0), (1, 1)),)): QQ('-1/2'),
    (((-2, 0, 0), (-2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('5/4'),
    (((-2, 0, 0), (-3, 0, 1), (-3, 0, 1)), (((0, 0), (1, 0), (2, 0)),)): QQ('1'),
    (((-3, -3, 1, 3), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('3'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0),), ((1, 2),))): QQ('-2'),
    (((-2, 0, 0), (-2, -2, 1, 3)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-4/3'),
    (((-3, 0, 1), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('-1/8'),
    (((-3, -2, 0, 0, 1, 2),), (((0, 0), (0, 1)),)): QQ('-18'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (2, 1)), ((1, 0), (2, 0)))): QQ('1'),
    (((-2, -2, 0, 1, 1), (-2, 0, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('1/4'),
    (((-2, -2, -2, 0, 0, 1, 1, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('90'),
    (((-2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('4/3'),
    (((0, 0, 0), (-2, -2, 1, 1)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, 1, 1), (-2, -2, 0, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-2, 0, 0), (-3, 0, 0, 1)), (((0, 0), (1, 0)),)): QQ('2'),
    (((-2, 0, 0, 0), (-3, 0, 1)), (((0, 0), (1, 0)),)): QQ('1'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1),), ((1, 2),))): QQ('1/4'),
    (((-2, 0, 0), (-2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)),)): QQ('0'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('-1/2'),
    (((-2, 0, 0, 1, 1), (-2, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1), (1, 2)))): QQ('8'),
    (((-4, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('-1'),
    (((-2, 0, 0), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((1, 1),), ((1, 2),))): QQ('6'),
    (((-2, 1, 1), (-4, 0, 0, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0)), ((1, 1), (2, 0), (2, 1)))): QQ('1'),
    (((-2, 0, 0), (-4, 1, 1), (-2, 2)), (((0, 0), (1, 0), (2, 0)),)): QQ('-1/8'),
    (((-2, 0, 0, 0), (-2, -2, 1, 1)), (((0, 0),), ((1, 0), (1, 1)))): QQ('-1'),
    (((-2, -2, 1, 1), (-4, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-1'),
    (((-2, 0, 0), (-3, -3, 1, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-8'),
    (((-2, -2, 1, 1), (-4, 4)), (((0, 0),), ((0, 1), (1, 0)))): QQ('15/8'),
    (((-2, -2, 1, 3), (-2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1/6'),
    (((0,), (-3, -3, 1, 1, 2)), (((1, 0), (1, 1)),)): QQ('-1/3'),
    (((-2, -2, 0, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-4'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (0, 1), (0, 2), (1, 0), (1, 1)),)): QQ('-6'),
    (((-2, -2, 1, 1), (0, 2)), (((0, 0), (0, 1)),)): QQ('0'),
    (((1, 1), (-2, -2, 0, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((1, 0), (2, 0)), ((2, 1),))): QQ('0'),
    (((-2, -2, 0, 1, 1), (-2, -2, 0, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('4'),
    (((-2, 0, 0, 0), (-4, 0, 1, 1)), (((0, 0), (1, 0)),)): QQ('-3'),
    (((0,), (-4, 1, 1), (-2, 2)), (((1, 0), (2, 0)),)): QQ('-1/192'),
    (((-2, 1, 3), (-2, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1)), ((0, 1), (1, 2)))): QQ('4'),
    (((-2, 0, 0), (-2, 0, 0, 1, 1)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-4, -2, 1, 3), (-2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-3/8'),
    (((-4, 0, 0, 1, 1), (-2, 2)), (((0, 0), (1, 0)),)): QQ('9/8'),
    (((-2, 0, 0), (-4, 1, 1, 2)), (((0, 0), (1, 0)),)): QQ('43/8'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((0, 1),), ((1, 0), (1, 1)))): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (0, 1)), ((1, 0),), ((1, 1),))): QQ('1'),
    (((-4, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((1, 0), (1, 1)))): QQ('1'),
    (((0,), (-2, -2, 2), (-2, 0, 2)), (((1, 0), (1, 1), (2, 0)),)): QQ('1/192'),
    (((-4, 0, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-9'),
    (((-2, 0, 0), (-2, 1, 1, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, 0, 0), (-3, -2, 1, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-3, 0, 1), (-3, 0, 0, 0, 1)), (((0, 0), (1, 0)),)): QQ('-4'),
    (((0,), (-2, -2, 1, 1), (-2, 2)), (((1, 0),), ((1, 1), (2, 0)))): QQ('-1/192'),
    (((0,), (0,), (-2, -2, 0, 1, 1)), (((2, 0), (2, 1)),)): QQ('1/288'),
    (((-2, 0, 0, 0, 0), (-4, 1, 1)), (((0, 0), (1, 0)),)): QQ('-1'),
    (((-2, 0, 0), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('-10'),
    (((-2, -2, 0, 1, 1), (-2, -2, 2)), (((0, 0),), ((0, 1),), ((1, 0), (1, 1)))): QQ('2'),
    (((-2, -2, 1, 1), (-2, -2, 1, 1)), (((0, 0), (0, 1)), ((1, 0), (1, 1)))): QQ('-1'),
    (((-2, -2, 0, 0, 1, 1), (-2, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-1/2'),
    (((-2, -2, 1, 1), (-2, -2, 0, 2)), (((0, 0), (0, 1)), ((1, 0), (1, 1)))): QQ('-2'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (2, 0)), ((1, 1), (2, 1)))): QQ('-1'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (0, 2), (1, 0)))): QQ('6'),
    (((-2, 0, 0), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),), ((1, 2),))): QQ('-2'),
    (((-2, -2, 0, 0, 1, 1), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0), (1, 1)),)): QQ('4'),
    (((0, 0), (-3, 0, 1), (-3, 0, 1)), (((1, 0), (2, 0)),)): QQ('0'),
    (((-2, 0, 0), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('-10'),
    (((0,), (-2, 0, 0, 0), (-2, 2)), (((1, 0), (2, 0)),)): QQ('1/192'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, 2)), (((0, 0), (1, 0)), ((1, 1), (2, 0)))): QQ('-1/8'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0), (2, 0), (2, 1)))): QQ('-1'),
    (((-3, 0, 0, 1), (-3, 1, 2)), (((0, 0), (1, 0)),)): QQ('5/4'),
    (((-2, 0, 0), (-2, -2, 0, 0, 1, 1)), (((0, 0),), ((1, 0), (1, 1)))): QQ('4'),
    (((-2, 0, 0), (-3, 0, 1), (-3, 0, 1)), (((0, 0),), ((1, 0), (2, 0)))): QQ('1'),
    (((-2, 0, 1, 1), (-2, -2, 2)), (((0, 0),), ((1, 0), (1, 1)))): QQ('0'),
    (((-2, -2, 0, 1, 1), (-2, 2)), (((0, 0), (0, 1)), ((1, 0),))): QQ('1/4'),
    (((-2, 0, 0), (-2, 0, 0), (-4, 1, 1)), (((0, 0), (1, 0), (2, 0)),)): QQ('1'),
    (((-2, -2, -2, 2, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('85/2'),
    (((0,), (-2, -2, 2), (-4, 0, 2)), (((1, 0), (1, 1), (2, 0)),)): QQ('1/24'),
    (((-2, 0, 0), (-4, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('6'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-13/8'),
    (((0,), (-2, -2, 1, 1), (-2, -2, 2)), (((1, 0),), ((1, 1), (2, 0), (2, 1)))): QQ('1/24'),
    (((-2, -2, 1, 1), (-2, -2, 0, 0, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0)))): QQ('-4'),
    (((-2, 0, 0), (-3, 1, 2)), (((0, 0), (1, 0)),)): QQ('-5/8'),
    (((-2, -2, 0, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-4'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0), (0, 2), (0, 3)), ((0, 1),))): QQ('-120'),
    (((-2, 1, 1), (-2, 0, 0, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((0, 2), (-2, 2)), (((1, 0),),)): QQ('0'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (2, 0), (2, 1)), ((1, 0),))): QQ('-1'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('48'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, 2)), (((0, 0), (1, 1), (2, 0)), ((1, 0),))): QQ('-1/8'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (2, 0)), ((1, 0), (2, 1)))): QQ('1'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, 2)), (((0, 0), (1, 0), (1, 1), (2, 0)),)): QQ('1/8'),
    (((0,), (0,), (-3, 0, 1)), (((2, 0),),)): QQ('1/576'),
    (((-2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((0, 1), (1, 0), (1, 1)))): QQ('8'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 1)), ((1, 0), (1, 2)))): QQ('1'),
    (((-2, 0, 0, 0), (-2, -2, 0, 1, 1)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-2'),
    (((-3, 0, 1), (2,)), (((0, 0),),)): QQ('1/640'),
    (((-3, 0, 0, 0, 0, 1),), (((0, 0),),)): QQ('-8'),
    (((0, 0, 0), (-2, -2, 0, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, 0, 0, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('1/8'),
    (((-2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('0'),
    (((-2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 1)), ((1, 1), (2, 0)))): QQ('1/8'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 1), (1, 2)), ((1, 0),))): QQ('1'),
    (((-2, -2, 0, 1, 1), (-4, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-2'),
    (((-4, 0, 1, 1), (-2, -2, 0, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-6'),
    (((-2, 0, 0), (-2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('-5/4'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 1)), ((0, 1), (1, 1), (2, 0)))): QQ('-1'),
    (((-2, 1, 1), (-2, -2, 1, 1)), (((0, 0),), ((1, 0), (1, 1)))): QQ('0'),
    (((0,), (-2, -2, 2), (-2, -2, 0, 2)), (((1, 0), (2, 0)), ((1, 1), (2, 1)))): QQ('1/12'),
    (((-2, 0, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)),)): QQ('0'),
    (((0, 0), (-2, 0, 0), (-2, 1, 1)), (((1, 0), (2, 0)),)): QQ('0'),
    (((0,), (-2, -2, 2), (-2, -2, 0, 2)), (((1, 0), (2, 1)), ((1, 1), (2, 0)))): QQ('1/12'),
    (((-2, 0, 1, 1), (-2, 0, 2)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 0, 0, 1, 1, 2),), (((0, 0), (0, 1)),)): QQ('5'),
    (((-2, 0, 0), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 1), (1, 2)),)): QQ('12'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 1)), ((0, 1),), ((1, 0), (1, 2)))): QQ('-1'),
    (((-2, 0, 0), (-2, 0, 0), (-2, 1, 1)), (((0, 0), (2, 0)), ((1, 0),))): QQ('0'),
    (((-2, -2, -2, -2, 1, 1, 4),), (((0, 0),), ((0, 1), (0, 2), (0, 3)))): QQ('-108'),
    (((-2, -2, 0, 1, 1), (2,)), (((0, 0), (0, 1)),)): QQ('1/320'),
    (((0, 1, 1), (-2, -2, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, 0, 0, 0), (-2, 0, 1, 1)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, 0, 0, 0, 0, 1, 1),), (((0, 0), (0, 1)),)): QQ('-16'),
    (((0,), (-2, -2, 2), (-2, -2, 0, 2)), (((1, 0), (1, 1), (2, 0), (2, 1)),)): QQ('-1/12'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0), (0, 2)), ((0, 1), (0, 3)))): QQ('-168'),
    (((-2, 0, 0, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0), (1, 1)),)): QQ('1'),
    (((-2, -2, 1, 1), (-4, 0, 0, 2)), (((0, 0), (0, 1), (1, 0)),)): QQ('-3'),
    (((-2, -2, -2, -2, 1, 1, 4),), (((0, 0), (0, 1)), ((0, 2), (0, 3)))): QQ('-124'),
    (((0,), (-2, -2, 0, 2, 2)), (((1, 0), (1, 1)),)): QQ('-1/8'),
    (((1, 1), (-2, -2, 1, 1)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, 0, 0), (-2, 0, 0), (-2, 1, 1)), (((0, 0), (1, 0), (2, 0)),)): QQ('0'),
    (((0,), (-2, -2, -2, 0, 2, 2)), (((1, 0), (1, 1), (1, 2)),)): QQ('1'),
    (((-2, 0, 0), (-2, 1, 1), (-2, 2)), (((0, 0), (1, 0), (2, 0)),)): QQ('0'),
    (((0, 0), (-2, -2, 0, 0, 1, 1)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 1), (2, 0)), ((1, 0), (2, 1)))): QQ('1'),
    (((-2, 0, 0, 0, 0), (-2, 1, 1)), (((0, 0), (1, 0)),)): QQ('0'),
    (((-2, -2, -2, 0, 0, 1, 3),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-36'),
    (((-2, -2, 0, 2), (-2, -2, 0, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('4'),
    (((-2, 0, 0), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((1, 0),), ((1, 1),))): QQ('-2'),
    (((0,), (-2, -2, -2, 0, 4)), (((1, 0),), ((1, 1), (1, 2)))): QQ('1/8'),
    (((0, 2), (-2, -2, 2)), (((1, 0), (1, 1)),)): QQ('0'),
    (((-2, -2, 1, 1), (-2, 2), (-2, 2)), (((0, 0), (2, 0)), ((0, 1), (1, 0)))): QQ('1/64'),
    (((-2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 2)), ((1, 0),), ((1, 1),))): QQ('2'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 2)), ((1, 0),), ((1, 1),))): QQ('6'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 2)), ((1, 1),))): QQ('4'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1),), ((1, 0),))): QQ('-1'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('3'),
    (((-2, -2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('3/2'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((1, 1),), ((1, 2),))): QQ('-3/4'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 2)), ((1, 1),))): QQ('10'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0)), ((0, 1), (2, 1)))): QQ('-1/8'),
    (((-2, -2, 1, 1), (-4, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-2, -2, 1, 1), (-3, -3, 2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('2'),
    (((-2, -2, 1, 1), (-2, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 0)), ((1, 1),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((0, 1),), ((1, 0),), ((1, 1),))): QQ('-2'),
    (((-2, -2, 1, 1), (-2, 2, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('-1/64'),
    (((-2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 0)), ((1, 0), (2, 1)))): QQ('0'),
    (((-2, -2, 1, 1), (-4, 2, 2)), (((0, 0),), ((0, 1), (1, 0)))): QQ('-31/12'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0), (1, 2)))): QQ('-8'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1), (2, 0), (2, 1)))): QQ('1'),
    (((-2, -2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 3)), ((0, 1),), ((0, 2),))): QQ('-240'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 0), (2, 0), (2, 1)))): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('3/2'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 2)), ((0, 1), (1, 0)), ((1, 1),))): QQ('10'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 2)), ((0, 1), (1, 1)))): QQ('-12'),
    (((-2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-151/2'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 1)), ((0, 1), (1, 0), (2, 0)))): QQ('1'),
    (((-4, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 1)), ((1, 1), (2, 0)))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1),))): QQ('5/4'),
    (((-2, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('0'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 1), (1, 2)), ((1, 0),))): QQ('-10'),
    (((-4, 1, 1), (-2, -2, 2, 2)), (((0, 0), (1, 1)), ((1, 0),))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0),), ((0, 1), (1, 0), (2, 0), (2, 1)))): QQ('-1/8'),
    (((-4, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((1, 1), (1, 2)))): QQ('4'),
    (((-4, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('-168'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)), ((1, 2),))): QQ('4'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0)), ((0, 1),), ((1, 1), (1, 2)))): QQ('4'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0), (1, 2)), ((1, 1),))): QQ('-4'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1), (1, 2)))): QQ('-4'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 1)), ((0, 1),), ((1, 1), (2, 0)))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (0, 1), (1, 1)), ((1, 0), (1, 2)))): QQ('-10'),
    (((-4, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('4'),
    (((-2, 2), (-2, -2, 1, 1, 2)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-5/32'),
    (((-2, -2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((0, 1), (1, 2)), ((1, 0),))): QQ('10'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0),), ((0, 1), (1, 2)), ((1, 0), (1, 1)))): QQ('4'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1), (1, 2)), ((0, 1),))): QQ('-8'),
    (((-2, -2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 2)), ((0, 1),), ((1, 1),))): QQ('4'),
    (((-2, -2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('312'),
    (((-4, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((1, 0),), ((1, 1),))): QQ('-2'),
    (((-2, 2), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('5/4'),
    (((-4, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 1)), ((1, 0), (2, 0)))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1), (2, 0)), ((0, 1), (2, 1)))): QQ('1'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (2, 0)), ((0, 1), (1, 0), (1, 1), (2, 1)))): QQ('1'),
    (((-2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((1, 0),), ((1, 1),))): QQ('0'),
    (((-2, 1, 1), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0)), ((0, 1),), ((1, 1), (2, 1)))): QQ('-1'),
    (((-2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 1)), ((0, 2),))): QQ('-151/2'),
    (((-2, -2, 1, 1), (-2, 2), (-2, -2, 2)), (((0, 0), (2, 0)), ((0, 1), (1, 0), (2, 1)))): QQ('-1/8'),
    (((-2, -2, -2, -2, 1, 1, 2, 2),), (((0, 0), (0, 3)), ((0, 1), (0, 2)))): QQ('368'),
    (((-2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0)), ((1, 1), (2, 1)))): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1)), ((0, 1), (2, 0)), ((1, 0), (2, 1)))): QQ('-1'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0), (2, 1)), ((1, 1),))): QQ('1'),
    (((-2, 0, 0), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('-10'),
    (((-2, -2, -2, 1, 3), (-2, 2)), (((0, 0), (0, 2), (1, 0)), ((0, 1),))): QQ('-1/2'),
    (((-2, 0, 0), (-2, -2, -2, 2, 2)), (((0, 0), (1, 2)), ((1, 0), (1, 1)))): QQ('4'),
    (((-2, -2, 2), (-2, -2, -2, 4)), (((0, 0), (0, 1), (1, 0)), ((1, 1), (1, 2)))): QQ('-1'),
    (((-2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-4/3'),
    (((-4, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1), (2, 1)), ((0, 1), (2, 0)))): QQ('-1'),
    (((-2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-4/3'),
    (((0,), (-2, -2, 1, 1), (-2, -2, 2)), (((1, 0), (2, 1)), ((1, 1), (2, 0)))): QQ('1/24'),
    (((-2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0), (1, 1)), ((1, 2),))): QQ('0'),
    (((-2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 0)), ((1, 0), (2, 1)))): QQ('1/8'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 1), (1, 2)), ((0, 1), (1, 0)))): QQ('8'),
    (((-4, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-3'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0), (0, 3)), ((0, 1), (0, 2)))): QQ('-136'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (0, 1), (1, 0)), ((0, 2), (1, 1)))): QQ('6'),
    (((-2, -2, -2, 1, 2, 3),), (((0, 0), (0, 1)), ((0, 2),))): QQ('257/6'),
    (((-2, -2, -2, 2, 2, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('85/2'),
    (((-2, 0, 0), (-2, -2, -2, 1, 3)), (((0, 0), (1, 1), (1, 2)), ((1, 0),))): QQ('4'),
    (((-4, -2, -2, 1, 1, 4),), (((0, 0), (0, 1)), ((0, 2),))): QQ('41'),
    (((-2, -2, -2, -2, 1, 2, 3),), (((0, 0), (0, 2), (0, 3)), ((0, 1),))): QQ('-102'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('-120'),
    (((-2, -2, 1, 1), (-4, -2, 4)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-1'),
    (((-2, -2, -2, -2, 1, 1, 4),), (((0, 0), (0, 1), (0, 2)), ((0, 3),))): QQ('-108'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (2, 0)), ((1, 1), (2, 1)))): QQ('1'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1),), ((0, 2), (1, 1)))): QQ('-4'),
    (((-2, -2, 1, 1), (-2, 4)), (((0, 0),), ((0, 1), (1, 0)))): QQ('23/1152'),
    (((-2, -2, -2, -2, 2, 2, 2),), (((0, 0),), ((0, 1), (0, 3)), ((0, 2),))): QQ('72'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (0, 1)), ((0, 2), (1, 0), (1, 1)))): QQ('4'),
    (((-2, -2, -2, 1, 3), (-2, -2, 2)), (((0, 0), (0, 2), (1, 0), (1, 1)), ((0, 1),))): QQ('4'),
    (((-2, -2, 1, 1), (-3, -3, 4)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-1'),
    (((-2, -2, 2), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 1), (2, 1)), ((0, 1), (1, 0), (2, 0)))): QQ('-1'),
    (((-2, 0, 0, 0), (-2, -2, 0, 1, 1)), (((0, 0), (1, 0)), ((1, 1),))): QQ('-2'),
    (((-2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (1, 0), (1, 2)), ((1, 1),))): QQ('-1/2'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0),), ((0, 1), (1, 1), (1, 2)), ((1, 0),))): QQ('-1'),
    (((-2, -2, -2, -2, 1, 5),), (((0, 0), (0, 1)), ((0, 2),), ((0, 3),))): QQ('-12'),
    (((-2, -2, -2, 1, 3), (-2, 2)), (((0, 0), (0, 1)), ((0, 2), (1, 0)))): QQ('-1/2'),
    (((-2, -2, 1, 1), (-2, -2, 0, 0, 2)), (((0, 0),), ((0, 1), (1, 0), (1, 1)))): QQ('-4'),
    (((-2, 0, 0), (-2, -2, -2, 1, 1, 2)), (((0, 0), (1, 1)), ((1, 0),), ((1, 2),))): QQ('6'),
    (((-2, -2, -2, 0, 0, 2, 2),), (((0, 0),), ((0, 1), (0, 2)))): QQ('-36'),
    (((-4, 1, 1), (-2, -2, 4)), (((0, 0), (1, 1)), ((1, 0),))): QQ('11/12'),
    (((0,), (-2, -2, -2, 0, 2, 2)), (((1, 0), (1, 2)), ((1, 1),))): QQ('-1/2'),
    (((-4, -2, -2, 2, 2, 2),), (((0, 0), (0, 2)), ((0, 1),))): QQ('36'),
    (((-2, 0, 0), (-2, -2, 2), (-2, -2, 2)), (((0, 0), (1, 0), (2, 0)), ((1, 1), (2, 1)))): QQ('-1'),
    (((-2, -2, 1, 1), (-2, -2, -2, 4)), (((0, 0), (1, 0)), ((0, 1), (1, 1), (1, 2)))): QQ('4'),
    (((-2, -2, 0, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0), (1, 1)), ((0, 1),))): QQ('-4'),
    (((-2, -2, 0, 0, 1, 1), (-2, 2)), (((0, 0), (1, 0)), ((0, 1),))): QQ('1/2'),
    (((-2, 0, 0), (-2, 0, 0), (-2, -2, 1, 1)), (((0, 0), (1, 0), (2, 1)), ((2, 0),))): QQ('1'),
    (((-2, -2, 2), (-2, -2, -2, 2, 2)), (((0, 0), (0, 1), (1, 0)), ((1, 1), (1, 2)))): QQ('4'),
    (((-2, 1, 1), (-2, -2, 4)), (((0, 0), (1, 1)), ((1, 0),))): QQ('0'),
    (((-2, -2, 1, 1), (-2, -2, 4)), (((0, 0),), ((0, 1), (1, 0)), ((1, 1),))): QQ('11/12'),
    (((-2, 0, 0), (-2, -2, 1, 1), (-2, 2)), (((0, 0), (1, 1)), ((1, 0), (2, 0)))): QQ('-1/8'),
    (((-2, -2, 0, 0, 1, 1), (-2, -2, 2)), (((0, 0), (1, 0)), ((0, 1), (1, 1)))): QQ('-4'),
}
